@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified July 28, 2022
+Last modified November 9, 2023
 
 Description:  Compares reads to the kmers in a reference dataset, optionally 
 allowing an edit distance. Splits the reads into two outputs - those that 
@@ -26,6 +26,7 @@ ref=<file,file>     Comma-delimited list of reference files.
 literal=<seq,seq>   Comma-delimited list of literal reference sequences.
 touppercase=f       (tuc) Change all bases upper-case.
 interleaved=auto    (int) t/f overrides interleaved autodetection.
+                    Must be set mainually when streaming fastq input.
 qin=auto            Input quality offset: 33 (Sanger), 64, or auto.
 reads=-1            If positive, quit after processing X reads or pairs.
 copyundefined=f     (cu) Process non-AGCT IUPAC reference bases by making all
@@ -110,7 +111,11 @@ k=27                Kmer length used for finding contaminants.  Contaminants
 rcomp=t             Look for reverse-complements of kmers in addition to 
                     forward kmers.
 maskmiddle=t        (mm) Treat the middle base of a kmer as a wildcard, to 
-                    increase sensitivity in the presence of errors.
+                    increase sensitivity in the presence of errors.  This may
+                    also be set to a number, e.g. mm=3, to mask that many bp.
+                    The default mm=t corresponds to mm=1 for odd-length kmers
+                    and mm=2 for even-length kmers (as of v39.04), while
+                    mm=f is always equivalent to mm=0.
 minkmerhits=1       (mkh) Reads need at least this many matching kmers 
                     to be considered as matching the reference.
 minkmerfraction=0.0 (mkf) A reads needs at least this fraction of its total
