@@ -1,10 +1,10 @@
 #!/bin/bash
 
 #usage(){
-#	echo "CalcMem v1.15"
+#	echo "CalcMem v1.16"
 #	echo "Written by Brian Bushnell, Doug Jacobsen, Alex Copeland, Bryce Foster"
 #	echo "Calculates available memory in megabytes"
-#	echo "Last modified December 17, 2019"
+#	echo "Last modified October 18, 2023"
 #}
 
 #Also parses other Java flags
@@ -13,6 +13,7 @@ function parseXmx () {
 	local setxmx=0
 	local setxms=0
 	
+	SIMD=""
 	for arg in "$@"
 	do
 		if [[ "$arg" == "Xmx="* ]] || [[ "$arg" == "xmx="* ]]; then
@@ -47,6 +48,8 @@ function parseXmx () {
 			json=1
 		elif [[ "$arg" == silent ]] || [[ "$arg" == "silent=t" ]] || [[ "$arg" == "silent=true" ]]; then
 			silent=1
+		elif [[ "$arg" == "simd" ]] || [[ "$arg" == "SIMD" ]] || [[ "$arg" == "simd=t" ]] || [[ "$arg" == "simd=true" ]]; then
+			SIMD="--add-modules jdk.incubator.vector"
 		fi
 	done
 	
