@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified July 28, 2022
+Last modified October 20, 2023
 
 Description:  Sorts sequences to put similar reads near each other.
 Can be used for increased compression or error correction.
@@ -119,7 +119,8 @@ dupedist=40         (dist) Max distance to consider for optical duplicates.
                        HiSeq 1T     40
                        HiSeq 2500   40
                        HiSeq 3k/4k  2500
-                       Novaseq      12000
+                       Novaseq6000  12000
+                       NovaseqX+    50
 spany=f             Allow reads to be considered optical duplicates if they
                     are on different tiles, but are within dupedist in the
                     y-axis.  Should only be enabled when looking for 
@@ -146,7 +147,10 @@ ecc=f               Error-correct reads.  Requires multiple passes for
                     complete correction.
 ecco=f              Error-correct paired reads via overlap before clumping.
 passes=1            Use this many error-correction passes.  6 passes are 
-                    suggested.
+                    suggested, though more will be more through.
+conservative=f      Only correct the highest-confidence errors, to minimize
+                    chances of eliminating a minor allele or inexact repeat.
+aggressive=f        Maximize the number of errors corrected.
 consensus=f         Output consensus sequence instead of clumps.
 
 Advanced error-correction parameters:
