@@ -6,6 +6,7 @@ import java.util.HashMap;
 
 import dna.AminoAcid;
 import dna.Data;
+import shared.KillSwitch;
 import shared.Shared;
 import shared.Tools;
 import stream.SiteScore;
@@ -609,7 +610,7 @@ public final class BBIndexPacBioSkimmer extends AbstractIndex {
 		assert(offsetsM.length==offsetsP.length);
 		assert(maxQuickScore==maxQuickScore(offsetsM, keyScoresM));
 		
-		final int[] bestScores=new int[6];
+		final int[] bestScores=KillSwitch.allocInt1D(6);
 		
 		//This prevents filtering by qscore when a low-quality read only uses a few keys.
 		//In that case, extending is more important.
@@ -2079,7 +2080,7 @@ public final class BBIndexPacBioSkimmer extends AbstractIndex {
 	private final int[] startArray=new int[1001];
 	private final int[] stopArray=new int[1001];
 	private final Quad[] tripleStorage=makeQuadStorage(1001);
-	private final int[] greedyReturn=new int[2];
+	private final int[] greedyReturn=KillSwitch.allocInt1D(2);
 	private final int[][] shrinkReturn2=new int[3][];
 	private final int[][] shrinkReturn3=new int[5][];
 	private final int[][] prescanReturn=new int[2][];
