@@ -18,13 +18,13 @@ import fileIO.TextFile;
 import fileIO.TextStreamWriter;
 import shared.Parse;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
 import stream.ConcurrentReadOutputStream;
 import stream.Read;
 import stream.SiteScore;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
