@@ -10,7 +10,7 @@ import fileIO.TextStreamWriter;
 import shared.Parse;
 import shared.PreParser;
 import shared.Tools;
-import stream.Header;
+import stream.CustomHeader;
 import stream.Read;
 import stream.SamLine;
 
@@ -214,7 +214,7 @@ public class GradeSamFile {
 				mappedRetained++;
 				
 				if(parsecustom){
-					Header h=new Header(sl.qname, sl.pairnum());
+					CustomHeader h=new CustomHeader(sl.qname, sl.pairnum());
 					boolean strict=isCorrectHit(sl, h);
 					boolean loose=isCorrectHitLoose(sl, h);
 
@@ -293,7 +293,7 @@ public class GradeSamFile {
 		
 	}
 	
-	public static boolean isCorrectHit(SamLine sl, Header h){
+	public static boolean isCorrectHit(SamLine sl, CustomHeader h){
 		if(!sl.mapped()){return false;}
 		if(h.strand!=sl.strand()){return false;}
 		int start=sl.start(true, true);
@@ -304,7 +304,7 @@ public class GradeSamFile {
 		return true;
 	}
 	
-	public static boolean isCorrectHitLoose(SamLine sl, Header h){
+	public static boolean isCorrectHitLoose(SamLine sl, CustomHeader h){
 		if(!sl.mapped()){return false;}
 		if(h.strand!=sl.strand()){return false;}
 		int start=sl.start(true, true);
