@@ -17,7 +17,6 @@ import fileIO.TextStreamWriter;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -25,6 +24,8 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ByteBuilder;
+import structures.Quantizer;
+import tracker.ReadStats;
 
 public final class RandomReads3 {
 	
@@ -124,6 +125,8 @@ public final class RandomReads3 {
 				//do nothing
 			}else if(Parser.parseQuality(arg, a, b)){
 				//do nothing
+			}else if(a.equals("quantize") || a.equals("quantizesticky")){
+				quantizeQuality=Quantizer.parse(arg, a, b);
 			}else if(a.equals("coverage")){
 				targetCov=Float.parseFloat(b);
 			}else if(a.equals("simplenames") || a.equals("simple") || a.equals("tagsimple")){
@@ -474,6 +477,7 @@ public final class RandomReads3 {
 		if(paired){
 			outstream.println("insert size="+(mateMiddleMin+2*minlen)+"-"+(mateMiddleMax+2*maxlen));
 		}
+//		assert(false) : mateMiddleMin+", "+mateMiddleMax;
 		
 //		assert(false) : OUTPUT_INTERLEAVED;
 		String fname1="reads_B"+Data.GENOME_BUILD+"_"+maxReads+"x"+maxlen+"bp_"
@@ -1560,7 +1564,7 @@ public final class RandomReads3 {
 		int[] delsa=makeDelsa(DELs, minDelLen, maxDelLen, randy2);
 		
 		int readlen=genReadLen(minlen, maxlen, midlen, randyLength, LINEAR_LENGTH, BELL_LENGTH);
-		int inititallen0=readlen+(delsa==null ? 0 : (int)Tools.sum(delsa));
+		int inititallen0=readlen+(delsa==null ? 0 : (int)shared.Vector.sum(delsa));
 		
 		if(verbose){
 			outstream.println("delsa="+Arrays.toString(delsa));
@@ -1579,14 +1583,14 @@ public final class RandomReads3 {
 			if(x==null){return null;}
 			loc=x[0];
 			inititallen0=x[1];
-			readlen=inititallen0-(delsa==null ? 0 : (int)Tools.sum(delsa));
+			readlen=inititallen0-(delsa==null ? 0 : (int)shared.Vector.sum(delsa));
 		}else if(METAGENOME){
 			int[] x=randomScaffoldLocMetagenome(inititallen0);
 			if(x==null){return null;}
 			chrom=x[0];
 			loc=x[1];
 			inititallen0=x[2];
-			readlen=inititallen0-(delsa==null ? 0 : (int)Tools.sum(delsa));
+			readlen=inititallen0-(delsa==null ? 0 : (int)shared.Vector.sum(delsa));
 		}else{
 			loc=randomLoc(r0, chrom, inititallen0, minMiddle, maxMiddle, strand);
 		}
@@ -1771,6 +1775,10 @@ public final class RandomReads3 {
 		if(adapters>0){r.setHasAdapter(true);}
 		if(FORCE_SINGLE_SCAFFOLD && !Data.isSingleScaffold(r.chrom, r.start, r.stop)){return null;}
 		if(MIN_SCAFFOLD_OVERLAP>0 && Data.scaffoldOverlapLength(r.chrom, r.start, r.stop)<MIN_SCAFFOLD_OVERLAP){return null;}
+		
+		if(quantizeQuality) {
+			Quantizer.quantize(r.quality);
+		}
 		return r;
 	}
 	
@@ -1819,7 +1827,7 @@ public final class RandomReads3 {
 	private static int[] fillRandomChrom(){
 
 		int[] in=Arrays.copyOf(Data.chromLengths, Data.chromLengths.length);
-		long total=Tools.sum(in);
+		long total=shared.Vector.sum(in);
 		int div=(int)(total/8192);
 		for(int i=0; i<in.length; i++){in[i]=((in[i]+div-1)/div);}
 
@@ -1890,6 +1898,8 @@ public final class RandomReads3 {
 	
 	private String prefix;
 	
+	private static boolean quantizeQuality=false;
+	
 	/*--------------------------------------------------------------*/
 	/*----------------        Static Fields         ----------------*/
 	/*--------------------------------------------------------------*/
