@@ -11,7 +11,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -21,6 +20,7 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import template.Accumulator;
 import template.ThreadWaiter;
+import tracker.ReadStats;
 
 /**
  * Aligns all sequences to all sequences and produces an identity matrix.
