@@ -21,7 +21,6 @@ import kmer.KmerTableSet;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -31,6 +30,7 @@ import stream.FastaReadInputStream;
 import structures.ByteBuilder;
 import structures.IntList;
 import structures.LongList;
+import tracker.ReadStats;
 import ukmer.Kmer;
 import ukmer.KmerTableSetU;
 
