@@ -12,10 +12,10 @@ import fileIO.ReadWrite;
 import jgi.FilterByCoverage;
 import shared.Parse;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
