@@ -467,7 +467,7 @@ public class BloomFilterCorrector {
 			final long x=AminoAcid.baseToNumber[base];
 			final long x2=AminoAcid.baseToComplementNumber[base];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			if(x<0){
 				len=0;
@@ -575,7 +575,7 @@ public class BloomFilterCorrector {
 
 				//Now consider the next kmer
 				kmer=((kmer<<2)|(long)x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				len++;
 
 				if(verbose){
@@ -943,7 +943,7 @@ public class BloomFilterCorrector {
 				final long x=AminoAcid.baseToNumber[b];
 				final long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(x<0){
 					len=0;
 					kmer=rkmer=0;
@@ -1029,7 +1029,7 @@ public class BloomFilterCorrector {
 			
 			//Now consider the next kmer
 			kmer=((kmer<<2)|(long)x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			key=toValue(kmer, rkmer);
 			
@@ -1108,7 +1108,7 @@ public class BloomFilterCorrector {
 			final long x=AminoAcid.baseToNumber[b];
 			final long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){
 				len=0;
 				kmer=rkmer=0;
@@ -1360,7 +1360,7 @@ public class BloomFilterCorrector {
 			final long x=AminoAcid.baseToNumber[base];
 			final long x2=AminoAcid.baseToComplementNumber[base];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			if(x<0){
 				len=0;
