@@ -17,7 +17,6 @@ import shared.MetadataWriter;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -30,6 +29,7 @@ import stream.SamLine;
 import structures.IntList;
 import structures.ListNum;
 import structures.LongList;
+import tracker.ReadStats;
 
 /**
  * Wraps a BloomFilter to filter or correct reads.
