@@ -13,7 +13,6 @@ import jgi.BBMerge;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -25,6 +24,7 @@ import stream.Read;
 import stream.SamLine;
 import structures.ListNum;
 import structures.LongList;
+import tracker.ReadStats;
 
 /**
  * Wraps a BloomFilter to filter reads.
@@ -387,8 +387,8 @@ public class BloomFilterWrapper {
 			long basesMatched=(basesProcessed-basesOut);
 			double rpct=readsMatched*100.0/readsProcessed;
 			double bpct=basesMatched*100.0/basesProcessed;
-			String rstring=Tools.padKM(readsMatched, 8);
-			String bstring=Tools.padKM(basesMatched, 8);
+			String rstring=Tools.padKMB(readsMatched, 8);
+			String bstring=Tools.padKMB(basesMatched, 8);
 			StringBuilder sb=new StringBuilder();
 			sb.append("Reads Matched:      ").append(rstring).append(String.format(Locale.ROOT, " \t%.2f%%", rpct)).append('\n');
 			sb.append("Bases Matched:      ").append(bstring).append(String.format(Locale.ROOT, " \t%.2f%%", bpct));
