@@ -36,12 +36,11 @@ public final class KCountArray7MTA extends KCountArray {
 	public static void main(String[] args){
 		long cells=Long.parseLong(args[0]);
 		int bits=Integer.parseInt(args[1]);
-		int gap=Integer.parseInt(args[2]);
-		int hashes=Integer.parseInt(args[3]);
+		int hashes=Integer.parseInt(args[2]);
 		
 		verbose=false;
 		
-		KCountArray7MTA kca=new KCountArray7MTA(cells, bits, gap, hashes, null, 0);
+		KCountArray7MTA kca=new KCountArray7MTA(cells, bits, hashes, null, 0);
 		
 		System.out.println(kca.read(0));
 		kca.increment(0);
@@ -74,8 +73,8 @@ public final class KCountArray7MTA extends KCountArray {
 		
 	}
 	
-	public KCountArray7MTA(long cells_, int bits_, int gap_, int hashes_, KCountArray prefilter_, int prefilterLimit_){
-		super(getPrimeCells(cells_, bits_), bits_, gap_, getDesiredArrays(cells_, bits_));
+	public KCountArray7MTA(long cells_, int bits_, int hashes_, KCountArray prefilter_, int prefilterLimit_){
+		super(getPrimeCells(cells_, bits_), bits_, getDesiredArrays(cells_, bits_));
 //		verbose=false;
 //		System.out.println(cells);
 		cellsPerArray=cells/numArrays;
@@ -266,33 +265,43 @@ public final class KCountArray7MTA extends KCountArray {
 	}
 	
 	@Override
-	public final void increment(final long rawKey){
-		if(verbose){System.err.println("\n*** Incrementing raw key "+rawKey+" ***");}
-		
-		if(prefilter!=null){
-			int x=prefilter.read(rawKey);
-			if(x<prefilterLimit){return;}
-		}
-		
-		if(useLocks){incrementLocked(rawKey);}
-		else{incrementUnlocked(rawKey);}
+	public final void increment(final long rawKey, final int amt){
+//		if(verbose){System.err.println("\n*** Incrementing raw key "+rawKey+" ***");}
+//		
+//		if(prefilter!=null){
+//			int x=prefilter.read(rawKey);
+//			if(x<prefilterLimit){return;/* x;*/}
+//		}
+//		
+//		if(useLocks){incrementLocked(rawKey, amt);}
+//		else{incrementUnlocked(rawKey, amt);}
+		incrementAndReturnUnincremented(rawKey, amt);
 	}
 	
-	private void incrementUnlocked(long rawKey){
+	/*
+	private void incrementUnlocked(long rawKey, int amt){
 		long key2=rawKey;
+//		int min=maxValue;
 		for(int i=0; i<hashes; i++){
 			key2=hash(key2, i);
 			if(verbose){System.err.println("key2="+key2+", value="+readHashed(key2));}
-			incrementHashedLocal(key2);
+//			min=min(min, incrementHashedLocal(key2, amt));
+			incrementHashedLocal(key2, amt);
 			key2=Long.rotateRight(key2, hashBits);
 		}
+//		return min;
 	}
 	
-	private void incrementLocked(long rawKey){
+	private void incrementLocked(long rawKey, int amt){
+		assert(amt>0) : "Don't increment by zero, and negatives should use decrement amt="+amt;
 		final Lock lock=getLock(rawKey);
 		lock.lock();
 		final int min=read(rawKey);
-		if(min>=maxValue){
+		final long newMinL=Tools.min(min+amt, maxValue);
+		final int newMin=(int)newMinL;
+		assert(newMin==newMinL && newMin>0) : newMin+", "+newMinL+", "+min+", "+amt;
+		if(newMin<=min){
+			assert(newMin==min) : min;
 			lock.unlock();
 			return;
 		}
@@ -300,35 +309,32 @@ public final class KCountArray7MTA extends KCountArray {
 		for(int i=0; i<hashes; i++){
 			key2=hash(key2, i);
 			if(verbose){System.err.println("key2="+key2+", value="+readHashed(key2));}
-			incrementHashedLocal_ifAtMost(key2, min);
+			//incrementHashedLocal_ifAtMost(key2, min);
+			incrementHashedLocal_toAtLeast(key2, newMin);
 			key2=Long.rotateRight(key2, hashBits);
 		}
 		lock.unlock();
+//		return max(min, newMin);
 	}
+	*/
 	
 	@Override
-	public final void decrement(final long rawKey){
+	public final void decrement(final long rawKey, int amt){
 		if(verbose){System.err.println("\n*** Decrementing raw key "+rawKey+" ***");}
 		
-		assert(prefilter!=null);
+		assert(prefilter!=null); //Why?
 		
 		long key2=rawKey;
+//		int min=maxValue;
 		for(int i=0; i<hashes; i++){
 			key2=hash(key2, i);
 			if(verbose){System.err.println("key2="+key2+", value="+readHashed(key2));}
-//			assert(readHashed(key2)==0);
-			
-//			int bnum=(int)(key2&arrayMask);
-			decrementHashedLocal(key2);
-//			assert(read(rawKey)<=min+incr) : "i="+i+", original="+min+", new should be <="+(min+incr)+", new="+read(rawKey)+", max="+maxValue+", key="+rawKey;
-//			assert(readHashed(key2)>=min+incr) : "i="+i+", original="+min+", new should be <="+(min+incr)+", new="+read(rawKey)+", max="+maxValue+", key="+rawKey;
+
+			decrementHashedLocal(key2, amt);
+//			min=min(min, decrementHashedLocal(key2, amt));
 			key2=Long.rotateRight(key2, hashBits);
 		}
-	}
-	
-	@Override
-	public int incrementAndReturn(long key, int incr){
-		throw new RuntimeException("Operation not supported.");
+//		return min;
 	}
 	
 	@Override
@@ -346,6 +352,7 @@ public final class KCountArray7MTA extends KCountArray {
 	}
 	
 	private int incrementAndReturnUnincrementedLocked(final long rawKey, final int incr){
+		assert(incr>0) : incr;
 		final Lock lock=getLock(rawKey);
 		lock.lock();
 		final int min=read(rawKey);
@@ -353,12 +360,13 @@ public final class KCountArray7MTA extends KCountArray {
 			lock.unlock();
 			return min;
 		}
+		final int newMin=(int)Tools.min(min+(long)incr, maxValue);
 		long key2=rawKey;
 		int value=maxValue;
 		for(int i=0; i<hashes; i++){
 			key2=hash(key2, i);
 			if(verbose){System.err.println("key2="+key2+", value="+readHashed(key2));}
-			int x=incrementHashedLocalAndReturnUnincremented_ifAtMost(key2, incr, min);
+			int x=incrementHashedLocalAndReturnUnincremented_toAtLeast(key2, newMin);
 			value=min(value, x);
 			key2=Long.rotateRight(key2, hashBits);
 		}
@@ -395,11 +403,6 @@ public final class KCountArray7MTA extends KCountArray {
 			for(int keynum=0; keynum<rawKeys.length; keynum++){
 				key2=hash(key2^rawKeys[keynum], i);
 				if(verbose){System.err.println("key2="+key2+", value="+readHashed(key2));}
-				//			assert(readHashed(key2)==0);
-
-				//			int bnum=(int)(key2&arrayMask);
-				//			assert(read(rawKey)<=min+incr) : "i="+i+", original="+min+", new should be <="+(min+incr)+", new="+read(rawKey)+", max="+maxValue+", key="+rawKey;
-				//			assert(readHashed(key2)>=min+incr) : "i="+i+", original="+min+", new should be <="+(min+incr)+", new="+read(rawKey)+", max="+maxValue+", key="+rawKey;
 			}
 			int x=incrementHashedLocalAndReturnUnincremented(key2, incr);
 			value=min(value, x);
@@ -640,7 +643,7 @@ public final class KCountArray7MTA extends KCountArray {
 		return lock;
 	}
 	
-	private int incrementHashedLocal(long key){
+	private int incrementHashedLocal(long key, int amt){
 		final int num=(int)(key&arrayMask);
 		final AtomicIntegerArray array=matrix[num];
 		key=(key>>>arrayBits)%(cellMod);
@@ -652,14 +655,34 @@ public final class KCountArray7MTA extends KCountArray {
 			assert(index>=0) : key+", "+cellMod+", "+cellBits+", "+valueMask+", "+arrayMask+", "+index+", "+num;
 			word=array.get(index);
 			value=((word>>>cellShift)&valueMask);
-			value=min(value+1, maxValue);
+			value=(int)min(value+(long)amt, maxValue);
 			word2=(value<<cellShift)|(word&~((valueMask)<<cellShift));
 		}while(word!=word2 && !array.compareAndSet(index, word, word2));
 //		if(value==1){cellsUsedPersonal.incrementAndGet(num);}
 		return value;
 	}
 	
-	private int incrementHashedLocal_ifAtMost(long key, final int thresh){
+//	private int incrementHashedLocal_ifAtMost(long key, final int thresh){
+//		final int num=(int)(key&arrayMask);
+//		final AtomicIntegerArray array=matrix[num];
+//		key=(key>>>arrayBits)%(cellMod);
+////		key=(key>>>(arrayBits+1))%(cellMod);
+//		int index=(int)(key>>>indexShift);
+//		int cellShift=(int)(cellBits*key);
+//		int value, word, word2;
+//		do{
+//			assert(index>=0) : key+", "+cellMod+", "+cellBits+", "+valueMask+", "+arrayMask+", "+index+", "+num;
+//			word=array.get(index);
+//			value=((word>>>cellShift)&valueMask);
+//			if(value>thresh){return value;}//Too high; don't increment
+//			value=min(value+1, maxValue);
+//			word2=(value<<cellShift)|(word&~((valueMask)<<cellShift));
+//		}while(word!=word2 && !array.compareAndSet(index, word, word2));
+//		return value;
+//	}
+	
+	private int incrementHashedLocal_toAtLeast(long key, final int newMin){
+		assert(newMin<=maxValue);
 		final int num=(int)(key&arrayMask);
 		final AtomicIntegerArray array=matrix[num];
 		key=(key>>>arrayBits)%(cellMod);
@@ -671,7 +694,7 @@ public final class KCountArray7MTA extends KCountArray {
 			assert(index>=0) : key+", "+cellMod+", "+cellBits+", "+valueMask+", "+arrayMask+", "+index+", "+num;
 			word=array.get(index);
 			value=((word>>>cellShift)&valueMask);
-			if(value>thresh){return value;}//Too high; don't increment
+			if(value>=newMin){return value;}//Too high; don't increment
 			value=min(value+1, maxValue);
 			word2=(value<<cellShift)|(word&~((valueMask)<<cellShift));
 		}while(word!=word2 && !array.compareAndSet(index, word, word2));
@@ -697,8 +720,28 @@ public final class KCountArray7MTA extends KCountArray {
 		return value;
 	}
 	
-	private int incrementHashedLocalAndReturnUnincremented_ifAtMost(long key, int incr, final int thresh){
-		assert(incr>=0);
+//	private int incrementHashedLocalAndReturnUnincremented_ifAtMost(long key, int incr, final int thresh){
+//		assert(incr>=0);
+//		final int num=(int)(key&arrayMask);
+//		final AtomicIntegerArray array=matrix[num];
+//		key=(key>>>arrayBits)%(cellMod);
+////		key=(key>>>(arrayBits+1))%(cellMod);
+//		int index=(int)(key>>>indexShift);
+//		int cellShift=(int)(cellBits*key);
+//		int value, word, word2;
+//		do{
+//			word=array.get(index);
+//			value=((word>>>cellShift)&valueMask);
+//			if(value>thresh){return value;}//Too high; don't increment
+//			int value2=min(value+incr, maxValue);
+//			word2=(value2<<cellShift)|(word&~((valueMask)<<cellShift));
+//		}while(word!=word2 && !array.compareAndSet(index, word, word2));
+////		if(value==1){cellsUsedPersonal.incrementAndGet(num);}
+//		return value;
+//	}
+	
+	private int incrementHashedLocalAndReturnUnincremented_toAtLeast(long key, int newMin){
+		assert(newMin>0 && newMin<=maxValue) : newMin;
 		final int num=(int)(key&arrayMask);
 		final AtomicIntegerArray array=matrix[num];
 		key=(key>>>arrayBits)%(cellMod);
@@ -706,18 +749,18 @@ public final class KCountArray7MTA extends KCountArray {
 		int index=(int)(key>>>indexShift);
 		int cellShift=(int)(cellBits*key);
 		int value, word, word2;
+		final int value2s=newMin<<cellShift;
 		do{
 			word=array.get(index);
 			value=((word>>>cellShift)&valueMask);
-			if(value>thresh){return value;}//Too high; don't increment
-			int value2=min(value+incr, maxValue);
-			word2=(value2<<cellShift)|(word&~((valueMask)<<cellShift));
+			if(value>=newMin){return value;}//Too high; don't increment
+			word2=value2s|(word&~((valueMask)<<cellShift));
 		}while(word!=word2 && !array.compareAndSet(index, word, word2));
 //		if(value==1){cellsUsedPersonal.incrementAndGet(num);}
 		return value;
 	}
 	
-	private int decrementHashedLocal(long key){
+	private int decrementHashedLocal(long key, int amt){
 		final int num=(int)(key&arrayMask);
 		final AtomicIntegerArray array=matrix[num];
 		key=(key>>>arrayBits)%(cellMod);
@@ -728,7 +771,7 @@ public final class KCountArray7MTA extends KCountArray {
 		do{
 			word=array.get(index);
 			value=((word>>>cellShift)&valueMask);
-			value=max(value-1, 0);
+			value=max(value-amt, 0);
 			word2=(value<<cellShift)|(word&~((valueMask)<<cellShift));
 		}while(word!=word2 && !array.compareAndSet(index, word, word2));
 //		if(value==1){cellsUsedPersonal.incrementAndGet(num);}
