@@ -10,7 +10,6 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import stream.ConcurrentGenericReadInputStream;
@@ -19,6 +18,7 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
 import structures.LongList;
+import tracker.ReadStats;
 
 class LogLogWrapper {
 	
