@@ -14,7 +14,6 @@ import jgi.Dedupe;
 import shared.Parse;
 import shared.Parser;
 import shared.Primes;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -23,6 +22,7 @@ import stream.ConcurrentReadInputStream;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 import ukmer.Kmer;
 
 /**
