@@ -1022,7 +1022,11 @@ public class Clump extends ArrayList<Read> implements Comparable<Clump> {
 		}else if(a.equals("dupesubs") || a.equals("duplicatesubs") || a.equals("dsubs") || a.equals("subs") || a.equals("s")){
 			maxSubstitutions=Integer.parseInt(b);
 		}else if(a.equals("dupedist") || a.equals("duplicatedistance") || a.equals("ddist") || a.equals("dist") || a.equals("opticaldist") || a.equals("distance")){
-			maxOpticalDistance=Float.parseFloat(b);
+			try {
+				maxOpticalDistance=Float.parseFloat(b);
+			} catch (NumberFormatException e) {
+				maxOpticalDistance=Parse.parseKMG(b);
+			}
 			opticalOnly=maxOpticalDistance>=0;
 		}else if(a.equals("scanlimit") || a.equals("scan")){
 			scanLimit=Integer.parseInt(b);
