@@ -8,6 +8,7 @@ import java.util.Random;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import jgi.BBMerge;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -105,23 +106,23 @@ public class Clumpify {
 			}else if(a.equals("groups") || a.equals("g") || a.equals("sets") || a.equals("ways")){
 				gString=b;
 			}else if(a.equals("delete") || a.equals("deletetemp")){
-				delete=Tools.parseBoolean(b);
+				delete=Parse.parseBoolean(b);
 			}else if(a.equals("deleteinput")){
-				deleteInput=Tools.parseBoolean(b);
+				deleteInput=Parse.parseBoolean(b);
 			}else if(a.equals("usetmpdir")){
-				useTmpdir=Tools.parseBoolean(b);
+				useTmpdir=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
-				ecco=Tools.parseBoolean(b);
+				ecco=Parse.parseBoolean(b);
 			}else if(a.equals("compresstemp") || a.equals("ct")){
 				if(b!=null && b.equalsIgnoreCase("auto")){forceCompressTemp=forceRawTemp=false;}
 				else{
-					forceCompressTemp=Tools.parseBoolean(b);
+					forceCompressTemp=Parse.parseBoolean(b);
 					forceRawTemp=!forceCompressTemp;
 				}
 			}else if(a.equals("tmpdir")){
 				Shared.setTmpdir(b);
 			}else if(a.equals("rename") || a.equals("addname")){
-				addName=Tools.parseBoolean(b);
+				addName=Parse.parseBoolean(b);
 			}else if(a.equals("shortname") || a.equals("shortnames")){
 				shortName=b;
 			}else if(a.equals("seed")){
@@ -139,21 +140,21 @@ public class Clumpify {
 			}
 
 			else if(a.equals("unpair")){
-				unpair=Tools.parseBoolean(b);
+				unpair=Parse.parseBoolean(b);
 			}else if(a.equals("repair")){
-				repair=Tools.parseBoolean(b);
+				repair=Parse.parseBoolean(b);
 			}else if(a.equals("namesort") || a.equals("sort")){
-				namesort=Tools.parseBoolean(b);
+				namesort=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("v1") || a.equals("kmersort1")){
-				boolean x=Tools.parseBoolean(b);
+				boolean x=Parse.parseBoolean(b);
 				if(x){V2=V3=false;}
 			}else if(a.equals("v2") || a.equals("kmersort2")){
-				V2=Tools.parseBoolean(b);
+				V2=Parse.parseBoolean(b);
 				if(V2){V3=false;}
 			}else if(a.equals("v3") || a.equals("kmersort3")){
-				V3=Tools.parseBoolean(b);
+				V3=Parse.parseBoolean(b);
 				if(V3){V2=false;}
 			}else if(a.equals("fetchthreads")){
 				KmerSort3.fetchThreads=Integer.parseInt(b);
@@ -161,35 +162,35 @@ public class Clumpify {
 			}
 			
 			else if(a.equals("comparesequence")){
-				KmerComparator.compareSequence=Tools.parseBoolean(b);
+				KmerComparator.compareSequence=Parse.parseBoolean(b);
 			}else if(a.equals("allowadjacenttiles") || a.equals("spantiles")){
-				ReadKey.spanTilesX=ReadKey.spanTilesY=Tools.parseBoolean(b);
+				ReadKey.spanTilesX=ReadKey.spanTilesY=Parse.parseBoolean(b);
 			}else if(a.equals("spanx") || a.equals("spantilesx")){
-				ReadKey.spanTilesX=Tools.parseBoolean(b);
+				ReadKey.spanTilesX=Parse.parseBoolean(b);
 			}else if(a.equals("spany") || a.equals("spantilesy")){
-				ReadKey.spanTilesY=Tools.parseBoolean(b);
+				ReadKey.spanTilesY=Parse.parseBoolean(b);
 			}else if(a.equals("spanadjacent") || a.equals("spanadjacentonly") || a.equals("adjacentonly") || a.equals("adjacent")){
-				ReadKey.spanAdjacentOnly=Tools.parseBoolean(b);
+				ReadKey.spanAdjacentOnly=Parse.parseBoolean(b);
 			}
 			
 //			else if(a.equals("repair")){
-//				repair=Tools.parseBoolean(b);
+//				repair=Parse.parseBoolean(b);
 //			}else if(a.equals("namesort") || a.equals("sort")){
-//				namesort=Tools.parseBoolean(b);
+//				namesort=Parse.parseBoolean(b);
 //			}
 			
 			else if(a.equals("interleaved") || a.equals("int")){
 				if("auto".equalsIgnoreCase(b)){FASTQ.FORCE_INTERLEAVED=!(FASTQ.TEST_INTERLEAVED=true);}
 				else{
-					FASTQ.FORCE_INTERLEAVED=FASTQ.TEST_INTERLEAVED=Tools.parseBoolean(b);
+					FASTQ.FORCE_INTERLEAVED=FASTQ.TEST_INTERLEAVED=Parse.parseBoolean(b);
 					System.err.println("Set INTERLEAVED to "+FASTQ.FORCE_INTERLEAVED);
 				}
 			}else if(a.equals("cq") || a.equals("changequality")){
-				BBMerge.changeQuality=Read.CHANGE_QUALITY=Tools.parseBoolean(b);
+				BBMerge.changeQuality=Read.CHANGE_QUALITY=Parse.parseBoolean(b);
 			}else if(a.equals("quantize") || a.equals("quantizesticky")){
 				quantizeQuality=Quantizer.parse(arg, a, b);
 			}else if(a.equals("lowcomplexity")){
-				lowComplexity=Tools.parseBoolean(b);
+				lowComplexity=Parse.parseBoolean(b);
 			}
 			
 			else if(Clump.parseStatic(arg, a, b)){
