@@ -13,7 +13,6 @@ import prok.ProkObject;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -30,6 +29,7 @@ import structures.ByteBuilder;
 import structures.ListNum;
 import template.Accumulator;
 import template.ThreadWaiter;
+import tracker.ReadStats;
 import var2.Realigner;
 import var2.SamFilter;
 
