@@ -14,7 +14,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -29,6 +28,7 @@ import structures.ByteBuilder;
 import structures.ListNum;
 import template.Accumulator;
 import template.ThreadWaiter;
+import tracker.ReadStats;
 import var2.SamFilter;
 
 /**
