@@ -230,7 +230,7 @@ public class SummarizeCoverage {
 			}
 			line=bf.nextLine();
 		}
-		long len=Tools.sum(hist);
+		long len=shared.Vector.sum(hist);
 		if(refLen>0){
 			assert(refLen>=len);
 			len=refLen;
