@@ -17,7 +17,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -27,6 +26,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
@@ -172,17 +172,31 @@ public class PlotGC {
 				}
 				
 				for(Read r : reads){
-					Arrays.fill(acgt, 0);
-					byte[] bases=r.bases;
-					int next=interval-1;
-					int start=0, i=0;
-					for(; i<bases.length; i++){
-						int num=AminoAcid.baseToNumber[bases[i]];
-						if(num>=0){acgt[num]++;}
-						if(i>=next){
-							int len=(i-start);
+					if(r.bases!=null) {
+						Arrays.fill(acgt, 0);
+						byte[] bases=r.bases;
+						int next=interval-1;
+						int start=0, i=0;
+						for(; i<bases.length; i++){
+							int num=AminoAcid.baseToNumber[bases[i]];
+							if(num>=0){acgt[num]++;}
+							if(i>=next){
+								int len=(i-start);
+								rStop=rStart+len;
+								String s=toGC(r.id, start, i, rStart, rStop, acgt);
+								start=i+1;
+								rStart=rStop+1;
+								next=i+interval;
+								Arrays.fill(acgt, 0);
+								if(tsw!=null && s!=null){
+									tsw.print(s);
+								}
+							}
+						}
+						if(printShortBins && i>start){
+							int len=(i-start)-1;
 							rStop=rStart+len;
-							String s=toGC(r.id, start, i, rStart, rStop, acgt);
+							String s=toGC(r.id, start, i-1, rStart, rStop, acgt);
 							start=i+1;
 							rStart=rStop+1;
 							next=i+interval;
@@ -192,18 +206,6 @@ public class PlotGC {
 							}
 						}
 					}
-					if(printShortBins && i>start){
-						int len=(i-start)-1;
-						rStop=rStart+len;
-						String s=toGC(r.id, start, i-1, rStart, rStop, acgt);
-						start=i+1;
-						rStart=rStop+1;
-						next=i+interval;
-						Arrays.fill(acgt, 0);
-						if(tsw!=null && s!=null){
-							tsw.print(s);
-						}
-					}
 				}
 				
 				cris.returnList(ln);
