@@ -59,8 +59,7 @@ public final class SelectReads {
 			}
 		}
 		tf.close();
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		
 	}
 	
