@@ -11,8 +11,8 @@ import java.util.zip.ZipOutputStream;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Timer;
+import tracker.ReadStats;
 
 
 /**
