@@ -13,6 +13,7 @@ import jgi.TestFormat;
 import shared.Parse;
 import shared.PreParser;
 import shared.Tools;
+import stream.Read;
 
 /**
  * This class contains metadata about a file
@@ -82,6 +83,7 @@ public final class FileFormat {
 				i=(qi[1]==INTERLEAVED);
 				len=qi[2];
 				stream.FASTQ.ASCII_OFFSET=qold;
+				//TODO: Check barcode status here
 			}else if(ff.fasta()){
 				i=stream.FASTQ.testInterleavedFasta(fname, false);
 			}
@@ -244,8 +246,11 @@ public final class FileFormat {
 		interleaving=a[3];
 		asciiOffset=a[4];
 		length=a[5];
+		numBarcodes=a[6];
+		barcodeDelimiter=a[7];
 		mode=mode_;
 		input=input_;
+//		assert(!allowFileRead || barcodeDelimiter>=0) : barcodeDelimiter;
 		
 		overwrite=overwrite_;
 		append=append_;
@@ -288,12 +293,23 @@ public final class FileFormat {
 	}
 	
 	public static String toString(int[] vector){
+		/* {format, compression, type, interleaved, 
+		 * quality, length, numBarcodes, barcodeDelimiter} */
+		
 		int format=vector[0], compression=vector[1], type=vector[2], interleaving=vector[3];
+		int quality=vector[4], length=vector[5], codes=vector[6], delimiter=vector[7];
 		StringBuilder sb=new StringBuilder();
 		sb.append(format+"("+FORMAT_ARRAY[format]+")").append(',');
 		sb.append(compression+"("+COMPRESSION_ARRAY[compression]+")").append(',');
 		sb.append(type+"("+TYPE_ARRAY[type]+")").append(',');
-		sb.append(interleaving+"("+INTERLEAVING_ARRAY[interleaving]+")");
+		sb.append(interleaving+"("+INTERLEAVING_ARRAY[interleaving]+")").append(',');
+
+		sb.append("ASCII-"+quality).append(',');
+		sb.append("length "+length).append(',');
+		sb.append("barcodes "+codes).append(',');
+		sb.append("delimiter "+(delimiter>0 ? Character.toString(delimiter) : Integer.toString(delimiter)));
+		
+		
 		return sb.toString();
 	}
 	
@@ -302,10 +318,11 @@ public final class FileFormat {
 	/*----------------        Static Methods        ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	/** Returns an int array: {format, compression, type, interleaved, quality, length} */
+	/** Returns an int array: {format, compression, type, interleaved, 
+	 * quality, length, numBarcodes, barcodeDelimiter} */
 	public static final int[] testFormat(String fname, boolean allowFileRead, boolean forceFileRead){
 		if(verbose){System.err.println("testFormat("+fname+", "+allowFileRead+", "+forceFileRead+")");}
-		final int[] r=new int[] {UNKNOWN, RAW, FILE, UNKNOWN, -1, -1};
+		final int[] r=new int[] {UNKNOWN, RAW, FILE, UNKNOWN, -1, -1, -1, -1};
 		if(fname==null || fname.length()<1){
 			r[2]=STDIO;
 			return r;
@@ -343,6 +360,7 @@ public final class FileFormat {
 		else if(ext.equals("gbk")){r[0]=GBK;}
 		else if(ext.equals("gbff")){r[0]=GBFF;}
 		else if(ext.equals("alm")){r[0]=ALM;}
+		else if(ext.equals("bbnet")){r[0]=BBNET;}
 		
 		if(comp!=null){
 			r[1]=Tools.find(comp, COMPRESSION_ARRAY);
@@ -359,8 +377,14 @@ public final class FileFormat {
 		}else if("/dev/null".equalsIgnoreCase(slc)){
 			r[2]=DEVNULL;
 		}
-		
-		if(verbose){System.err.println("Before reading: \t"+r[0]+", "+toString(r)+", "+forceFileRead+", "+(r[0]!=BAM));}
+
+		if(verbose){System.err.println("Before reading: \t"+r[0]+", "+toString(r)+
+				", "+forceFileRead+", "+(r[0]!=BAM));
+			System.err.println((r[0]==UNKNOWN)+","+(r[0]!=BAM && forceFileRead)+","+ 
+				(r[0]==FASTQ || r[0]==FASTA)+","+(r[3]==UNKNOWN)+","+allowFileRead+","
+					+(!stream.FASTQ.FORCE_INTERLEAVED)
+				+","+stream.FASTQ.TEST_INTERLEAVED);//false,false,true,true,true,true,false
+		}
 		if(r[0]==UNKNOWN || (r[0]!=BAM && forceFileRead) || 
 				((r[0]==FASTQ || r[0]==FASTA) && r[3]==UNKNOWN && allowFileRead && !stream.FASTQ.FORCE_INTERLEAVED && stream.FASTQ.TEST_INTERLEAVED)){
 			File f=(allowFileRead && r[2]==FILE ? new File(fname) : null);
@@ -370,11 +394,13 @@ public final class FileFormat {
 				try {
 					int[] a=testInterleavedAndQuality(fname, false);
 					if(a!=null){
-						final int aq=a[0], ai=a[1], al=a[2], af=a[3];
+						final int aq=a[0], ai=a[1], al=a[2], af=a[3], abc=a[4], abd=a[5];
 						if(aq>-1){r[4]=aq;}
 						if(ai!=UNKNOWN){r[3]=ai;}
 						if(af!=UNKNOWN && (af!=BREAD || (r[0]!=HEADER && r[0]!=TEXT))){r[0]=af;}
 						if(al>1 && r[5]==-1){r[5]=al;}
+						r[6]=abc;
+						r[7]=abd;
 					}
 				} catch (Exception e) {
 					// TODO Auto-generated catch block
@@ -429,7 +455,7 @@ public final class FileFormat {
 	
 	/**
 	 * @param fname File to read
-	 * @return {quality, interleaved, length, format}
+	 * @return {quality, interleaved, length, format, numBarcodes, barcodeDelimiter}
 	 */
 	public static int[] testInterleavedAndQuality(String fname, boolean forceFastq){
 		final ArrayList<String> oct=getFirstOctet(fname);
@@ -463,13 +489,14 @@ public final class FileFormat {
 	/**
 	 * @param oct First 8 lines of file
 	 * @param fname File to read
-	 * @return {quality, interleaved, length, format}
+	 * @return {quality, interleaved, length, format, numBarcodes, barcodeDelimiter}
 	 */
 	public static int[] testInterleavedAndQuality(final ArrayList<String> oct, String fname, boolean forceFastq){
 		int len=-1, format=UNKNOWN;
 		byte q=-1, i=UNKNOWN;
+		int numBarcodes=0, barcodeDelimiter=0;
 		if(oct==null || oct.size()<1){
-			return new int[] {q, i, len, format};
+			return new int[] {q, i, len, format, numBarcodes, barcodeDelimiter};
 		}
 		{
 			String s1=oct.size()>0 ? oct.get(0) : "";
@@ -522,21 +549,59 @@ public final class FileFormat {
 			i=(byte)(stream.FASTQ.testInterleaved(oct, fname, false) ? INTERLEAVED : SINGLE);
 			//		stream.FASTQ.DETECT_QUALITY=old;
 			{
+				String h=oct.size()>0 ? oct.get(0) : null;
 				String a=oct.size()>1 ? oct.get(1) : null;
 				String b=oct.size()>5 ? oct.get(5) : null;
 				if(a!=null){len=Tools.max(a.length(), len);}
 				if(b!=null){len=Tools.max(b.length(), len);}
 				if(len<2){len=-1;}
+				if(h!=null){
+					String barcode=Read.headerToBarcode(h, false);
+					if(barcode!=null && barcode.length()>2){
+						barcodeDelimiter=barcodeDelimiter(barcode);
+						numBarcodes=(countLetters(barcode))>0 ? (barcodeDelimiter>0 ? 2 : 1) : 0;
+					}
+				}
 			}
 			stream.FASTQ.DETECT_QUALITY=oldDQ;
 			stream.FASTQ.ASCII_OFFSET=oldQin;
 			stream.FASTQ.ASCII_OFFSET_OUT=oldQout;
 		}
-		int[] r=new int[] {q, i, len, format};
+		int[] r=new int[] {q, i, len, format, numBarcodes, barcodeDelimiter};
 		if(verbose){System.err.println(Arrays.toString(r));}
 		return r;
 	}
 	
+	public static byte barcodeDelimiter(String barcode){
+		if(barcode==null || barcode.length()<3) {return 0;}
+		int letters=0, nonletters=0;
+		byte delimiter=0;
+		for(int i=0; i<barcode.length(); i++){
+			char c=barcode.charAt(i);
+			if(Tools.isLetter(c)){
+				letters++;
+			}else{
+				if(nonletters==0) {delimiter=(byte)c;}
+				nonletters++;
+			}
+		}
+		if(nonletters==1 && letters>1){
+			return delimiter;
+		}
+		return 0;//No delimiter or multiple delimiters
+	}
+	
+	private static int countLetters(String s){
+		int letters=0;
+		for(int i=0; s!=null && i<s.length(); i++){
+			char c=s.charAt(i);
+			if(Tools.isLetter(c)){
+				letters++;
+			}
+		}
+		return letters;
+	}
+	
 	public static boolean isFasta(String ext){
 		if(ext==null){return false;}
 		return (ext.equals("fa") || ext.equals("fasta") || ext.equals("fas") || ext.equals("fna") || ext.equals("ffn")
@@ -610,6 +675,9 @@ public final class FileFormat {
 		File f=new File(name);
 		if(f.exists()){f.delete();}
 	}
+
+	public int barcodeDelimiter() {return barcodeDelimiter;}
+	public int barcodesPerRead() {return numBarcodes;}
 	
 	/*--------------------------------------------------------------*/
 	/*----------------            Getters           ----------------*/
@@ -780,6 +848,8 @@ public final class FileFormat {
 	private final int length;
 	private final boolean input;
 	private final boolean amino;
+	private final int numBarcodes;
+	private final int barcodeDelimiter;
 
 	private final boolean overwrite;
 	private final boolean append;
@@ -837,13 +907,14 @@ public final class FileFormat {
 	public static final int GBFF=29;//TODO: this may be the same as GBK...
 	//Alignment Model, from Consensus package
 	public static final int ALM=30;
+	public static final int BBNET=31;
 	
 	public static final String[] FORMAT_ARRAY=new String[] {
 		"unknown", "fasta", "fastq", "bread", "sam", "csfasta",
 		"qual", "sequential", "random", "sites", "attachment",
 		"bam", "scarf", "text", "phylip", "header", "int1d",
 		"long1d", "bitset", "sketch", "oneline", "fastr",
-		"vcf", "var", "gff", "bed", "pgm", "embl", "gbk", "gbff", "alm"
+		"vcf", "var", "gff", "bed", "pgm", "embl", "gbk", "gbff", "alm", "bbnet"
 	};
 	
 	public static final String[] EXTENSION_LIST=new String[] {
@@ -853,7 +924,7 @@ public final class FileFormat {
 		"scarf", "phylip", "txt",
 		"gz", "gzip", "bz2", "zip", "xz", "dsrc", "header", "headers",
 		"int1d", "long1d", "bitset", "sketch", "oneline", "flat", "fqz",
-		"gff", "gff3", "var", "vcf", "bed", "pgm", "embl", "gbk", "gbff", "alm"
+		"gff", "gff3", "var", "vcf", "bed", "pgm", "embl", "gbk", "gbff", "alm", "bbnet"
 	};
 	
 	/* Compression */
