@@ -6,9 +6,9 @@ import java.util.Locale;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
+import tracker.ReadStats;
 
 public class Calc {
 	
