@@ -18,7 +18,6 @@ import prok.ProkObject;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -31,6 +30,7 @@ import tax.TaxClient;
 import tax.TaxTree;
 import template.Accumulator;
 import template.ThreadWaiter;
+import tracker.ReadStats;
 
 public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 	
@@ -43,16 +43,17 @@ public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 	 * @param args Command line arguments
 	 */
 	public static void main(String[] args){
+		
 		//Start a timer immediately upon code entrance.
 		Timer t=new Timer();
 		
-		//Create an instance of this class
+		//Create an instance of this class.
 		CutGff x=new CutGff(args);
 		
-		//Run the object
+		//Run the object.
 		x.process(t);
 		
-		//Close the print stream if it was redirected
+		//Close the print stream if it was redirected.
 		Shared.closeStream(x.outstream);
 	}
 	
