@@ -437,9 +437,9 @@ public class AnalyzeFlowCell {
 			
 			if(ffout1!=null || ffoutbad!=null){
 
-				String rpstring=Tools.padKM(readsDiscarded, 8);
-				String bpstring=Tools.padKM(basesDiscarded, 8);
-				String gpstring=Tools.padKM(gsTransformedToN, 8);
+				String rpstring=Tools.padKMB(readsDiscarded, 8);
+				String bpstring=Tools.padKMB(basesDiscarded, 8);
+				String gpstring=Tools.padKMB(gsTransformedToN, 8);
 				outstream.println();
 				outstream.println("Reads Discarded:    "+rpstring+" \t"+String.format(Locale.ROOT, "%.3f%%", readsDiscarded*100.0/readsProcessed));
 				outstream.println("Bases Discarded:    "+bpstring+" \t"+String.format(Locale.ROOT, "%.3f%%", basesDiscarded*100.0/basesProcessed));
