@@ -18,7 +18,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -29,9 +28,10 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import stream.SamLine;
 import structures.ByteBuilder;
-import structures.EntropyTracker;
 import structures.IntHashSet;
 import structures.IntList;
+import tracker.EntropyTracker;
+import tracker.ReadStats;
 
 /**
  * Version of Reformat designed for PacBio data.
@@ -465,7 +465,7 @@ public final class ReformatPacBio {
 		final ByteStreamWriter bsw=new ByteStreamWriter(ff);
 		bsw.start();
 
-		bsw.print("#Counted\t").println(Tools.sum(hist));
+		bsw.print("#Counted\t").println(shared.Vector.sum(hist));
 		bsw.print("#Mean\t").println(Tools.averageHistogram(hist), 3);
 		bsw.print("#Median\t").println(Tools.medianHistogram(hist));
 		bsw.print("#Mode\t").println(Tools.calcModeHistogram(hist));
