@@ -13,7 +13,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -24,6 +23,7 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ByteBuilder;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * This class does nothing.
