@@ -834,8 +834,8 @@ public final class AssemblyStats2 {
 			outstream.println("Can't write gc histogram because file exists and overwrite="+overwrite);
 			assert(false);
 		}else{
-			long gchistFilesum=Tools.sum(gchistArray_downsampled);
-			long gchistFilesumbb=Tools.sum(gchist_by_base_downsampled);
+			long gchistFilesum=shared.Vector.sum(gchistArray_downsampled);
+			long gchistFilesumbb=shared.Vector.sum(gchist_by_base_downsampled);
 			double invsum=(gchistFilesum==0 ? 0 : 1.0/gchistFilesum);
 			double invsumbb=(gchistFilesum==0 ? 0 : 1.0/gchistFilesumbb);
 			double invbins=1.0/(gcbins==0 ? 1 : gcbins);
@@ -1426,12 +1426,12 @@ public final class AssemblyStats2 {
 			if(printheadersize){sb.append("Header:\t"+formatKB(HEADERLENSUM, 3, 0)+(HEADERLENSUM<1000 ? " bytes" : ""));}
 			
 			//		System.out.println();
-			//		System.out.println("Scaffolds: "+Tools.sum(slist.array));
+			//		System.out.println("Scaffolds: "+shared.Vector.sum(slist.array));
 			//		for(int i=0; i<slist.size; i++){
 			//			if(slist.array[i]>0){System.out.print(i+":"+slist.array[i]+", ");}
 			//		}
 			//		System.out.println();
-			//		System.out.println("Contigs:"+Tools.sum(clist.array));
+			//		System.out.println("Contigs:"+shared.Vector.sum(clist.array));
 			//		for(int i=0; i<clist.size; i++){
 			//			if(clist.array[i]>0){System.out.print(i+":"+clist.array[i]+", ");}
 			//		}
@@ -1738,7 +1738,7 @@ public final class AssemblyStats2 {
 			long bytes=new File(in).length();
 			if(bytes<1){bytes=LIMSUM;}
 			double mbps=bytes*1000d/t.elapsed;
-			double mbpps=Tools.sum(counts)*1000d/t.elapsed;
+			double mbpps=shared.Vector.sum(counts)*1000d/t.elapsed;
 			outstream.println(String.format(Locale.ROOT, "Speed:\t%.2f MBytes/s",mbps));
 			outstream.println(String.format(Locale.ROOT, "      \t%.2f MBases/s",mbpps));
 		}
