@@ -21,7 +21,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -35,9 +34,10 @@ import stream.SamLine;
 import structures.CoverageArray;
 import structures.CoverageArray2;
 import structures.CoverageArray3;
-import structures.EntropyTracker;
 import structures.IntList;
 import structures.ListNum;
+import tracker.EntropyTracker;
+import tracker.ReadStats;
 
 /**
  * Masks a fasta file by inserting 'N' in place of low-complexity short repeats,
@@ -934,7 +934,7 @@ public class BBMask{
 			}
 			
 			if(verify && i2>-1 && i<bases.length){
-				assert(Tools.sum(counts)==window);
+				assert(shared.Vector.sum(counts)==window);
 			}
 			
 			if(current<mincount && ns<1 && i2>=-1 && i<bases.length){
