@@ -11,6 +11,8 @@ import shared.KillSwitch;
 import shared.Shared;
 import shared.Tools;
 import stream.Read;
+import structures.ByteBuilder;
+import structures.FloatList;
 import ukmer.Kmer;
 
 /**
@@ -44,8 +46,10 @@ public final class BBMergeOverlapper {
 		final int x;
 		if(false && Shared.USE_JNI){//TODO: Disabled!
 			x=mateByOverlapJNI(a.bases, b.bases, a.quality, b.quality, aprob, bprob, rvector, minOverlap0, minOverlap, minInsert0, margin, maxMismatches0, maxMismatches, minq);
-		}else{
+		}else if(!TAG_CUSTOM){
 			x=mateByOverlapJava_unrolled(a, b, aprob, bprob, rvector, minOverlap0, minOverlap, minInsert0, margin, maxMismatches0, maxMismatches, minq);
+		}else{
+			x=mateByOverlapJava_unrolled_training(a, b, aprob, bprob, rvector, minOverlap0, minOverlap, minInsert0, margin, maxMismatches0+40, maxMismatches+40, minq);
 		}
 		return x;
 	}
@@ -63,6 +67,7 @@ public final class BBMergeOverlapper {
 //		}else{
 //			swapped=false;
 //		}
+//		assert(false) : useQuality+", "+a.quality;
 		
 		final int x;
 		if(false && Shared.USE_JNI/* && !useQuality*/){
@@ -84,6 +89,8 @@ public final class BBMergeOverlapper {
 //			a.reverseComplement();
 //			b.reverseComplement();
 //		}
+//		assert(x>-1) : x+", "+a.quality;
+//		System.err.println("returning x="+x);
 		return x;
 	}
 	
@@ -101,13 +108,18 @@ public final class BBMergeOverlapper {
 		final int minLength=Tools.min(alen, blen);
 		
 		assert(aqual!=null && bqual!=null);
-		{
+		{//Set the correctness probabilities from the quality scores.
 			for(int i=0; i<aqual.length; i++){aprob[i]=probCorrect3[aqual[i]];}
 			for(int i=0; i<bqual.length; i++){bprob[i]=probCorrect3[bqual[i]];}
 		}
 		
 		{
-			float x=findBestRatio_WithQualities(a, b, aprob, bprob, minOverlap0, minOverlap, minInsert, maxRatio, offset);
+			final float x;
+//			if(!BBMerge.TRAINING) {
+				x=findBestRatio_WithQualities(a, b, aprob, bprob, minOverlap0, minOverlap, minInsert, maxRatio, offset);
+//			}else{
+//				x=findBestRatio_WithQualitiesTraining(a, b, aprob, bprob, minOverlap0, minOverlap, minInsert, maxRatio, offset);
+//			}
 			if(!TAG_CUSTOM && x>maxRatio){
 				rvector[2]=minLength;
 				rvector[4]=0;
@@ -115,7 +127,7 @@ public final class BBMergeOverlapper {
 			}
 			maxRatio=Tools.min(maxRatio, x);
 		}
-
+		
 //		final float altBadlimit=Tools.max(maxRatio, 0.07f)*2f*alen+2;
 		final float margin2=(margin+offset)/minLength;
 
@@ -123,10 +135,12 @@ public final class BBMergeOverlapper {
 		int bestOverlap=-1;
 		int bestBadInt=-1;
 		float bestBad=minLength;
+		float bestGood=0;
 		float bestRatio=1;
 		boolean ambig=false;
-		
+
 		float secondBestBad=0;
+		float secondBestGood=0;
 		float secondBestRatio=1;
 		int secondBestInsert=0;
 		int secondBestOverlap=0;
@@ -148,9 +162,9 @@ public final class BBMergeOverlapper {
 			final int overlapLength=Tools.min(alen-istart, blen-jstart, insert);
 //			final float badlimit=extraMult*Tools.max(minSecondRatio, Tools.min(altBadlimit, (Tools.min(bestRatio, maxRatio)))*margin*overlapLength)+1f;
 //			final float badlimit=extraMult*Tools.max(minSecondRatio, Tools.min(bestRatio, maxRatio)*margin*overlapLength)+1f;
-			final float badlimit=extraMult*(Tools.min(bestRatio, maxRatio)*margin*overlapLength)+1f;
+			final float badlimit=extraMult*(Tools.min(bestRatio, maxRatio)*margin*overlapLength)+1f+extraBadlimit;
 //			final float badlimit=extraMult*Tools.max(minSecondRatio, Tools.min(bestRatio, maxRatio))*margin*overlapLength+1f;
-
+			
 			final int imax=istart+overlapLength;
 			for(int i=istart, j=jstart; i<imax && bad<=badlimit; i++, j++){
 				assert(i>=0 && i<alen && j>=0 && j<blen) : "\njstart="+jstart+", j="+j+
@@ -175,7 +189,7 @@ public final class BBMergeOverlapper {
 //			}
 
 			if(bad<=badlimit){
-				if(bad==0 && good>minOverlap0 && good<minOverlap){
+				if(!TAG_CUSTOM && bad==0 && good>minOverlap0 && good<minOverlap){
 					rvector[2]=bestBadInt;//=(int)(bestBad+0.95f);
 					rvector[4]=1;
 					return -1;
@@ -191,12 +205,14 @@ public final class BBMergeOverlapper {
 						secondBestInsert=bestInsert;
 						secondBestOverlap=bestOverlap;
 						secondBestBad=bestBad;
+						secondBestGood=bestGood;
 						secondBestRatio=bestRatio;
 						secondBestBadInt=bestBadInt;
 						
 						bestInsert=insert;
 						bestOverlap=overlapLength;
 						bestBad=bad;
+						bestGood=good;
 						bestRatio=ratio;
 						bestBadInt=badInt;
 					}
@@ -204,6 +220,7 @@ public final class BBMergeOverlapper {
 						secondBestInsert=insert;
 						secondBestOverlap=overlapLength;
 						secondBestBad=bad;
+						secondBestGood=good;
 						secondBestRatio=ratio;
 						secondBestBadInt=badInt;
 					}
@@ -217,28 +234,86 @@ public final class BBMergeOverlapper {
 			}
 		}
 		if(secondBestRatio<minSecondRatio){ambig=true;}
+		if(MAKE_VECTOR) {
+//			System.err.println("Read "+a.numericID+": "+a.obj+", "+b.obj);
+			FloatList fl=b.fetchVector();
+			assert(fl.size==3) : fl.size;
+			fl.add((a.length()-100)*0.01f);
+			fl.add((b.length()-100)*0.01f);
+			fl.add(bestInsert*.004f);
+			fl.add(bestOverlap/(bestOverlap+50f));
+			fl.add((bestBad+1f)/(bestBad+5f));
+			fl.add((bestGood+1f)/(bestGood+5f));
+			fl.add(bestRatio);
+			fl.add((bestBadInt+1f)/(bestBadInt+5f));
+
+			fl.add(secondBestInsert*.004f);
+			fl.add(secondBestOverlap/(secondBestOverlap+50f));
+			fl.add((secondBestBad+1f)/(secondBestBad+5f));
+			fl.add((secondBestGood+1f)/(secondBestGood+5f));
+			fl.add(secondBestRatio);
+			fl.add((secondBestBadInt)/(secondBestBadInt+5f));
+			
+			fl.add((secondBestRatio+1)/(bestRatio+1));
+			fl.add(secondBestBad/(bestBad+8));
+			fl.add(secondBestGood/(bestGood+8));
+			fl.add((bestOverlap+1f)/(secondBestOverlap+bestOverlap+1f));
+		}
 		
 		if(TAG_CUSTOM){
+			final ByteBuilder sb=a.fetchBB();
 			if(secondBestRatio<minSecondRatio){ambig=true;}
-			StringBuilder sb=new StringBuilder(a.id);
+////			StringBuilder sb=new StringBuilder(a.id);
+//
+//			sb.append("_alen=").append(a.length()*0.01f, 2);
+//			sb.append("_blen=").append(b.length()*0.01f, 2);
+//			sb.append("_bi=").append(bestInsert*.01f, 2);
+//			sb.append("_bo=").append(bestOverlap*0.1f, 1);
+//			sb.append("_bb=").append(String.format(Locale.ROOT, "%.4f", bestBad*.1f));
+//			sb.append("_bg=").append(String.format(Locale.ROOT, "%.4f", bestGood*.1f));
+//			sb.append("_br=").append(String.format(Locale.ROOT, "%.4f", bestRatio));
+//			sb.append("_bbi=").append(bestBadInt*.1f, 1);
+//
+//			sb.append("_sbi=").append(secondBestInsert*.01f, 2);
+//			sb.append("_sbo=").append(secondBestOverlap*0.1f, 1);
+//			sb.append("_sbb=").append(String.format(Locale.ROOT, "%.4f", secondBestBad*.1f));
+//			sb.append("_sbg=").append(String.format(Locale.ROOT, "%.4f", secondBestGood*.1f));
+//			sb.append("_sbr=").append(String.format(Locale.ROOT, "%.4f", secondBestRatio));
+//			sb.append("_sbbi=").append(secondBestBadInt*.1f, 1);
+//			sb.append("_rr=").append(secondBestRatio/bestRatio, 4);
+//			sb.append("_badr=").append(secondBestBad/bestBad, 4);
+//			sb.append("_goodr=").append(secondBestGood/bestGood, 4);
 			
-			sb.append("_bi=").append(bestInsert);
-			sb.append("_bo=").append(bestOverlap);
-			sb.append("_bb=").append(String.format(Locale.ROOT, "%.4f", bestBad));
-			sb.append("_br=").append(String.format(Locale.ROOT, "%.4f", bestRatio));
-			sb.append("_bbi=").append(bestBadInt);
+			float lenSum=a.length()+b.length();
 
-			sb.append("_sbi=").append(secondBestInsert);
-			sb.append("_sbo=").append(secondBestOverlap);
-			sb.append("_sbb=").append(String.format(Locale.ROOT, "%.4f", secondBestBad));
-			sb.append("_sbr=").append(String.format(Locale.ROOT, "%.4f", secondBestRatio));
-			sb.append("_sbbi=").append(secondBestBadInt);
+			assert(sb.length()<40) : sb;
+			sb.append((a.length()-100)*0.01f, 2).tab();
+			sb.append((b.length()-100)*0.01f, 2).tab();
+			sb.append(bestInsert*.004f, 3).tab();
+			sb.append(bestOverlap/(bestOverlap+50f), 3).tab();
+			sb.append((bestBad+1f)/(bestBad+5f), 5).tab();
+			sb.append((bestGood+1f)/(bestGood+5f), 5).tab();
+			sb.append(bestRatio, 4).tab();
+			sb.append((bestBadInt+1f)/(bestBadInt+5f), 5).tab();
+
+			sb.append(secondBestInsert*.004f, 3).tab();
+			sb.append(secondBestOverlap/(secondBestOverlap+50f), 3).tab();
+			sb.append((secondBestBad+1f)/(secondBestBad+5f), 5).tab();
+			sb.append((secondBestGood+1f)/(secondBestGood+5f), 5).tab();
+			sb.append(secondBestRatio, 4).tab();
+			sb.append((secondBestBadInt)/(secondBestBadInt+5f), 5).tab();
 			
-			a.id=sb.toString();
+			sb.append((secondBestRatio+1)/(bestRatio+1), 3).tab();
+			sb.append(secondBestBad/(bestBad+8), 5).tab();
+			sb.append(secondBestGood/(bestGood+8), 5).tab();
+			sb.append((bestOverlap+1f)/(secondBestOverlap+bestOverlap+1f), 5).tab();
+			
+//			a.id=sb.toString();
 			
 			rvector[2]=bestBadInt;//=(int)(bestBad+0.95f);
 			rvector[4]=(ambig ? 1 : 0);
 			
+			a.mapScore=bestInsert;//TODO: For testing
 			return (bestInsert<0 ? -1 : bestInsert);
 		}
 		
@@ -264,13 +339,13 @@ public final class BBMergeOverlapper {
 		final byte[] abases=a.bases, bbases=b.bases;
 		final int alen=abases.length, blen=bbases.length;
 		final int minLength=Tools.min(alen, blen);
-		
+		if(MAKE_VECTOR || TAG_CUSTOM){maxRatio=.7f;}
 		{
 			float x=findBestRatio(a, b, minOverlap0, minOverlap, minInsert, maxRatio, offset, gIncr, bIncr);
 			if(verbose){
 				System.err.println(x+", "+maxRatio+", "+Arrays.toString(rvector));
 			}
-			if(x>maxRatio){
+			if(!TAG_CUSTOM && x>maxRatio){
 				rvector[2]=minLength;
 				rvector[4]=0;
 				return -1;
@@ -286,16 +361,18 @@ public final class BBMergeOverlapper {
 		int bestOverlap=-1;
 		int bestBadInt=-1;
 		float bestBad=minLength;
+		float bestGood=0;
 		float bestRatio=1;
 		boolean ambig=false;
-		
+
 		float secondBestBad=0;
+		float secondBestGood=0;
 		float secondBestRatio=1;
 		int secondBestInsert=0;
 		int secondBestOverlap=0;
 		int secondBestBadInt=-1;
 		
-		final float extraMult=(TAG_CUSTOM ? 80 : 1.2f);
+		final float extraMult=(TAG_CUSTOM || MAKE_VECTOR ? 4f : 1.2f);
 		
 		final int largestInsertToTest=(alen+blen-minOverlap0);
 		final int smallestInsertToTest=minInsert0;
@@ -307,7 +384,7 @@ public final class BBMergeOverlapper {
 			final int overlapLength=Tools.min(alen-istart, blen-jstart, insert);
 			
 //			final float badlimit=Tools.min(altBadlimit, Tools.min(bestRatio, maxRatio)*margin*overlapLength);
-			final float badlimit=extraMult*(Tools.min(bestRatio, maxRatio)*margin*overlapLength)+1f;
+			final float badlimit=extraMult*(Tools.min(bestRatio, maxRatio)*margin*overlapLength)+1f+extraBadlimit;
 			float good=0, bad=0;
 			int badInt=0;
 
@@ -332,9 +409,9 @@ public final class BBMergeOverlapper {
 //				System.err.println("bestGood="+bestGood+", bestBad="+bestBad);
 //				System.err.println();
 //			}
-
+			
 			if(bad<=badlimit){
-				if(bad==0 && good>minOverlap0 && good<minOverlap){
+				if(!TAG_CUSTOM && bad==0 && good>minOverlap0 && good<minOverlap){
 					rvector[2]=bestBadInt;//=(int)(bestBad+0.95f);
 					rvector[4]=1;
 					return -1;
@@ -390,23 +467,63 @@ public final class BBMergeOverlapper {
 			System.err.println("minSecondRatio="+minSecondRatio+", secondBestRatio="+secondBestRatio+", margin="+margin+", bestRatio="+bestRatio+", bestBad="+bestBad);
 		}
 		
+
+		if(MAKE_VECTOR) {
+//			System.err.println("Read "+a.numericID+": "+a.obj+", "+b.obj);
+			FloatList fl=b.fetchVector();
+			if(fl.size==3) {
+				fl.add((a.length()-100)*0.01f); //alen
+				fl.add((b.length()-100)*0.01f);
+				fl.add(bestInsert*.004f);
+				fl.add(bestOverlap/(bestOverlap+50f));
+				fl.add((bestBad+1f)/(bestBad+5f));
+				fl.add((bestGood+1f)/(bestGood+5f));
+				fl.add(bestRatio);
+				fl.add((bestBadInt+1f)/(bestBadInt+5f));
+
+				fl.add(secondBestInsert*.004f);
+				fl.add(secondBestOverlap/(secondBestOverlap+50f));
+				fl.add((secondBestBad+1f)/(secondBestBad+5f));
+				fl.add((secondBestGood+1f)/(secondBestGood+5f));
+				fl.add(secondBestRatio);
+				fl.add((secondBestBadInt)/(secondBestBadInt+5f));
+
+				fl.add((secondBestRatio+1)/(bestRatio+1));
+				fl.add(secondBestBad/(bestBad+8));
+				fl.add(secondBestGood/(bestGood+8));
+				fl.add((bestOverlap+1f)/(secondBestOverlap+bestOverlap+1f));
+			}
+		}
+		
 		if(TAG_CUSTOM){
+			final ByteBuilder sb=(ByteBuilder) a.fetchBB();
 			if(secondBestRatio<minSecondRatio){ambig=true;}
-			StringBuilder sb=new StringBuilder(a.id);
 
-			sb.append("_bi=").append(bestInsert);
-			sb.append("_bo=").append(bestOverlap);
-			sb.append("_bb=").append(String.format(Locale.ROOT, "%.4f", bestBad));
-			sb.append("_br=").append(String.format(Locale.ROOT, "%.4f", bestRatio));
-			sb.append("_bbi=").append(bestBadInt);
+//			assert(sb.length()<40) : sb;
+			if(sb.length()<40) {
+				sb.append((a.length()-100)*0.01f, 2).tab();
+				sb.append((b.length()-100)*0.01f, 2).tab();
+				sb.append(bestInsert*.004f, 3).tab();
+				sb.append(bestOverlap/(bestOverlap+50f), 3).tab();
+				sb.append((bestBad+1f)/(bestBad+5f), 5).tab();
+				sb.append((bestGood+1f)/(bestGood+5f), 5).tab();
+				sb.append(bestRatio, 4).tab();
+				sb.append((bestBadInt+1f)/(bestBadInt+5f), 5).tab();
 
-			sb.append("_sbi=").append(secondBestInsert);
-			sb.append("_sbo=").append(secondBestOverlap);
-			sb.append("_sbb=").append(String.format(Locale.ROOT, "%.4f", secondBestBad));
-			sb.append("_sbr=").append(String.format(Locale.ROOT, "%.4f", secondBestRatio));
-			sb.append("_sbbi=").append(secondBestBadInt);
+				sb.append(secondBestInsert*.004f, 3).tab();
+				sb.append(secondBestOverlap/(secondBestOverlap+50f), 3).tab();
+				sb.append((secondBestBad+1f)/(secondBestBad+5f), 5).tab();
+				sb.append((secondBestGood+1f)/(secondBestGood+5f), 5).tab();
+				sb.append(secondBestRatio, 4).tab();
+				sb.append((secondBestBadInt)/(secondBestBadInt+5f), 5).tab();
+				
+				sb.append((secondBestRatio+1)/(bestRatio+1), 3).tab();
+				sb.append(secondBestBad/(bestBad+8), 5).tab();
+				sb.append(secondBestGood/(bestGood+8), 5).tab();
+				sb.append((bestOverlap+1f)/(secondBestOverlap+bestOverlap+1f), 5).tab();
+			}
 			
-			a.id=sb.toString();
+//			a.id=sb.toString();
 			
 			rvector[2]=bestBadInt;//=(int)(bestBad+0.95f);
 			rvector[4]=(ambig ? 1 : 0);
@@ -445,7 +562,7 @@ public final class BBMergeOverlapper {
 			final int overlapLength=Tools.min(alen-istart, blen-jstart, insert);
 
 //			final float badlimit=(Tools.min(altBadlimit, bestRatio*overlapLength));
-			final float badlimit=bestRatio*overlapLength;
+			final float badlimit=bestRatio*overlapLength+extraBadlimit;
 			float good=0, bad=0;
 			
 			final int imax=istart+overlapLength;
@@ -478,6 +595,64 @@ public final class BBMergeOverlapper {
 		return bestRatio;
 	}
 	
+	protected static final float findBestRatio_WithQualitiesTraining(Read a, Read b, final float[] aprob, final float[] bprob,
+			final int minOverlap0, final int minOverlap, final int minInsert, final float maxRatio, final float offset) {
+		final byte[] abases=a.bases, bbases=b.bases;
+		final int alen=abases.length, blen=bbases.length;
+		
+		float bestRatio=maxRatio+0.0001f;
+		float bestRatio2=maxRatio+0.0001f;
+		float bestRatio3=maxRatio+0.0001f;
+//		final float altBadlimit=Tools.max(maxRatio, 0.07f)*2f*alen+1;
+		final float halfmax=maxRatio*0.5f;
+		
+		int maxbad=99999;
+		int maxbad2=99999;
+		
+		ByteBuilder bb=new ByteBuilder();//TODO, need expected length
+		
+		final int largestInsertToTest=(alen+blen-minOverlap); //TODO: test speed with minOverlap0
+		final int smallestInsertToTest=minInsert;
+		for(int insert=largestInsertToTest; insert>=smallestInsertToTest; insert--){
+			if(verbose){System.err.println("a\nTesting read "+a.numericID+", overlap "+insert+", insert "+(alen+blen-insert));}
+			
+			final int istart=(insert<=blen ? 0 : insert-blen);
+			final int jstart=(insert>=blen ? 0 : blen-insert);
+			final int overlapLength=Tools.min(alen-istart, blen-jstart, insert);
+
+//			final float badlimit=bestRatio*overlapLength*1.5f;//Made it a little bigger
+			final float badlimit=bestRatio3*overlapLength+extraBadlimit;
+			float good=0, bad=0;
+			
+			final int imax=istart+overlapLength;
+			for(int i=istart, j=jstart; i<imax && bad<=badlimit; i++, j++){
+				assert(i>=0 && i<alen && j>=0 && j<blen) : "\njstart="+jstart+", j="+j+
+				", istart="+istart+", i="+i+" \n"+"insert="+insert+", overlap="+overlapLength+", a.length="+a.length()+
+				", b.length="+b.length()+", bad="+bad+", badlimit="+badlimit+", good="+good;
+				final byte ca=abases[i], cb=bbases[j];
+				
+				final float x=aprob[i]*bprob[j];
+
+				if(ca==cb){good+=x;}
+				else{bad+=x;}
+			}
+			
+			float ratio=(bad+offset)/overlapLength;
+
+			if(ratio<bestRatio){
+				bestRatio3=bestRatio2;
+				bestRatio2=bestRatio;
+				bestRatio=ratio;
+			}
+		}
+		
+//		bb.append(alen).tab().append(blen).tab().append(maxRatio, 5).tab().append(maxbad).tab().append(bestRatio, 5);
+//		bb.tab().append(bestRatio2, 5).tab().append(bestRatio3, 5)
+		
+		assert(false) : bb.length();
+		return bestRatio;
+	}
+	
 	protected static final float findBestRatio(Read a, Read b,
 			final int minOverlap0, final int minOverlap, final int minInsert, final float maxRatio, final float offset, final float gIncr, final float bIncr) {
 		final byte[] abases=a.bases, bbases=b.bases;
@@ -499,7 +674,7 @@ public final class BBMergeOverlapper {
 			final int overlapLength=Tools.min(alen-istart, blen-jstart, insert);
 
 //			final float badlimit=(Tools.min(altBadlimit, bestRatio*overlapLength));
-			final float badlimit=bestRatio*overlapLength;
+			final float badlimit=bestRatio*overlapLength+extraBadlimit;
 			float good=0, bad=0;
 			
 			final int imax=istart+overlapLength;
@@ -572,7 +747,7 @@ public final class BBMergeOverlapper {
 			{
 				final int iters=Tools.min(overlap-istart, blen-istart, alen-jstart);
 				final int imax=istart+iters;
-				final int badlim=bestBad+margin;
+				final int badlim=bestBad+margin+extraBadlimit;
 
 				for(int i=istart, j=jstart; i<imax && bad<=badlim; i++, j++){
 					assert(j>=0 && j<=alen && i>=0 && i<=blen) : "\njstart="+jstart+", j="+j+
@@ -647,6 +822,123 @@ public final class BBMergeOverlapper {
 		return (bestOverlap<0 ? -1 : alen+blen-bestOverlap);
 	}
 	
+	protected static final int mateByOverlapJava_unrolled_training(Read a, Read b, float[] aprob, float[] bprob, int[] rvector,
+			int minOverlap0, final int minOverlap, final int minInsert0, int margin, final int maxMismatches0, final int maxMismatches, final int minq) {
+		assert(rvector!=null);
+		minOverlap0=Tools.min(Tools.max(1, minOverlap0), minOverlap);
+		assert(maxMismatches<=maxMismatches0);
+		margin=Tools.max(margin, 0);
+		assert(maxMismatches>=margin);
+		
+		final byte[] abases=a.bases, bbases=b.bases;
+		final byte[] aqual=a.quality, bqual=b.quality;
+		final int alen=abases.length, blen=bbases.length;
+		
+		int bestOverlap=-1;
+		int bestGood=-1;
+		int bestBad=maxMismatches0;
+		
+		boolean ambig=false;
+		final int maxOverlap=alen+blen-Tools.max(minOverlap, minInsert0);
+//		assert(false) : minOverlap+", "+maxOverlap;
+		assert(TAG_CUSTOM);
+		
+		if(aqual!=null && bqual!=null){
+			for(int i=0; i<aqual.length; i++){aprob[i]=probCorrect3[aqual[i]];}
+			for(int i=0; i<bqual.length; i++){bprob[i]=probCorrect3[bqual[i]];}
+		}else{
+			for(int i=0; i<alen; i++){aprob[i]=0.98f;}
+			for(int i=0; i<blen; i++){bprob[i]=0.98f;}
+		}
+		
+		final float minprob=probCorrect3[Tools.mid(1, minq, 41)];
+
+		for(int overlap=Tools.max(minOverlap0, 0); overlap<maxOverlap; overlap++){
+			if(verbose){System.err.println("c\nTesting read "+a.numericID+", overlap "+overlap+", insert "+(alen+blen-overlap));}
+
+			int good=0, bad=0;
+
+			int istart=(overlap<=alen ? 0 : overlap-alen);
+			int jstart=(overlap<=alen ? alen-overlap : 0);
+
+			{
+				final int iters=Tools.min(overlap-istart, blen-istart, alen-jstart);
+				final int imax=istart+iters;
+				final int badlim=bestBad+margin+extraBadlimit;
+
+				for(int i=istart, j=jstart; i<imax && bad<=badlim; i++, j++){
+					assert(j>=0 && j<=alen && i>=0 && i<=blen) : "\njstart="+jstart+", j="+j+
+					", istart="+istart+", i="+i+" \n"+"overlap="+overlap+", a.length="+alen+
+					", b.length="+blen+", bad="+bad+", badlim="+badlim+", good="+good;
+					final byte ca1=abases[j], cb1=bbases[i];
+					final float pc=aprob[j]*bprob[i];
+					
+					if(pc<=minprob){//do nothing
+					}else if(ca1==cb1){good++;}
+					else{bad++;}
+				}
+
+				if(verbose){
+					final int overlapLen=(imax-istart);
+					System.err.println("overlapLen="+overlapLen+"; coordinates ("+jstart+"-"+(jstart+overlapLen)+"), ("+istart+"-"+imax+")");
+					System.err.println(new String(abases, jstart, overlapLen));
+					System.err.println(new String(bbases, istart, overlapLen));
+				}
+
+				if(verbose){System.err.println("overlap="+overlap+", bad="+bad+", good="+good+", badlim="+badlim+", bestOverlap="+
+						bestOverlap+", bestGood="+bestGood+", bestBad="+bestBad+", ambig="+ambig+", mino="+minOverlap+", mino0="+minOverlap0+
+						", margin="+margin+", maxMismatches="+maxMismatches);}
+			}
+
+			if(bad*0.0f<good){
+				if(verbose){System.err.print("a");}
+				if(good>minOverlap){//Candidate
+					if(verbose){System.err.print("b");}
+					if(bad<=bestBad){
+
+						if(verbose){System.err.print("c");}
+						if(bad<bestBad || (bad==bestBad && good>bestGood)){//Current winner
+							if(verbose){System.err.print("d");}
+							if(bestBad-bad<margin){ambig=true;}
+							bestOverlap=overlap;
+							bestBad=bad;
+							bestGood=good;
+						}else if(bad==bestBad){
+							if(verbose){System.err.print("e");}
+							ambig=true;
+						}
+
+						if(ambig && bestBad<margin){
+							if(verbose){System.err.print("f");}
+							rvector[2]=bestBad;
+							rvector[4]=(ambig ? 1 : 0);
+							return -1;
+						}
+					}
+				}else if(bad<margin){
+					if(verbose){System.err.print("g");}
+					ambig=true;
+					rvector[2]=bestBad;
+					rvector[4]=(ambig ? 1 : 0);
+					return -1;
+				}else{
+					if(verbose){System.err.print("h");}
+				}
+			}
+		}
+		
+		if(!ambig && bestBad>maxMismatches-margin){bestOverlap=-1;}
+		
+		rvector[2]=bestBad;
+		rvector[4]=(ambig ? 1 : 0);
+		
+		if(verbose){System.err.println("bestOverlap="+
+				bestOverlap+", bestGood="+bestGood+", bestBad="+bestBad+", ambig="+ambig+", mino="+minOverlap+", mino0="+minOverlap0+
+				", margin="+margin+", maxMismatches="+maxMismatches);}
+		
+		return (bestOverlap<0 ? -1 : alen+blen-bestOverlap);
+	}
+	
 	
 	/**
 	 * TODO Use this
@@ -929,8 +1221,11 @@ public final class BBMergeOverlapper {
 	private static final int BAD_MULT=6;
 	private static final int GOOD_MULT_1=8;
 	private static final int GOOD_MULT_2=400;
-	
-	private static final boolean TAG_CUSTOM=BBMerge.TAG_CUSTOM;
+
+	private static boolean TAG_CUSTOM=BBMerge.TAG_CUSTOM;
+	static boolean MAKE_VECTOR=BBMerge.MAKE_VECTOR;
+
+	private static int extraBadlimit=20;//(TAG_CUSTOM ? 40 : 20);//0 is fine when not using nets
 	
 	protected static final boolean verbose=false;
 	
