@@ -15,12 +15,12 @@ import fileIO.TextFile;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
 import structures.ByteBuilder;
 import structures.LongList;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
@@ -137,7 +137,7 @@ public class CallPeaks {
 		LongList hist=lists[0];
 		LongList gchist=lists[1];
 		ArrayList<Peak> peaks=callPeaks(hist, gchist);
-		long sum=Tools.sum(hist.array);
+		long sum=shared.Vector.sum(hist.array);
 		printPeaks(peaks, k, sum, hist.array, (gchist==null ? null : gchist.array));
 		hist=null;
 		t.stop();
@@ -169,7 +169,7 @@ public class CallPeaks {
 		if(ploidy>0){list.add("ploidy="+ploidy);}
 		CallPeaks cp=new CallPeaks(list.toArray(new String[0]));
 		ArrayList<Peak> peaks=cp.callPeaks(array, gcArray, array.length);
-		cp.printPeaks(peaks, k, Tools.sum(array), array, gcArray);
+		cp.printPeaks(peaks, k, shared.Vector.sum(array), array, gcArray);
 		return cp.errorState;
 	}
 	
