@@ -22,7 +22,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -38,6 +37,7 @@ import structures.CoverageArray2;
 import structures.CoverageArray3;
 import structures.ListNum;
 import structures.LongList;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
