@@ -18,7 +18,6 @@ import fileIO.TextFile;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -31,6 +30,7 @@ import stream.FastaReadInputStream;
 import stream.MultiCros;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 
 /**
