@@ -20,7 +20,6 @@ import fileIO.TextFile;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -35,6 +34,7 @@ import stream.Read;
 import stream.SamLine;
 import structures.ByteBuilder;
 import structures.ListNum;
+import tracker.ReadStats;
 
 
 /**
@@ -233,9 +233,12 @@ public class DemuxByName2 {
 				outu2=b;
 			}else if(a.equals("pattern")){
 				parser.out1=b;
+			}else if(a.equals("statsonly")){
+				statsOnly=Parse.parseBoolean(b);
 			}else if(a.equals("remap") || a.equals("replace")){
 				remap=Parse.parseRemap(b);
 			}
+			
 			//Old version, allowed more complicated replacements
 //			else if(a.equals("replace")){
 //				if(b==null){
@@ -333,7 +336,7 @@ public class DemuxByName2 {
 			}
 
 			//This does not prevent expansion into a matching string
-			assert(!out1.equalsIgnoreCase(in1) && !out1.equalsIgnoreCase(in1)) : "Input file and output file have same name.";
+			assert(out1==null || (!out1.equalsIgnoreCase(in1) && !out1.equalsIgnoreCase(in1))) : "Input file and output file have same name.";
 			assert(out2==null || (!out2.equalsIgnoreCase(in1) && !out2.equalsIgnoreCase(in2))) : "out1 and out2 have same name.";
 		}
 	}
@@ -1067,4 +1070,6 @@ public class DemuxByName2 {
 	/** Verbose messages for debugging */
 	public static boolean verbose=false;
 	
+	public static boolean statsOnly=false;
+	
 }
