@@ -3,6 +3,7 @@ package jgi;
 import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.HashSet;
 import java.util.LinkedHashSet;
 
@@ -13,7 +14,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -23,6 +23,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Filters by exact sequence matches.
@@ -102,6 +103,13 @@ public class FilterBySequence {
 				rcomp=Parse.parseBoolean(b);
 			}else if(a.equals("casesensitive") || a.equals("case")){
 				toUpperCase=!Parse.parseBoolean(b);
+			}else if(a.equals("hdist") || a.equals("subs") || a.equals("s")){
+				maxSubs=Integer.parseInt(b);
+			}else if(a.equals("mismatchfraction") || a.equals("mf") || a.equals("f") || a.equals("fraction")
+					 || a.equals("sf") || a.equals("subfraction")){
+				mismatchFraction=Float.parseFloat(b);
+			}else if(a.equals("lengthdif") || a.equals("maxlengthdif") || a.equals("lendif")){
+				maxLengthDif=Integer.parseInt(b);
 			}else if(a.equals("parse_flag_goes_here")){
 				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
@@ -229,6 +237,7 @@ public class FilterBySequence {
 		}
 		
 		refSet=new HashSet<Code>();
+		refList=new ArrayList<byte[]>();
 	}
 	
 	/*--------------------------------------------------------------*/
@@ -250,7 +259,7 @@ public class FilterBySequence {
 			}
 			if(literal!=null){
 				for(String s : literal){
-					refSet.add(new Code(s.getBytes()));
+					addToRef(new Code(s.getBytes()));
 				}
 			}
 
@@ -424,6 +433,18 @@ public class FilterBySequence {
 	/*----------------         Inner Methods        ----------------*/
 	/*--------------------------------------------------------------*/
 	
+	private void addToRef(Collection<Code> codes) {
+		synchronized(refSet) {
+			for(Code c : codes) {addToRef(c);}
+		}
+	}
+	
+	private void addToRef(Code c) {
+		boolean novel=refSet.add(c);
+		if(novel) {refList.add(c.bases);}
+//		System.err.println(new String(c.bases)+": "+novel);
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------         Inner Classes        ----------------*/
 	/*--------------------------------------------------------------*/
@@ -522,11 +543,76 @@ public class FilterBySequence {
 		 * @return True if the reads should be kept, false if they should be discarded.
 		 */
 		boolean processReadPair(final Read r1, final Read r2){
-			final Code c1=new Code(r1.bases);
-			final Code c2=(r2==null ? null : new Code(r2.bases));
-			if(refSet.contains(c1)!=include){return false;}
-			if(c2!=null && refSet.contains(c2)!=include){return false;}
-			return true;
+			boolean contained=containsBoth(r1, r2);
+			return contained==include;
+		}
+		
+		boolean containsBoth(final Read r1, final Read r2){
+			boolean match1=contains(r1);
+			if(r2==null || !match1) {return match1;}
+			boolean match2=contains(r2);
+			return match1 && match2;
+		}
+		
+		boolean contains(final Read r){
+//			System.err.println(new String(r.bases)+": Query");
+			if(r==null || r.bases==null || r.bases.length<1) {return true;}//Empty string is always contained
+			final Code c=new Code(r.bases);
+//			System.err.println(refSet.contains(c)+", "+include);
+			if(refSet.contains(c)){return true;}
+//			System.err.println("b");
+			if(maxSubs<1 && maxLengthDif<1 && mismatchFraction<=0) {return false;}
+//			System.err.println("c");
+			return bruteForce(r.bases);
+		}
+		
+		boolean bruteForce(byte[] bases) {
+			if(bases==null) {return false;}
+			boolean match=compare(bases);
+//			System.err.println("g: "+match);
+			if(match || !rcomp) {return match;}
+			AminoAcid.reverseComplementBasesInPlace(bases);
+			match=compare(bases);
+//			System.err.println("h: "+match);
+			AminoAcid.reverseComplementBasesInPlace(bases);
+			return match;
+		}
+		
+		boolean compare(byte[] bases) {
+			int minlen=bases.length-maxLengthDif, maxlen=bases.length+maxLengthDif;
+//			System.err.println("d: "+minlen+"-"+maxlen);
+//			System.err.println(new String(bases)+": Query2");
+			boolean match=false;
+			for(byte[] ref : refList) {
+				if(ref.length>=minlen && ref.length<=maxlen) {
+//					System.err.println(new String(ref)+": Ref");
+					final byte[] longer, shorter;
+					if(bases.length<ref.length) {
+						shorter=bases; longer=ref;
+					}else {
+						shorter=ref; longer=bases;
+					}
+					match=compare(longer, shorter);
+					if(match) {break;}
+				}
+			}
+//			System.err.println("compare returned "+match);
+			return match;
+		}
+		
+		boolean compare(byte[] a, byte[] b) {
+			final int maxSubs0=Tools.max(maxSubs, 
+					(int)Math.round(Tools.min(a.length, b.length)*mismatchFraction));
+			final int aStartMax=a.length-b.length;
+			for(int aStart=0; aStart<=aStartMax; aStart++) {
+				int subs=0;
+				for(int apos=aStart, bpos=0; bpos<b.length && subs<=maxSubs0; apos++, bpos++) {
+					subs+=(a[apos]==b[bpos] ? 0 : 1);
+				}
+				if(subs<=maxSubs0) {return true;}
+//				System.err.println("Subs="+subs+", maxSubs="+maxSubs);
+			}
+			return false;
 		}
 
 		/** Number of reads processed by this thread */
@@ -615,9 +701,7 @@ public class FilterBySequence {
 				
 				if(codes.size()>2000){
 					synchronized(refSet){
-						for(Code c : codes){
-							refSet.add(c);
-						}
+						addToRef(codes);
 						codes.clear();
 					}
 				}
@@ -633,9 +717,7 @@ public class FilterBySequence {
 			
 			if(codes.size()>0){
 				synchronized(refSet){
-					for(Code c : codes){
-						refSet.add(c);
-					}
+					addToRef(codes);
 					codes.clear();
 				}
 			}
@@ -669,7 +751,7 @@ public class FilterBySequence {
 			b=(rcomp ? Tools.min(fwd, rev) : rev);
 			
 			if(storeBases){
-				if(!rcomp && !toUpperCase){
+				if(a==fwd && !toUpperCase){
 					bases=bases_;
 				}else{
 					bases=bases_.clone();
@@ -694,6 +776,12 @@ public class FilterBySequence {
 			return Tools.equals(bases, c.bases);
 		}
 		
+//		public boolean revEquals(Code c){
+//			if(a!=c.b || b!=c.a){return false;}
+//			if(bases==null || c.bases==null){return true;}
+//			return AminoAcid.equalsReverseComp(bases, c.bases);
+//		}
+		
 		@Override
 		public int hashCode(){
 			return (int)(a&0x7FFFFFFF);
@@ -734,8 +822,9 @@ public class FilterBySequence {
 	
 	/** Literals */
 	private String[] literal=null;
-	
+
 	private HashSet<Code> refSet;
+	private ArrayList<byte[]> refList;
 	
 	private boolean storeBases=true;
 	
@@ -762,6 +851,10 @@ public class FilterBySequence {
 
 	/** Quit after processing this many input reads; -1 means no limit */
 	private long maxReads=-1;
+
+	private int maxSubs=0;
+	private float mismatchFraction=0f;
+	private int maxLengthDif=0;
 	
 	/*--------------------------------------------------------------*/
 	/*----------------         Final Fields         ----------------*/
