@@ -249,7 +249,7 @@ public class FindHiCJunctions {
 		final String fname=junctionFile.replaceFirst("%", k+direction);
 		final ByteStreamWriter bsw=new ByteStreamWriter(fname, true, false, false);
 		bsw.start();
-		final long sum=Tools.sum(array);
+		final long sum=shared.Vector.sum(array);
 		final double mult=1.0/(Tools.max(1, sum));
 		final long thresh=Tools.max((2*sum)/array.length, (long)Math.ceil(Tools.max(minCount, minFraction*sum)));
 //		if(k==4){System.err.println(Arrays.toString(array));}
