@@ -12,7 +12,6 @@ import shared.MetadataWriter;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -23,6 +22,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Reformats a fungal assembly for release. Also creates contig and agp files.
@@ -262,7 +262,7 @@ public class FungalRelease {
 		if (bswLegend != null) {
 			bswLegend.start();
 		}
-
+		
 		if (ros != null) {
 			if (sortScaffolds) {
 				Shared.sort(scaffolds, ReadLengthComparator.comparator);
