@@ -272,7 +272,7 @@ public class GatherKapaStats {
 				double p25=ppmk[(int)Math.round((len-1)*.25)];
 				double p50=ppmk[(int)Math.round((len-1)*.50)];
 				double p75=ppmk[(int)Math.round((len-1)*.75)];
-				double avg=Tools.sum(ppmk)/len;
+				double avg=shared.Vector.sum(ppmk)/len;
 				double stdev=Tools.standardDeviation(ppmk);
 				bb.append(td.name).append('\t');
 				bb.append(key).append('\t');
