@@ -11,7 +11,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -24,6 +23,7 @@ import structures.ByteBuilder;
 import structures.ListNum;
 import structures.LongListSet;
 import structures.LongListSet.LongListSetIterator;
+import tracker.ReadStats;
 
 /**
  * Generates mutants of kmers.
