@@ -14,7 +14,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -26,6 +25,7 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
 import tax.GiToTaxid;
+import tracker.ReadStats;
 
 /**
  * Designed to keep the best copy of an SSU per organism.
