@@ -23,7 +23,6 @@ import kmer.Walker;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -31,6 +30,7 @@ import sketch.Sketch;
 import sketch.SketchObject;
 import sketch.SketchTool;
 import stream.FastaReadInputStream;
+import tracker.ReadStats;
 import ukmer.AbstractKmerTableU;
 import ukmer.HashArrayU1D;
 import ukmer.HashForestU;
@@ -376,12 +376,12 @@ public class KmerCountExact {
 		bsw.nl();
 		
 		int maxDepth=counts.length-1;
-		while(maxDepth>0 && Tools.sum(counts[maxDepth])<1){
+		while(maxDepth>0 && shared.Vector.sum(counts[maxDepth])<1){
 			maxDepth--;
 		}
 		
 		for(int depth=0; depth<=maxDepth; depth++){
-			if(histZeros || Tools.sum(counts[depth])>0){
+			if(histZeros || shared.Vector.sum(counts[depth])>0){
 				bsw.print(depth);
 				for(int copy=0; copy<counts[depth].length; copy++){
 					bsw.tab();
@@ -841,7 +841,7 @@ public class KmerCountExact {
 		outstream.println("Generating sketch.");
 		SketchObject.maxGenomeFraction=1;
 		SketchObject.k=k;
-		SketchTool sketcher=new SketchTool(sketchLength, minToDump, false, false);
+		SketchTool sketcher=new SketchTool(sketchLength, minToDump, false, false, SketchObject.rcomp);
 		Sketch sketch=sketcher.toSketch((KmerTableSet)tables, true);
 		if(sketch==null){
 			errorState=true;
