@@ -19,7 +19,6 @@ import fileIO.TextStreamWriter;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -29,6 +28,7 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ByteBuilder;
 import structures.ListNum;
+import tracker.ReadStats;
 
 
 /**
@@ -603,7 +603,7 @@ public class KmerCoverage {
 				tswh.print("#Depth\tRaw_Count\tUnique_Kmers\n");
 			}
 			int lim=(int)(HIST_LEN_PRINT-1);
-			long remaining=Tools.sum(histogram_total);
+			long remaining=shared.Vector.sum(histogram_total);
 			long sumRaw1=0;
 			long sumRaw2=0;
 			long sum1=0;
@@ -646,7 +646,7 @@ public class KmerCoverage {
 				outstream.println("Wrote histogram to "+histFile);
 			}
 			
-			long histCount=Tools.sum(histogram_total); //Total number of kmers counted
+			long histCount=shared.Vector.sum(histogram_total); //Total number of kmers counted
 			long halfCount=(histCount+1)/2;
 			double histCountU=0; //Unique kmers counted
 			long temp1=0;
