@@ -11,7 +11,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -19,6 +18,7 @@ import stream.ConcurrentGenericReadInputStream;
 import stream.FASTQ;
 import stream.FastaReadInputStream;
 import structures.ByteBuilder;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
