@@ -14,7 +14,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -25,6 +24,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
@@ -260,8 +260,8 @@ public class MergeBarcodes {
 		double rpnano=readsProcessed/(double)(t.elapsed);
 		double bpnano=basesProcessed/(double)(t.elapsed);
 
-		String rpstring=Tools.padKM(readsProcessed, 8);
-		String bpstring=Tools.padKM(basesProcessed, 8);
+		String rpstring=Tools.padKMB(readsProcessed, 8);
+		String bpstring=Tools.padKMB(basesProcessed, 8);
 		
 		outstream.println("Loaded barcodes.");
 		outstream.println("Time:                         \t"+t);
