@@ -8,6 +8,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Locale;
 import java.util.Random;
+import java.util.regex.Pattern;
 
 import cardinality.CardinalityTracker;
 import dna.AminoAcid;
@@ -18,11 +19,12 @@ import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
+import shared.LineParser2;
+import shared.LineParser2S;
 import shared.MetadataWriter;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -38,6 +40,7 @@ import structures.ListNum;
 import structures.LongList;
 import structures.Quantizer;
 import structures.SuperLongList;
+import tracker.ReadStats;
 import var2.ScafMap;
 
 /**
@@ -79,7 +82,7 @@ public class ReformatReads {
 		Parser parser=new Parser();
 		for(int i=0; i<args.length; i++){
 			String arg=args[i];
-			String[] split=arg.split("=");
+			String[] split=Parse.splitOnFirst(arg, '=');
 			String a=split[0].toLowerCase();
 			String b=split.length>1 ? split[1] : null;
 			
@@ -219,6 +222,21 @@ public class ReformatReads {
 				minsubs=Integer.parseInt(b);
 			}
 			
+			else if(a.equals("tag")){
+				tag=b;
+			}else if(a.equals("delimiter")){
+//				delimiterS=null;
+				delimiter=Parse.parseSymbolToCharacter(b);
+//				if(delimiter==0) {delimiterS=Parse.parseSymbol(b);}
+				assert(delimiter>0) : delimiter+", '"+b+"'";
+			}else if(a.equals("minvalue")){
+				minValue=Integer.parseInt(b);
+			}else if(a.equals("maxvalue")){
+				maxValue=Integer.parseInt(b);
+			}else if(a.equals("value")){
+				requiredValue=b;
+			}
+			
 			else if(parser.parse(arg, a, b)){
 				//do nothing
 			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
@@ -418,8 +436,22 @@ public class ReformatReads {
 		nameMap2=(uniqueNames ? new HashMap<String, Integer>() : null);
 		
 		if(ref!=null){ScafMap.loadReference(ref, true);}
+		if(tag!=null) {
+			assert(delimiter>0/* || delimiterS!=null*/) :
+				"When using a tag, a delimiter must be set; e.g. "
+				+ "delimiter=X, delimiter=' ' or delimiter=space\n"
+				+ "Most problematic symbols can be spelled out, like tab, "
+				+ "pipe, asterisk, greaterthan, etc.";
+//			if(delimiterS!=null) {
+//				splitter=Pattern.compile(delimiterS);
+//			}
+//			lp=new LineParser2S(delimiter);
+		}
+//		lp=null;//lp is not currently used
 	}
 
+	
+	
 	void process(Timer t){
 		
 		long readsRemaining=0;
@@ -471,6 +503,10 @@ public class ReformatReads {
 				readsRemaining=counts[0];
 				basesRemaining=counts[2];
 				setSampleSeed(sampleseed);
+				double prob=(sampleReadsExact ? sampleReadsTarget/(double)(readsRemaining)
+						: sampleBasesTarget/(double)(basesRemaining));
+				if(!allowUpsample) {prob=Tools.min(prob, 1.0);}
+				System.err.println("Initial samplerate set to "+String.format("%.6f", prob));
 			}
 		}
 		
@@ -535,23 +571,11 @@ public class ReformatReads {
 		long basesSwappedT=0;
 		long readsSwappedT=0;
 
-		final boolean MAKE_QHIST=ReadStats.COLLECT_QUALITY_STATS;
-		final boolean MAKE_QAHIST=ReadStats.COLLECT_QUALITY_ACCURACY;
-		final boolean MAKE_MHIST=ReadStats.COLLECT_MATCH_STATS;
-		final boolean MAKE_BHIST=ReadStats.COLLECT_BASE_STATS;
-		
-		final boolean MAKE_EHIST=ReadStats.COLLECT_ERROR_STATS;
-		final boolean MAKE_INDELHIST=ReadStats.COLLECT_INDEL_STATS;
-		final boolean MAKE_LHIST=ReadStats.COLLECT_LENGTH_STATS;
-		final boolean MAKE_GCHIST=ReadStats.COLLECT_GC_STATS;
-		final boolean MAKE_IDHIST=ReadStats.COLLECT_IDENTITY_STATS;
 		final boolean MAKE_IHIST=ReadStats.COLLECT_INSERT_STATS;
 		
 		final boolean sam=ffin1.samOrBam();
 		
-		final ReadStats readstats=(MAKE_QHIST || MAKE_MHIST || MAKE_BHIST || MAKE_QAHIST || MAKE_EHIST
-				|| MAKE_INDELHIST || MAKE_LHIST || MAKE_GCHIST || MAKE_IDHIST || MAKE_IHIST) ?
-				new ReadStats() : null;
+		final ReadStats readstats=ReadStats.collectingStats() ? new ReadStats() : null;
 		
 		{
 			
@@ -626,16 +650,7 @@ public class ReformatReads {
 					}
 					
 					if(readstats!=null){
-						if(MAKE_QHIST){readstats.addToQualityHistogram(r1);}
-						if(MAKE_BHIST){readstats.addToBaseHistogram(r1);}
-						if(MAKE_MHIST){readstats.addToMatchHistogram(r1);}
-						if(MAKE_QAHIST){readstats.addToQualityAccuracy(r1);}
-						
-						if(MAKE_EHIST){readstats.addToErrorHistogram(r1);}
-						if(MAKE_INDELHIST){readstats.addToIndelHistogram(r1);}
-						if(MAKE_LHIST){readstats.addToLengthHistogram(r1);}
-						if(MAKE_GCHIST){readstats.addToGCHistogram(r1);}
-						if(MAKE_IDHIST){readstats.addToIdentityHistogram(r1);}
+						readstats.addToHistograms(r1);
 						
 						if(MAKE_IHIST && sl1!=null && !r1.secondary() && sl1.pairnum()==0){
 							readstats.addToInsertHistogram(sl1);
@@ -738,8 +753,7 @@ public class ReformatReads {
 						if(r1!=null && r1.failsChastity()){
 							lowqBasesT+=r1.pairLength();
 							lowqReadsT+=r1.pairCount();
-							r1.setDiscarded(true);
-							if(r2!=null){r2.setDiscarded(true);}
+							r1.setPairDiscarded(true);
 						}
 					}
 					
@@ -748,11 +762,15 @@ public class ReformatReads {
 							if(failBadBarcodes){KillSwitch.kill("Invalid barcode detected: "+r1.id+"\nThis can be disabled with the flag barcodefilter=f");}
 							lowqBasesT+=r1.pairLength();
 							lowqReadsT+=r1.pairCount();
-							r1.setDiscarded(true);
-							if(r2!=null){r2.setDiscarded(true);}
+							r1.setPairDiscarded(true);
 						}
 					}
 					
+					if(tag!=null && r1!=null && !r1.discarded()) {
+						boolean pass=passesTagFilter(r1.id, tag, delimiter);
+						if(!pass){r1.setPairDiscarded(true);}
+					}
+					
 					if(filterBits!=0 || requiredBits!=0){
 						if(r1!=null && !r1.discarded()){
 							assert(sl1!=null) : "filterbits and requiredbits only work on sam/bam input.";
@@ -1359,6 +1377,25 @@ public class ReformatReads {
 		return !bad;
 	}
 	
+	public boolean passesTagFilter(String s, String tag, char delimiter) {
+		if(requiredValue!=null) {
+			String value=Parse.parseString(s, tag, delimiter);
+			return (value==null ? requiredValue==null : value.equals(requiredValue));
+		}
+		double value=Parse.parseDouble(s, tag, delimiter);
+		return value>=minValue && value<=maxValue;
+	}
+	
+//	public boolean passesTagFilter(String s, Pattern splitter) {
+//		String[] split=s.split(s);
+//		if(requiredValue!=null) {
+//			String value=Parse.parseString(s, tag, delimiter);
+//			return (value==null ? requiredValue==null : value.equals(requiredValue));
+//		}
+//		double value=Parse.parseDouble(s, tag, delimiter);
+//		return value>=minValue && value<=maxValue;
+//	}
+	
 	/*--------------------------------------------------------------*/
 	
 	private void deleteEmpty(long readsOut1, long readsOut2, long readsOutSingle){
@@ -1680,6 +1717,21 @@ public class ReformatReads {
 	private int padLeft=0;
 	private int padRight=0;
 	
+	//For scanning for specific terms in headers, like "count=53".
+	/** Parse headers for this tag, like "count=" */
+	private String tag;
+	/** Use this delimiter when parsing the header */
+	private char delimiter=0;
+	private String delimiterS=null;
+	/** Min value for numeric terms */
+	private float minValue=Float.MIN_VALUE;
+	/** Max value for numeric terms */
+	private float maxValue=Float.MAX_VALUE;
+	/** A specific String value for terms */
+	private String requiredValue=null;
+//	private final LineParser2S lp;
+//	private Pattern splitter;
+	
 	/*--------------------------------------------------------------*/
 	
 	private final FileFormat ffin1;
