@@ -11,9 +11,9 @@ import fileIO.ByteFile1;
 import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -24,6 +24,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
@@ -59,7 +60,7 @@ public class RenameReads {
 		
 		for(int i=0; i<args.length; i++){
 			String arg=args[i];
-			String[] split=arg.split("=");
+			String[] split=Parse.splitOnFirst(arg, '=');
 			String a=split[0].toLowerCase();
 			String b=split.length>1 ? split[1] : null;
 			
@@ -77,7 +78,7 @@ public class RenameReads {
 				assert(false) : "'passes' is disabled.";
 //				passes=Integer.parseInt(b);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -85,15 +86,17 @@ public class RenameReads {
 				stream.FastqReadInputStream.verbose=verbose;
 				ReadWrite.verbose=verbose;
 			}else if(a.equalsIgnoreCase("fixSRA")){
-				fixSRA=Tools.parseBoolean(b);
+				fixSRA=Parse.parseBoolean(b);
 			}else if(a.equals("reads") || a.equals("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.equals("build") || a.equals("genome")){
 				Data.setGenome(Integer.parseInt(b));
 			}else if(a.equals("in") || a.equals("input") || a.equals("in1") || a.equals("input1")){
 				in1=b;
 			}else if(a.equals("prefix") || a.equals("p")){
 				prefix=b;
+			}else if(a.equals("suffix")){
+				suffix=b;
 			}else if(a.equals("in2") || a.equals("input2")){
 				in2=b;
 			}else if(a.equals("out") || a.equals("output") || a.equals("out1") || a.equals("output1")){
@@ -113,21 +116,21 @@ public class RenameReads {
 			}else if(a.equals("extout")){
 				extout=b;
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("renamebyinsert")){
-				renameByInsert=Tools.parseBoolean(b);
+				renameByInsert=Parse.parseBoolean(b);
 			}else if(a.equals("renamebytrim")){
-				renameByTrim=Tools.parseBoolean(b);
+				renameByTrim=Parse.parseBoolean(b);
 			}else if(a.equals("addprefix")){
-				addPrefix=Tools.parseBoolean(b);
+				addPrefix=Parse.parseBoolean(b);
 			}else if(a.equals("addpairnum")){
-				addPairnum=Tools.parseBoolean(b);
+				addPairnum=Parse.parseBoolean(b);
 			}else if(a.equals("prefixonly")){
-				prefixOnly=Tools.parseBoolean(b);
+				prefixOnly=Parse.parseBoolean(b);
 			}else if(a.equals("underscore") || a.equals("addunderscore")){
-				addUnderscore=Tools.parseBoolean(b);
+				addUnderscore=Parse.parseBoolean(b);
 			}else if(a.startsWith("minscaf") || a.startsWith("mincontig")){
 				stream.FastaReadInputStream.MIN_READ_LEN=Integer.parseInt(b);
 			}else if(in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
@@ -285,6 +288,9 @@ public class RenameReads {
 						r2.id=prefix+r2.id;
 					}
 					x++;
+				}else if(suffix!=null) {
+					r1.id+="\t"+suffix;
+					if(r2!=null) {r2.id+="\t"+suffix;}
 				}else{
 					r1.id=prefix+x;
 					if(r2!=null){
@@ -336,6 +342,7 @@ public class RenameReads {
 	private String extout=null;
 
 	private String prefix=null;
+	private String suffix=null;
 	
 	private final FileFormat ffin1;
 	private final FileFormat ffin2;
