@@ -14,6 +14,7 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -80,32 +81,32 @@ public class RepresentativeSet {
 			}
 			
 			else if(a.equals("maxsize")){
-				maxSize=Tools.parseKMG(b);
+				maxSize=Parse.parseKMG(b);
 			}else if(a.equals("minsize")){
-				minSize=Tools.parseKMG(b);
+				minSize=Parse.parseKMG(b);
 			}
 			else if(a.equals("maxbases") || a.equals("maxbp")){
-				maxBases=Tools.parseKMG(b);
+				maxBases=Parse.parseKMG(b);
 			}else if(a.equals("minbases") || a.equals("minbp")){
-				minBases=Tools.parseKMG(b);
+				minBases=Parse.parseKMG(b);
 			}
 			
 			else if(a.equals("invertratio") || a.equals("ir")){
-				invertRatio=Tools.parseBoolean(b);
+				invertRatio=Parse.parseBoolean(b);
 			}else if(a.equals("printsize")){
-				printSize=Tools.parseBoolean(b);
+				printSize=Parse.parseBoolean(b);
 			}else if(a.equals("printclusters") || a.equals("cluster")){
-				printClusters=Tools.parseBoolean(b);
+				printClusters=Parse.parseBoolean(b);
 			}else if(a.equals("printheader") || a.equals("header")){
-				printHeader=Tools.parseBoolean(b);
+				printHeader=Parse.parseBoolean(b);
 			}
 			
 //			else if(a.equals("taxfilter")){
-//				foo=Tools.parseBoolean(b);
+//				foo=Parse.parseBoolean(b);
 //			}
 			
 			else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
