@@ -18,12 +18,12 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Tools;
 import stream.Read;
 import stream.SamLine;
 import structures.LongList;
+import tracker.ReadStats;
 
 /**
  * 
