@@ -3,12 +3,11 @@ package jgi;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collections;
-import java.util.HashMap;
 import java.util.Locale;
-import java.util.Map.Entry;
-
+import align2.BandedAlignerConcrete;
 import align2.QualityTools;
+import barcode.Barcode;
+import barcode.BarcodeStats;
 import dna.AminoAcid;
 import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
@@ -21,7 +20,6 @@ import server.ServerTools;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -35,10 +33,14 @@ import sketch.SketchTool;
 import stream.ConcurrentReadInputStream;
 import stream.FASTQ;
 import stream.Read;
+import structures.ByteBuilder;
 import structures.IntHashMapBinary;
 import structures.ListNum;
 import structures.LongPair;
+import structures.Range;
 import structures.SuperLongList;
+import tracker.AdapterTracker;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
@@ -97,10 +99,13 @@ public class TestFormat {
 				parseZmw=Parse.parseBoolean(b);
 			}
 			
-			else if(a.equals("barcodes") || a.equals("barcodefile")){
+			else if(a.equals("barcodes") || a.equals("barcodefile") || a.equals("indexes") || a.equals("indices")){
 				barcodeFile=b;
 			}
 			
+			else if(a.equals("expectedbarcodes") || a.equals("expectedindexes") || a.equals("expectedindices") || a.equals("barcodelist") || a.equals("indexlist")){
+				expectedCodeFile=b;
+			}
 			
 			else if(a.equals("hist") || a.equals("hists")){
 				if(!Parse.parseBoolean(b)){
@@ -146,6 +151,8 @@ public class TestFormat {
 				fast=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("slow")){
 				fast=!Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("edist") || a.equalsIgnoreCase("calcedist") || a.equalsIgnoreCase("edits")){
+				BarcodeStats.calcEdist=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("sketch") || a.equalsIgnoreCase("card")){
 				makeSketch=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("merge")){
@@ -199,8 +206,17 @@ public class TestFormat {
 		initialQin=FASTQ.ASCII_OFFSET;
 		initialDetectQuality=FASTQ.DETECT_QUALITY;
 		
+		if(barcodeFile!=null){
+			if(barcodeFile.indexOf('#')>0){
+//				barcodeFile1=barcodeFile.replace('#', '1');
+//				barcodeFile2=barcodeFile.replace('#', '2');
+				barcodeFile=barcodeFile.replace('#', 's');
+			}
+		}
+		
 		//TODO: in is not considered here.
-		if(!Tools.testForDuplicateFiles(true, qhistFile, ihistFile, khistFile, bhistFile, lhistFile, gchistFile, zmwhistFile, barcodeFile, junkFile)){
+		if(!Tools.testForDuplicateFiles(true, qhistFile, ihistFile, khistFile, bhistFile, lhistFile, gchistFile, zmwhistFile, 
+				barcodeFile, /*barcodeFile1, barcodeFile2,*/ expectedCodeFile, junkFile)){
 			throw new RuntimeException("\nSome file names were specified multiple times.\n");
 		}
 	}
@@ -272,7 +288,7 @@ public class TestFormat {
 		
 		if(format!=FileFormat.FASTA && format!=FileFormat.UNKNOWN){
 			println("QualOffset\t"+offset);
-			long negatives=Tools.sum(qhist, 0, 127);
+			long negatives=shared.Vector.sum(qhist, 0, 127);
 			println("NegativeQuals\t"+negatives);
 		}
 		if(differs){}
@@ -291,15 +307,18 @@ public class TestFormat {
 			printNucleotideTop();
 		}
 		
-		if(Tools.sum(qhist)>0){
+		if(shared.Vector.sum(qhist)>0){
 			printQhist();
 		}
-		if(doMerge && pairsProcessed>0 && !amino && Tools.sum(ihist)>0){
+		if(doMerge && pairsProcessed>0 && !amino && shared.Vector.sum(ihist)>0){
 			printIhist();
 		}
-		if(!amino && barcodes.size()>0){
+		if(!amino && barcodeStats.size()>0){
 			printBarcodes();
 		}
+		if(!amino && aTrack.makeSequence()){
+			aTrack.writeAdapterConsensus(adapterFile);
+		}
 		if(!amino && junkProcessed>0){
 			printJunk();
 		}
@@ -307,6 +326,7 @@ public class TestFormat {
 	
 	void printAminoTop(){
 		println("Content\t\tAminoAcids");
+		println("FirstHeader\t"+firstHeader);
 		println("Sequences\t"+readsProcessed);
 		println("Residues\t"+basesProcessed);
 		println("-Lowercase\t"+lowerUpperSymbol[0]);
@@ -332,6 +352,7 @@ public class TestFormat {
 		
 		println("Content\t\tNucleotides");
 		println("Type\t\t"+(U==0 ? "DNA" : T==0 ? "RNA" : "Mixed"));
+		println("FirstHeader\t"+firstHeader);
 		println("Reads\t\t"+readsProcessed);
 		println("-JunkReads\t"+junkProcessed);
 		println("-ChastityFail\t"+chastityFail);
@@ -360,6 +381,7 @@ public class TestFormat {
 			sketch=smm.toSketch(smm.pacBioDetected ? 2 : 1);
 //			System.err.println(smm.pacBioDetected);
 			println("Cardinality\t"+(sketch==null ? 0 : sketch.genomeSizeEstimate()));
+			println("Cardinality_3+\t"+(sketch==null ? 0 : sketch.genomeSizeEstimate(3)));
 			if(khistFile!=null){
 				if(sketch!=null){
 					ArrayList<LongPair> list=sketch.toKhist();
@@ -425,10 +447,10 @@ public class TestFormat {
 				}
 			}
 		}
-		println("Barcodes\t"+barcodes.size());
+		println("Barcodes\t"+barcodeStats.size());
 		println("ZMWs    \t"+zmwMap.cardinality());
 		if(doMerge && pairsProcessed>0){
-			final long numMerged=Tools.sum(ihist);
+			final long numMerged=shared.Vector.sum(ihist);
 			final double insertAvg=Tools.averageHistogram(ihist);
 			final int insertMode=Tools.maxIndex(ihist);
 			final double mergeFraction=(numMerged/(1.0*Tools.max(mergeAttempts, 1)));
@@ -438,8 +460,12 @@ public class TestFormat {
 			if(mergeFraction>0.02){
 				println("-InsertMean\t"+String.format(Locale.ROOT, "%.2f", insertAvg));
 				println("-InsertMode\t"+insertMode);
-				println("-AdapterReads\t"+String.format(Locale.ROOT, "%.3f%%", 100*adapterBaseFraction));
-				println("-AdapterBases\t"+String.format(Locale.ROOT, "%.3f%%", 100*adapterReadFraction));
+				println("-AdapterReads\t"+String.format(Locale.ROOT, "%.3f%%", 100*adapterReadFraction));
+				println("-AdapterBases\t"+String.format(Locale.ROOT, "%.3f%%", 100*adapterBaseFraction));
+				if(aTrack.makeSequence()){
+					println("-Adapter1\t"+aTrack.seq1);
+					println("-Adapter2\t"+aTrack.seq2);
+				}
 			}
 		}
 	}
@@ -466,6 +492,7 @@ public class TestFormat {
 		println("-qMaxUncalled\t"+qMaxUncalled);
 		println("-qMinCalled\t"+qMinCalled);
 		println("-qMaxCalled\t"+qMaxCalled);
+		println("-qScoreRange\t"+qhistToRangeString(qhist));
 		
 		if(doTrim){
 			println("-TrimmedAtQ5\t"+String.format(Locale.ROOT, "%.2f%%", trimhist[5]*trimMult));
@@ -483,7 +510,7 @@ public class TestFormat {
 				if(q>0){println((i-qOffset)+"\t\t"+q);}
 			}
 		}
-		if(qhistFile!=null && Tools.sum(qhist)>0){
+		if(qhistFile!=null && shared.Vector.sum(qhist)>0){
 			try {
 				StringBuilder sb=new StringBuilder();
 				sb.append("#QErrorRate\t"+String.format(Locale.ROOT, "%.3f%%\n", 100*errorAvg));
@@ -497,9 +524,41 @@ public class TestFormat {
 		}
 	}
 	
+	static String qhistToRangeString(long[] qhist) {
+		ArrayList<Range> list=qhistToRanges(qhist);
+		if(list.isEmpty()) {return "";}
+		ByteBuilder bb=new ByteBuilder();
+		for(Range r : list){
+			if(!bb.isEmpty()){bb.comma();}
+			r.appendTo(bb);
+		}
+		return bb.toString();
+	}
+	
+	static ArrayList<Range> qhistToRanges(long[] qhist){
+		ArrayList<Range> list=new ArrayList<Range>();
+		Range current=null;
+		for(int i=0; i<qhist.length; i++){
+			final long count=qhist[i];
+			final int q=i-128;
+			if(count>0){
+				if(current==null){
+					current=new Range(q, q);
+					list.add(current);
+				}else if(current.touches(q)){
+					current.absorb(q);
+				}else{
+					current=new Range(q, q);
+					list.add(current);
+				}
+			}
+		}
+		return list;
+	}
+	
 	void printIhist(){
 
-		final long numMerged=Tools.sum(ihist);
+		final long numMerged=shared.Vector.sum(ihist);
 		final double insertAvg=Tools.averageHistogram(ihist);
 		final int insertMode=Tools.maxIndex(ihist);
 		final double mergeFraction=(numMerged/(1.0*Tools.max(mergeAttempts, 1)));
@@ -518,8 +577,8 @@ public class TestFormat {
 				StringBuilder sb=new StringBuilder();
 				sb.append("#InsertMean\t"+String.format(Locale.ROOT, "%.2f\n", insertAvg));
 				sb.append("#InsertMode\t"+insertMode+"\n");
-				sb.append("#AdapterReads\t"+String.format(Locale.ROOT, "%.2f%%\n", 100*adapterBaseFraction));
-				sb.append("#AdapterBases\t"+String.format(Locale.ROOT, "%.2f%%\n", 100*adapterReadFraction));
+				sb.append("#AdapterReads\t"+String.format(Locale.ROOT, "%.2f%%\n", 100*adapterReadFraction));
+				sb.append("#AdapterBases\t"+String.format(Locale.ROOT, "%.2f%%\n", 100*adapterBaseFraction));
 				printToFile(ihist, true, sb.toString(), ihistFile);
 			} catch (Throwable e) {
 				System.err.println("ERROR - Could not write ihist: "+e.toString());
@@ -529,25 +588,31 @@ public class TestFormat {
 	}
 	
 	void printBarcodes(){
-		ArrayList<Barcode> list=new ArrayList<Barcode>(barcodes.size());
-		list.addAll(barcodes.values());
-		Collections.sort(list);
-		if(printBarcodes){
-			println("\nBarcodeList:");
-			for(Barcode bc : list){println(bc);}
-		}
+		final BarcodeStats bs=barcodeStats;
 		
 		if(barcodeFile!=null){
-			try {
-				TextStreamWriter tsw=new TextStreamWriter(barcodeFile, true, false, false);
-				tsw.start();
-				tsw.println("#Barcodes\t"+barcodes.size());
-				for(Barcode bc : list){tsw.println(bc.toString());}
-				errorState|=tsw.poisonAndWait();
-			} catch (Throwable e) {
-				System.err.println("ERROR - Could not write barcode file: "+e.toString());
-				errorState=true;
-			}
+			bs.printToFile(barcodeFile, true);
+		}
+		
+		println("");
+		if(barcodesPerRead>1) {
+			bs.leftStats=bs.makeLeft();
+			bs.rightStats=bs.makeRight();
+			bs.calcStats();
+			println(bs.toStats("Barcodes"));
+			bs.leftStats.calcStats();
+			println(bs.leftStats.toStats("Barcode1"));
+			bs.rightStats.calcStats();
+			println(bs.rightStats.toStats("Barcode2"));
+		}else{
+			bs.calcStats();
+			println(bs.toStats(""));
+		}
+		
+		if(printBarcodes){
+			ArrayList<Barcode> list=bs.toList();
+			println("\nBarcodeList:");
+			for(Barcode bc : list){println(bc);}
 		}
 	}
 	
@@ -600,6 +665,8 @@ public class TestFormat {
 				interleaved=(qi[1]==FileFormat.INTERLEAVED);
 				maxLen=Tools.max(maxLen, qi[2]);
 				minLen=Tools.min(minLen, qi[2]);
+				barcodesPerRead=qi[4];
+				barcodeDelimiter=(byte)qi[5];
 				stream.FASTQ.ASCII_OFFSET=qold;
 			}else if(ff.fasta()){
 				interleaved=stream.FASTQ.testInterleavedFasta(fname, false);
@@ -622,6 +689,8 @@ public class TestFormat {
 			cris.start();
 		}
 		final boolean paired=cris.paired();
+		barcodeStats=new BarcodeStats((char)barcodeDelimiter, barcodesPerRead, "Full");
+		if(expectedCodeFile!=null){barcodeStats.loadBarcodeList(expectedCodeFile);}
 		
 		spawnThreads(ff, cris);
 		
@@ -696,44 +765,6 @@ public class TestFormat {
 	
 	/*--------------------------------------------------------------*/
 	
-	private static class Barcode implements Comparable<Barcode> {
-		
-		Barcode(String s){
-			name=s;
-		}
-		
-		public void increment() {
-			count++;
-		}
-		
-		public void increment(long x) {
-			count+=x;
-		}
-		
-		public long count(){return count;}
-
-		@Override
-		public int hashCode(){
-			return name.hashCode();
-		}
-		
-		@Override
-		public int compareTo(Barcode other) {
-			if(count!=other.count){return count>other.count ? -1 : 1;}
-			return name.compareTo(other.name);
-		}
-		
-		@Override
-		public String toString(){
-			return name+"\t"+count;
-		}
-		
-		final String name;
-		private long count=0;
-	}
-	
-	/*--------------------------------------------------------------*/
-	
 	private static final byte[] makeToNum(){
 		byte[] array=new byte[128];
 		Arrays.fill(array, (byte)8);
@@ -878,15 +909,8 @@ public class TestFormat {
 			add(ihist, pt.ihist_T);
 			add(trimhist, pt.trimhist_T);
 			
-			for(Entry<String, Barcode> e : pt.barcodes_T.entrySet()){
-				String key=e.getKey();
-				Barcode b=barcodes.get(key);
-				if(b!=null){
-					b.increment(e.getValue().count);
-				}else{
-					barcodes.put(e.getKey(), e.getValue());
-				}
-			}
+			barcodeStats.merge(pt.barcodeStats_T);
+			aTrack.merge(pt.aTrack_T);
 			invalidHeaders.addAll(pt.invalidHeaders_T);
 			
 			if(makeSketch){
@@ -958,6 +982,12 @@ public class TestFormat {
 						parseZmwT=(zmw>=0 && zmw<=1000000000);
 					} catch (Exception e) {}
 				}
+				if(r.numericID==0){
+					synchronized(cris) {
+						assert(firstHeader==null);
+						firstHeader=r.id;
+					}
+				}
 			}
 
 			while(ln!=null && reads!=null && reads.size()>0){//ln!=null prevents a compiler potential null access warning
@@ -1008,6 +1038,8 @@ public class TestFormat {
 								adapterBases_T+=trim2;
 								adapterReads_T++;
 							}
+							aTrack_T.storeAdapterSequence(r1, insert);
+							aTrack_T.storeAdapterSequence(r2, insert);
 						}
 					}
 				}
@@ -1127,12 +1159,7 @@ public class TestFormat {
 		void addBarcode(Read r){
 			String code=r.barcode(false);
 			if(code==null){return;}
-			Barcode bc=barcodes_T.get(code);
-			if(bc==null){
-				bc=new Barcode(code);
-				barcodes_T.put(code, bc);
-			}
-			bc.increment();
+			barcodeStats_T.increment(code, 1);
 		}
 		
 		boolean parseZmwT=false;
@@ -1166,7 +1193,9 @@ public class TestFormat {
 		private int minLen_T=Integer.MAX_VALUE;
 		private int maxLen_T=0;
 		
-		private HashMap<String, Barcode> barcodes_T=new HashMap<String, Barcode>();
+//		private HashMap<String, Barcode> barcodes_T=new HashMap<String, Barcode>();
+		private BarcodeStats barcodeStats_T=barcodeStats.copySpecial();
+		private AdapterTracker aTrack_T=new AdapterTracker();
 		private ArrayList<String> invalidHeaders_T=new ArrayList<String>();
 		private final SketchMakerMini smm_T;
 
@@ -1176,6 +1205,7 @@ public class TestFormat {
 //		private final BitSet zmwsT=new BitSet(8192);
 		private IntHashMapBinary zmwMapT=new IntHashMapBinary(2048);
 		
+		private final BandedAlignerConcrete bandy=(BarcodeStats.calcEdist ? new BandedAlignerConcrete(35) : null);
 	}
 	
 	/*--------------------------------------------------------------*/
@@ -1217,7 +1247,6 @@ public class TestFormat {
 	private IntHashMapBinary zmwMap=new IntHashMapBinary(2048);
 	private boolean parseZmw=true;
 	
-	private HashMap<String, Barcode> barcodes=new HashMap<String, Barcode>();
 	private ArrayList<String> invalidHeaders=new ArrayList<String>();
 	private final SketchTool tool;
 	private final SketchMakerMini smm;
@@ -1225,6 +1254,13 @@ public class TestFormat {
 
 	private final byte initialQin;
 	private final boolean initialDetectQuality;
+
+//	private HashMap<String, Barcode> barcodes=new HashMap<String, Barcode>();
+	private int barcodesPerRead;
+	private byte barcodeDelimiter;
+	private BarcodeStats barcodeStats;
+	
+	private AdapterTracker aTrack=new AdapterTracker();
 	
 	/*--------------------------------------------------------------*/
 
@@ -1274,8 +1310,13 @@ public class TestFormat {
 	private String gchistFile="gchist.txt";
 	private String zmwhistFile="zmwhist.txt";
 	
-	private String barcodeFile="barcodes.txt";
+	private String adapterFile="adapters.fa";
+
+	private String firstHeader=null;
+	
+	private String barcodeFile="barcode#.txt";
 	private String junkFile="junk.txt";
+	private String expectedCodeFile=null;//List of expected barcodes
 	
 	/*--------------------------------------------------------------*/
 
