@@ -10,10 +10,10 @@ import fileIO.TextStreamWriter;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
