@@ -423,6 +423,14 @@ public abstract class AbstractKmerTable {
 		return tables;
 	}
 	
+	public static final long makeMiddleMask(int k, boolean amino){
+		final boolean odd=((k&1)==1);
+		final int bitsPerSymbol=(amino ? 5 : 2);
+		final int shift=bitsPerSymbol*((k-1)/2);
+		final long middle=~((-1L)<<(odd ? bitsPerSymbol : 2*bitsPerSymbol));
+		return ~(middle<<shift);
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------        Nested Classes        ----------------*/
 	/*--------------------------------------------------------------*/
