@@ -56,6 +56,7 @@ public abstract class AbstractKmerTableSet {
 			}else if(a.equals("onepass")){
 			}else if(a.equals("passes")){
 			}else if(a.equals("rcomp")){
+			}else if(a.equals("maskmiddle")){
 			}else if(a.equals("filtermemory") || a.equals("prefiltermemory") || a.equals("filtermem")){
 			}else{
 				return false;
@@ -144,6 +145,7 @@ public abstract class AbstractKmerTableSet {
 	public final KCountArray makePrefilter(final KCountArray[] filter, Timer ht){
 //		assert(false) : lastFilter+", "+prefilter+", "+filterMax()+", "+currentPass+", "+filterMemory(currentPass);
 		if(!prefilter){return null;}
+		assert(!MASK_MIDDLE) : "TODO: MaskMiddle not yet supported by prefilter.";
 		
 		if(filter[0]!=null){
 			filter[0].purgeFilter();
@@ -527,6 +529,7 @@ public abstract class AbstractKmerTableSet {
 	
 	/** IIRC this has to do with allowing 32-mers */
 	public static boolean MASK_CORE=false;
+	public static boolean MASK_MIDDLE=false;
 	public static boolean FAST_FILL=true;
 	
 }
