@@ -12,7 +12,6 @@ import fileIO.ReadWrite;
 import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -21,6 +20,7 @@ import stream.ConcurrentReadOutputStream;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Increased sensitivity to nearby adapters.
