@@ -241,10 +241,10 @@ public class AnalyzeGenes {
 		double gpnano=genes/(double)elapsed;
 		double fpnano=files/(double)elapsed;
 
-		String rstring=Tools.padKM(reads, pad);
-		String bstring=Tools.padKM(bases, pad);
-		String gstring=Tools.padKM(genes, pad);
-		String fstring=Tools.padKM(files, pad);
+		String rstring=Tools.padKMB(reads, pad);
+		String bstring=Tools.padKMB(bases, pad);
+		String gstring=Tools.padKMB(genes, pad);
+		String fstring=Tools.padKMB(files, pad);
 		ByteBuilder sb=new ByteBuilder();
 		sb.append("Files Processed:    ").append(fstring).append(String.format(Locale.ROOT, " \t%.2f  files/sec", fpnano*1000000000)).append('\n');
 		sb.append("Sequences Processed:").append(rstring).append(String.format(Locale.ROOT, " \t%.2fk seqs/sec", rpnano*1000000)).append('\n');
