@@ -4,6 +4,7 @@ import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Locale;
 
 import dna.AminoAcid;
 import dna.Data;
@@ -12,20 +13,22 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import gff.CompareGff;
+import gff.GffLine;
 import jgi.BBMerge;
 import json.JsonObject;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
 import stream.ConcurrentReadInputStream;
 import stream.ConcurrentReadOutputStream;
 import stream.Read;
+import stream.ReadInputStream;
 import structures.ByteBuilder;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * This is the executable class for gene-calling.
@@ -130,7 +133,8 @@ public class CallGenes extends ProkObject {
 //			outstream.println(arg+", "+a+", "+b);
 			if(PGMTools.parseStatic(arg, a, b)){
 				//do nothing
-			}else if(a.equals("in") || a.equals("infna") || a.equals("fnain") || a.equals("fna")){
+			}else if(a.equals("in") || a.equals("infna") || 
+					a.equals("fnain") || a.equals("fna") || a.equals("ref")){
 				assert(b!=null);
 				Tools.addFiles(b, fnaList);
 			}else if(b==null && new File(arg).exists() && FileFormat.isFastaFile(arg)){
@@ -144,7 +148,7 @@ public class CallGenes extends ProkObject {
 					Tools.addFiles(b, pgmList);
 				}
 			}else if(b==null && new File(arg).exists() && FileFormat.isPgmFile(arg)){
-				Tools.addFiles(arg, pgmList);
+				pgmList.add(b);
 			}else if(a.equals("outamino") || a.equals("aminoout") || a.equals("outa") || a.equals("outaa") || a.equals("aaout") || a.equals("amino")){
 				outAmino=b;
 			}else if(a.equalsIgnoreCase("out16s") || a.equalsIgnoreCase("16sout")){
@@ -155,6 +159,8 @@ public class CallGenes extends ProkObject {
 				verbose=Parse.parseBoolean(b);
 				//ReadWrite.verbose=verbose;
 				GeneCaller.verbose=verbose;
+			}else if(a.equalsIgnoreCase("ingff") || a.equalsIgnoreCase("gffin")){
+				Tools.addFiles(b, inGffList);
 			}
 			
 			else if(a.equals("json_out") || a.equalsIgnoreCase("json")){
@@ -175,8 +181,16 @@ public class CallGenes extends ProkObject {
 				merge=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
 				ecco=Parse.parseBoolean(b);
+			}else if(a.equals("2pass") || a.equals("twopass")){
+				if(Parse.parseBoolean(b)) {passes=2;}
+			}else if(a.equals("passes")){
+				passes=Integer.parseInt(b);
 			}
 
+			else if(a.equals("extended") || a.equals("extendedstats") || a.equals("verbosestats")){
+				extendedStats=Parse.parseBoolean(b);
+			}
+			
 			else if(a.equalsIgnoreCase("setbias16s")) {
 				GeneCaller.biases[r16S]=Float.parseFloat(b);
 			}else if(a.equalsIgnoreCase("setbias18s")) {
@@ -361,7 +375,7 @@ public class CallGenes extends ProkObject {
 	/** Create read streams and process all data */
 	void process(Timer t){
 		
-		GeneModel pgm=PGMTools.loadAndMerge(pgmList);
+		final GeneModel pgm0=PGMTools.loadAndMerge(pgmList);
 		
 		if(call16S || call18S || call23S || calltRNA || call5S){
 			loadLongKmers();
@@ -385,10 +399,14 @@ public class CallGenes extends ProkObject {
 		readsIn=genesOut=0;
 		basesIn=bytesOut=0;
 		
-		for(String fname : fnaList){
+		for(int fnum=0; fnum<fnaList.size(); fnum++){
+			final String fna=fnaList.get(fnum);
+			String gffIn=(inGffList!=null && !inGffList.isEmpty()) ? inGffList.set(fnum, null) : null;
 			//Create a read input stream
-			final ConcurrentReadInputStream cris=makeCris(fname);
-
+			final GeneModel pgm=makeMultipassModel(pgm0, fna, gffIn, passes/*, maxReads*/);
+			
+			final ConcurrentReadInputStream cris=makeCris(fna);
+			
 			//Process the reads in separate threads
 			spawnThreads(cris, bsw, rosAmino, ros16S, ros18S, pgm);
 			
@@ -446,10 +464,14 @@ public class CallGenes extends ProkObject {
 		bsw.start();
 		
 		if(callCDS){
-			bsw.println("Gene Starts Made:     \t "+Tools.padLeft(geneStartsMade, 12));
-			bsw.println("Gene Stops Made:      \t "+Tools.padLeft(geneStopsMade, 12));
-			bsw.println("Gene Starts Retained: \t "+Tools.padLeft(geneStartsRetained, 12));
-			bsw.println("Gene Stops Retained:  \t "+Tools.padLeft(geneStopsRetained, 12));
+			if(extendedStats || verbose) {
+				bsw.println("Gene Starts Made:     \t "+Tools.padLeft(geneStartsMade, 12));
+				bsw.println("Gene Stops Made:      \t "+Tools.padLeft(geneStopsMade, 12));
+				bsw.println("Gene Starts Retained: \t "+Tools.padLeft(geneStartsRetained, 12));
+				bsw.println("Gene Stops Retained:  \t "+Tools.padLeft(geneStopsRetained, 12));
+			}
+			bsw.print("Approx Coding Fraction:\t ");
+			bsw.print(Tools.padLeft(String.format(Locale.ROOT, "%.4f", Tools.min(1.0, stCdsPass.lengthSum/(double)basesIn)), 12)).nl();
 			bsw.println("CDS Out:              \t "+Tools.padLeft(geneStartsOut, 12));
 		}
 		if(call16S){bsw.println("16S Out:              \t "+Tools.padLeft(r16SOut, 12));}
@@ -458,40 +480,47 @@ public class CallGenes extends ProkObject {
 		if(call5S){bsw.println("5S Out:               \t "+Tools.padLeft(r5SOut, 12));}
 		if(calltRNA){bsw.println("tRNA Out:             \t "+Tools.padLeft(tRNAOut, 12));}
 		
-		if(callCDS){
-			bsw.println();
-			bsw.println("All ORF Stats:");
-			bsw.print(stCds.toString());
+		if(extendedStats || verbose) {
+			if(callCDS){
+				bsw.println();
+				bsw.println("All ORF Stats:");
+				bsw.print(stCds.toString());
 
-			bsw.println();
-			bsw.println("Retained ORF Stats:");
-			bsw.print(stCds2.toString());
+				//			bsw.println();
+				//			bsw.println("Retained ORF Stats:");
+				//			bsw.print(stCds2.toString());
 
-			bsw.println();
-			bsw.println("Called ORF Stats:");
-			stCdsPass.genomeSize=basesIn;
-			bsw.print(stCdsPass.toString());
-		}
+				bsw.println();
+				bsw.println("Called ORF Stats:");
+				stCdsPass.genomeSize=basesIn;
+				bsw.print(stCdsPass.toString());
+			}
 
-		if(call16S){
-			bsw.println();
-			bsw.println("Called 16S Stats:");
-			bsw.print(st16s.toString());
-		}
-		if(call23S){
-			bsw.println();
-			bsw.println("Called 23S Stats:");
-			bsw.print(st23s.toString());
-		}
-		if(call5S){
-			bsw.println();
-			bsw.println("Called 5S Stats:");
-			bsw.print(st5s.toString());
-		}
-		if(call18S){
-			bsw.println();
-			bsw.println("Called 18S Stats:");
-			bsw.print(st18s.toString());
+			if(call16S && r16SOut>0){
+				bsw.println();
+				bsw.println("Called 16S Stats:");
+				bsw.print(st16s.toString());
+			}
+			if(call23S && r23SOut>0){
+				bsw.println();
+				bsw.println("Called 23S Stats:");
+				bsw.print(st23s.toString());
+			}
+			if(call5S && r5SOut>0){
+				bsw.println();
+				bsw.println("Called 5S Stats:");
+				bsw.print(st5s.toString());
+			}
+			if(call18S && r18SOut>0){
+				bsw.println();
+				bsw.println("Called 18S Stats:");
+				bsw.print(st18s.toString());
+			}
+			if(calltRNA && tRNAOut>0){
+				bsw.println();
+				bsw.println("Called tRNA Stats:");
+				bsw.print(sttRNA.toString());
+			}
 		}
 		bsw.poisonAndWait();
 	}
@@ -542,7 +571,7 @@ public class CallGenes extends ProkObject {
 		if(fname==null || geneHist==null){return;}
 		ByteStreamWriter bsw=new ByteStreamWriter(fname, overwrite, append, false);
 		bsw.start();
-		long sum=Tools.sum(geneHist);
+		long sum=shared.Vector.sum(geneHist);
 		double mean=Tools.averageHistogram(geneHist)*geneHistDiv;
 		int median=Tools.medianHistogram(geneHist)*geneHistDiv;
 		double std=Tools.standardDeviationHistogram(geneHist)*geneHistDiv;
@@ -651,6 +680,67 @@ public class CallGenes extends ProkObject {
 		if(!success){errorState=true;}
 	}
 	
+	/*--------------------------------------------------------------*/
+	/*----------------          Multipass           ----------------*/
+	/*--------------------------------------------------------------*/
+	
+	public static GeneModel makeMultipassModel(GeneModel pgm0, String fna, String gff, int passes/*, long maxReads*/) {
+		ArrayList<Read> reads=ReadInputStream.toReads(fna, FileFormat.FASTA, -1/*maxReads*/);
+		return makeMultipassModel(pgm0, reads, gff, passes);
+	}
+	
+	public static GeneModel makeMultipassModel(GeneModel pgm0, ArrayList<Read> reads, String gff, int passes) {
+		GeneModel pgm=pgm0;
+		for(int i=1; i<passes; i++) {
+			pgm=runOnePass(reads, gff, pgm);
+			if(i==1 && passes==2) {//only pass for 2-pass
+				pgm=PGMTools.mix(0.50, 0.10, 0.10, true, pgm0, pgm);
+			}else if(i==passes-1) {//final pass for 3+ passes
+				pgm=PGMTools.mix(0.50, 0.12, 0.12, true, pgm0, pgm);
+			}else if(i==1 && passes>2) {//first pass for 3+ passes
+				pgm=PGMTools.mix(0.10, 0.01, 0.01, true, pgm0, pgm);
+			}else {//middle pass for 4+ passes
+				pgm=PGMTools.mix(0.20, 0.02, 0.02, true, pgm0, pgm);
+			}
+		}
+		return pgm;
+	}
+	
+	/** This needs a pgm OR a gff, not both */
+	public static GeneModel runOnePass(String fna, String gff, GeneModel pgm0/*, long maxReads*/) {//TODO: Make this multithreaded
+		ArrayList<Read> reads=ReadInputStream.toReads(fna, FileFormat.FASTA, -1/*maxReads*/);
+		return runOnePass(reads, gff, pgm0);
+	}
+	
+	/** This needs a pgm OR a gff, not both */
+	public static GeneModel runOnePass(ArrayList<Read> reads, String gff, GeneModel pgm0) {//TODO: Make this multithreaded
+		GeneCaller caller=new GeneCaller(minLen, maxOverlapSameStrand, maxOverlapOppositeStrand, 
+				minStartScore, minStopScore, minKmerScore, minOrfScore, minAvgScore, pgm0);
+		
+		final ArrayList<GffLine> cds, rrna, trna;
+		if(gff!=null && !"null".equalsIgnoreCase(gff)) {
+			ArrayList<GffLine>[] allGffLines=GffLine.loadGffFileByType(gff, "CDS,rRNA,tRNA", true);
+			cds=allGffLines[0];
+			rrna=allGffLines[1];
+			trna=allGffLines[2];
+//			System.err.println("Loaded "+cds.size()+" CDSs");
+		}else {
+			ArrayList<Orf> orfs=caller.callGenes(reads);
+			ArrayList<GffLine>[] allGffLines=Orf.toGffLinesByType(orfs, "CDS,rRNA,tRNA");
+			cds=allGffLines[0];
+			rrna=allGffLines[1];
+			trna=allGffLines[2];
+//			System.err.println("Called "+cds.size()+" CDSs");
+		}
+		
+		GeneModel pgm=new GeneModel(true);
+		pgm.process(reads, cds, rrna, trna);
+		for(StatsContainer sc : pgm.allContainers) {
+			sc.calculate();//Not sure if this is needed...
+		}
+		return pgm;
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------        Inner Methods         ----------------*/
 	/*--------------------------------------------------------------*/
@@ -830,7 +920,7 @@ public class CallGenes extends ProkObject {
 		 * @return True if the reads should be kept, false if they should be discarded.
 		 */
 		ArrayList<Orf> processRead(final Read r){
-			ArrayList<Orf> list=caller.callGenes(r, pgm);
+			ArrayList<Orf> list=caller.callGenes(r, pgm, true);
 			
 			if(geneHistT!=null && list!=null){
 				for(Orf o : list){
@@ -980,6 +1070,21 @@ public class CallGenes extends ProkObject {
 		return r;
 	}
 	
+	public static ArrayList<Read> fetch(final Read r, final ArrayList<Orf> list){
+		if(list==null || list.isEmpty()){return null;}
+		ArrayList<Read> genes=new ArrayList<Read>(list.size());
+		for(int strand=0; strand<2; strand++){
+			for(Orf orf : list){
+				if(orf.strand==strand && orf.type==CDS){
+					Read gene=fetch(orf, r.bases, r.id);
+					genes.add(gene);
+				}
+			}
+			r.reverseComplement();
+		}
+		return genes.isEmpty() ? null : genes;
+	}
+	
 	public static Read fetch(Orf orf, Read source){
 		assert(orf.start>=0 && orf.stop<source.length()) : source.length()+"\n"+orf;
 		if(orf.strand==1){source.reverseComplement();}
@@ -1036,6 +1141,7 @@ public class CallGenes extends ProkObject {
 	private long maxReads=-1;
 	private boolean merge;
 	private boolean ecco;
+	private int passes=1;
 	
 	private long readsIn=0;
 	private long basesIn=0;
@@ -1092,6 +1198,7 @@ public class CallGenes extends ProkObject {
 
 	private ArrayList<String> fnaList=new ArrayList<String>();
 	private ArrayList<String> pgmList=new ArrayList<String>();
+	private ArrayList<String> inGffList=new ArrayList<String>();
 	private String outGff=null;
 	private String outAmino=null;
 	private String out16S=null;
@@ -1126,6 +1233,7 @@ public class CallGenes extends ProkObject {
 	
 	private PrintStream outstream=System.err;
 	public boolean verbose=false;
+	public boolean extendedStats=false;
 	public boolean errorState=false;
 	private boolean overwrite=false;
 	private boolean append=false;
