@@ -12,7 +12,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -25,6 +24,7 @@ import stream.Read;
 import structures.ListNum;
 import tax.TaxNode;
 import tax.TaxTree;
+import tracker.ReadStats;
 
 /**
  * Removes unwanted sequences from Silva, particularly bacteria flagged as euks due to name misidentification.
