@@ -9,6 +9,7 @@ import aligner.SingleStateAlignerFlat2;
 import aligner.SingleStateAlignerFlat3;
 import aligner.SingleStateAlignerFlatFloat;
 import dna.AminoAcid;
+import gff.GffLine;
 import shared.KillSwitch;
 import shared.Tools;
 import stream.Read;
@@ -48,11 +49,24 @@ public class GeneCaller extends ProkObject {
 	/*----------------         Outer Methods        ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	public ArrayList<Orf> callGenes(Read r){
-		return callGenes(r, pgm);
+	public ArrayList<Orf> callGenes(ArrayList<Read> reads){
+		ArrayList<Orf> orfs=new ArrayList<Orf>();
+		for(Read r : reads) {
+			ArrayList<Orf> list=callGenes(r);
+			if(list!=null) {orfs.addAll(list);}
+		}
+		return orfs;
 	}
 	
-	public ArrayList<Orf> callGenes(Read r, GeneModel pgm_){
+	public ArrayList<Orf> callGenes(Read r){
+		return callGenes(r, pgm, true);
+	}
+	
+	public ArrayList<Orf> callGenes(Read r, boolean breakOrfs){
+		return callGenes(r, pgm, breakOrfs);
+	}
+	
+	public ArrayList<Orf> callGenes(Read r, GeneModel pgm_, boolean breakOrfs){
 		pgm=pgm_;
 		
 		final String name=r.id;
@@ -61,17 +75,25 @@ public class GeneCaller extends ProkObject {
 		//Lists of all longest orfs per frame
 		ArrayList<Orf>[] frameLists=makeOrfs(name, bases, minLen);
 		//Lists of all high-scoring orfs per frame, with potentially multiple orfs sharing stops.
-		ArrayList<Orf>[] brokenLists=breakOrfs(frameLists, bases);
+		ArrayList<Orf>[] brokenLists=(breakOrfs ? breakOrfs(frameLists, bases) : frameLists);
+		if(!breakOrfs) {
+			for(int i=0; i<brokenLists.length; i++) {
+				if(brokenLists[i]==null) {brokenLists[i]=new ArrayList<Orf>(1);}
+			}
+		}
 		
 		ArrayList<Orf>[] rnaLists=null;
 		final int rlen=r.length();
 		if(calltRNA || (call16S && rlen>800) || (call23S && rlen>1500) || call5S || (call18S && rlen>1000)){
 			rnaLists=makeRnas(name, bases);
-
-			brokenLists[0].addAll(rnaLists[0]);
-			brokenLists[3].addAll(rnaLists[1]);
-			Collections.sort(brokenLists[0]);
-			Collections.sort(brokenLists[3]);
+			if(rnaLists[0]!=null && !rnaLists[0].isEmpty()) {
+				brokenLists[0].addAll(rnaLists[0]);
+				Collections.sort(brokenLists[0]);
+			}
+			if(rnaLists[1]!=null && !rnaLists[1].isEmpty()) {
+				brokenLists[3].addAll(rnaLists[1]);
+				Collections.sort(brokenLists[3]);
+			}
 		}
 		
 		boolean printAllOrfs=false;
@@ -82,6 +104,7 @@ public class GeneCaller extends ProkObject {
 				temp.addAll(broken);
 			}
 			Collections.sort(temp);
+//			System.err.print(temp.size()+"; ");
 			return temp;
 		}
 		
@@ -191,10 +214,12 @@ public class GeneCaller extends ProkObject {
 	 * */
 	static ArrayList<Orf>[] makeOrfs(String name, byte[] bases, int minlen){
 		@SuppressWarnings("unchecked")
+		int orfs=0;
 		ArrayList<Orf>[] array=new ArrayList[6];
 		for(int strand=0; strand<2; strand++){
 			for(int frame=0; frame<3; frame++){
 				ArrayList<Orf> list=makeOrfsForFrame(name, bases, frame, strand, minlen);
+				orfs+=(list==null ? 0 : list.size());
 				array[frame+3*strand]=list;
 				if(strand==1 && list!=null){
 					for(Orf orf : list){
@@ -206,6 +231,7 @@ public class GeneCaller extends ProkObject {
 			}
 			AminoAcid.reverseComplementBasesInPlace(bases);
 		}
+//		System.err.print("orfs="+orfs+", ");
 		return array;
 	}
 	
@@ -497,7 +523,8 @@ public class GeneCaller extends ProkObject {
 				orfs.add(f);
 			}
 		}
-		
+
+//		System.err.print(" *"+orfs.size()+"* ");
 		return orfs;
 	}
 	
@@ -1097,12 +1124,14 @@ public class GeneCaller extends ProkObject {
 		}
 		
 		//Sort to by score descending to eliminate low-scoring copies. 
-		if(broken.size()>1){Collections.sort(broken, Feature.featureComparatorScore);}
+		if(broken.size()>1){Collections.sort(broken, PFeature.featureComparatorScore);}
 		
 		int removed=0;
 		for(int i=0; i<size; i++){//Fix scores because they were generated together, from start to stop, to make this O(N) instead of O(N^2).
 			Orf orf=broken.get(i);
-			if(orf.averageKmerScore()<minInnerScore || orf.orfScore<minOrfScore || 
+			if(keepAtLeastOneOrf && i==0) {
+				//skip
+			}else if(orf.averageKmerScore()<minInnerScore || orf.orfScore<minOrfScore || 
 					orf.orfScore/orf.length()<minAvgScore || 
 					orf.orfScore<0.5f*best.orfScore-10 || (orf.startScore<bestStart.startScore-0.55f && orf.kmerScore<best.kmerScore*1.1f && orf!=best)){
 				broken.set(i, null);
@@ -1123,6 +1152,60 @@ public class GeneCaller extends ProkObject {
 		return broken;
 	}
 	
+	/**
+	 * Return a score of how well this sequence matches a feature based on inner kmer frequencies.
+	 * Intended to see whether a short read matches a feature, or which side matches better.
+	 * Generally this would be called twice, with bases being reverse-complemented in between.
+	 * @param bases Bases, oriented on the intended strand.
+	 * @param type Type of feature, e.g. ProkObject.CDS.
+	 * @return Average score of best-scoring frame for this strand.
+	 */
+	public float scoreFeature(byte[] bases, int type){
+		assert(pgm!=null) : pgm;
+		StatsContainer sc=pgm.allContainers[type];
+		assert(sc!=null) : type+", "+pgm;
+		final FrameStats innerStats=pgm.allContainers[type].inner;
+		assert(innerStats!=null) : sc;
+		assert(innerStats.k>0) : innerStats;
+		final int frames=(type==CDS ? 3 : 1);
+		
+		final int k=innerStats.k;
+		final int mask=~((-1)<<(2*k));
+		
+		int codon=0;
+		int kmer=0;
+		int len=0;
+		int numKmers=0;
+		float[] frameScores=new float[frames];
+		for(int pos=0, currentFrame=0; pos<bases.length; pos++){
+			final byte b=bases[pos];
+			final int x=AminoAcid.baseToNumber[b];
+			codon=((codon<<2)|x);
+			kmer=((kmer<<2)|x)&mask;
+			
+			if(x>=0){
+				len++;
+				if(len>=k){
+					for(int frame2=0; frame2<frames; frame2++) {
+						int frame=(currentFrame+frame2)%frames;
+						float prob=innerStats.probs[frame][kmer];
+//						float dif=prob-0.99f;//Prob above 1 is more likely than average
+						frameScores[frame]+=prob;
+						numKmers++;
+					}
+				}
+			}else{
+				len=0;
+				kmer=0;
+			}
+			
+			currentFrame++;
+			if(currentFrame>2){currentFrame=0;}
+		}
+//		System.err.println(Arrays.toString(frameScores));
+		return (Tools.max(frameScores)*frames)/Tools.max(1, numKmers);
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
@@ -1288,6 +1371,8 @@ public class GeneCaller extends ProkObject {
 		}
 		return ssa;
 	}
+	
+	public boolean keepAtLeastOneOrf=false;
 
 	private static ThreadLocal<SingleStateAlignerFlat2> localSSA=new ThreadLocal<SingleStateAlignerFlat2>();
 	private static ThreadLocal<SingleStateAlignerFlat3> localSSA3=new ThreadLocal<SingleStateAlignerFlat3>();
