@@ -70,8 +70,6 @@ public class GeneModel extends ProkObject {
 	/*--------------------------------------------------------------*/
 	
 	public boolean process(String genomeFname, String gffFname){
-//		fnames.add(ReadWrite.stripPath(genomeFname));
-		numFiles++;
 		FileFormat fnaFile=FileFormat.testInput(genomeFname, FileFormat.FA, null, true, true);
 		FileFormat gffFile=FileFormat.testInput(gffFname, FileFormat.GFF, null, true, true);
 		
@@ -79,23 +77,36 @@ public class GeneModel extends ProkObject {
 			errorState=true;
 			return true;
 		}
+		
+		ArrayList<Read> reads=ReadInputStream.toReads(fnaFile, maxReads);
+		ArrayList<GffLine>[] allGffLines=GffLine.loadGffFileByType(gffFile, "CDS,rRNA,tRNA", true);
+		ArrayList<GffLine> cds=allGffLines[0];
+		ArrayList<GffLine> rrna=allGffLines[1];
+		ArrayList<GffLine> trna=allGffLines[2];
+
+		return process(reads, cds, rrna, trna);
+	}
+	
+	public boolean process(ArrayList<Read> genome, 
+			ArrayList<GffLine> cds, ArrayList<GffLine> rrna, ArrayList<GffLine> trna){
+		numFiles++;
+		
+		if(genome==null || cds==null){
+			errorState=true;
+			return true;
+		}
 		filesProcessed++;
 		
 		ArrayList<ScafData> scafList;
 		{//Scoped to save memory
-			ArrayList<Read> reads=ReadInputStream.toReads(fnaFile, maxReads);
-			readsProcessed+=reads.size();
-			scafList=new ArrayList<ScafData>(reads.size());
-			for(Read r : reads){
+			readsProcessed+=genome.size();
+			scafList=new ArrayList<ScafData>(genome.size());
+			for(Read r : genome){
 				basesProcessed+=r.length();
 				scafList.add(new ScafData(r));
 			}
 		}
 		{//Scoped to save memory
-			ArrayList<GffLine>[] allGffLines=GffLine.loadGffFileByType(gffFile, "CDS,rRNA,tRNA", true);
-			ArrayList<GffLine> cds=allGffLines[0];
-			ArrayList<GffLine> rrna=allGffLines[1];
-			ArrayList<GffLine> trna=allGffLines[2];
 			genesProcessed+=cds.size();
 			genesProcessed+=(rrna==null ? 0 : rrna.size());
 			genesProcessed+=(trna==null ? 0 : trna.size());
@@ -124,10 +135,17 @@ public class GeneModel extends ProkObject {
 		return false;
 	}
 	
+	public static boolean ADD_CDS_ONLY=false;//Sometimes merging in a custom model messes up non-CDS numbers
 	public void add(GeneModel pgm){
-		for(int i=0; i<allContainers.length; i++){
-//			System.err.println("merging "+allContainers[i].name);
-			allContainers[i].add(pgm.allContainers[i]);
+		if(ADD_CDS_ONLY && readsProcessed>0) {
+//			System.err.println("Adding CDS; readsProcessed="+readsProcessed+", ADD_CDS_ONLY="+ADD_CDS_ONLY);
+			statsCDS.add(pgm.statsCDS);
+		}else {
+//			System.err.println("Adding all; readsProcessed="+readsProcessed+", ADD_CDS_ONLY="+ADD_CDS_ONLY);
+			for(int i=0; i<allContainers.length; i++){
+//				System.err.println("merging "+allContainers[i].name);
+				allContainers[i].add(pgm.allContainers[i]);
+			}
 		}
 		
 		readsProcessed+=pgm.readsProcessed;
