@@ -3,6 +3,7 @@ package prok;
 import java.util.ArrayList;
 
 import fileIO.ByteFile;
+import shared.Parse;
 import shared.Tools;
 
 public class GeneModelParser {
@@ -174,11 +175,11 @@ public class GeneModelParser {
 	}
 	private static int parseInt(byte[] line){
 		int idx=Tools.indexOf(line, '\t');
-		return Tools.parseInt(line, idx+1, line.length);
+		return Parse.parseInt(line, idx+1, line.length);
 	}
 	private static long parseLong(byte[] line){
 		int idx=Tools.indexOf(line, '\t');
-		return Tools.parseLong(line, idx+1, line.length);
+		return Parse.parseLong(line, idx+1, line.length);
 	}
 	
 //	public static void parseHeaderStatic(byte[] line){
