@@ -13,7 +13,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -26,6 +25,7 @@ import structures.ListNum;
 import tax.GiToTaxid;
 import template.Accumulator;
 import template.ThreadWaiter;
+import tracker.ReadStats;
 
 /**
  * Picks one ribosomal (16S) sequence per taxID.
