@@ -1,6 +1,10 @@
 package prok;
 
+import java.util.ArrayList;
+import java.util.HashMap;
+
 import dna.AminoAcid;
+import gff.GffLine;
 import shared.Shared;
 import shared.Tools;
 import structures.ByteBuilder;
@@ -13,7 +17,7 @@ import structures.ByteBuilder;
  * @date Sep 20, 2018
  *
  */
-public class Orf extends Feature {
+public class Orf extends PFeature {
 	
 	/*--------------------------------------------------------------*/
 	/*----------------        Initialization        ----------------*/
@@ -114,6 +118,37 @@ public class Orf extends Feature {
 	/*----------------           ToString           ----------------*/
 	/*--------------------------------------------------------------*/
 	
+	/**
+	 * @param orfs A list of called features
+	 * @param types Types of features to retain, e.g. "CDS,rRNA,tRNA"
+	 * @return GffLines subdivided by type
+	 */
+	public static ArrayList<GffLine>[] toGffLinesByType(ArrayList<Orf> orfs, String types){
+		String[] typeArray=types.split(",");
+		@SuppressWarnings("unchecked")
+		ArrayList<GffLine>[] lists=new ArrayList[typeArray.length];
+		HashMap<String, ArrayList<GffLine>> map=new HashMap<String, ArrayList<GffLine>>(3*typeArray.length);
+		for(int i=0; i<typeArray.length; i++){
+			String type=typeArray[i];
+			lists[i]=new ArrayList<GffLine>();
+			map.put(type,  lists[i]);
+		}
+		for(Orf orf : orfs){
+			String type=ProkObject.typeStrings2[orf.type];
+			ArrayList<GffLine> glist=map.get(type);
+			if(glist!=null) {
+				glist.add(new GffLine(orf));
+			}
+		}
+		return lists;
+	}
+	
+	public static ArrayList<GffLine> toGffLines(ArrayList<Orf> orfs){
+		ArrayList<GffLine> list=new ArrayList<GffLine>(orfs.size());
+		for(Orf orf : orfs){list.add(new GffLine(orf));}
+		return list;
+	}
+	
 	public String toStringFlipped(){
 		if(strand==flipped()){
 			return toString();
@@ -177,17 +212,12 @@ public class Orf extends Feature {
 		return bb;
 	}
 	
-	public boolean isSSU(){
-		return type==r16S || type==r18S;
-	}
-	
-	public boolean is16S(){
-		return type==r16S;
-	}
-	
-	public boolean is18S(){
-		return type==r18S;
-	}
+	public boolean isSSU(){return type==r16S || type==r18S;}
+	public boolean is16S(){return type==r16S;}
+	public boolean is18S(){return type==r18S;}
+	public boolean isCDS(){return type==CDS;}
+	public boolean isRRNA(){return type==r18S || type==r16S || type==r5S || type==r23S;}
+	public boolean isTRNA(){return type==tRNA;}
 	
 	/*--------------------------------------------------------------*/
 	/*----------------          Overrides           ----------------*/
