@@ -13,7 +13,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -27,6 +26,7 @@ import structures.ListNum;
 import structures.LongHashSet;
 import template.Accumulator;
 import template.ThreadWaiter;
+import tracker.ReadStats;
 
 /**
  * Makes a consensus ribosomal sequence using raw reads as input.
