@@ -11,7 +11,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -22,6 +21,7 @@ import stream.Read;
 import structures.ListNum;
 import template.Accumulator;
 import template.ThreadWaiter;
+import tracker.ReadStats;
 
 /**
  * Splits a mix of ribosomal sequences (such as Silva) into different files per type (16S, 18S, etc).
@@ -276,8 +276,8 @@ public class SplitRibo implements Accumulator<SplitRibo.ProcessThread> {
 		//Reset read validation
 		Read.VALIDATE_IN_CONSTRUCTOR=vic;
 
-		long readsOut2=Tools.sum(readsOut)-readsOut[0];
-		long basesOut2=Tools.sum(basesOut)-basesOut[0];
+		long readsOut2=shared.Vector.sum(readsOut)-readsOut[0];
+		long basesOut2=shared.Vector.sum(basesOut)-basesOut[0];
 		
 		//Report timing and results
 		t.stop();
