@@ -21,6 +21,7 @@ import fileIO.TextFile;
 import jgi.BBMerge;
 import jgi.CalcTrueQuality;
 import kmer.AbstractKmerTable;
+import ml.CellNet;
 import sketch.SketchObject;
 import stream.ConcurrentDepot;
 import stream.ConcurrentReadInputStream;
@@ -31,9 +32,10 @@ import stream.ReadStreamByteWriter;
 import stream.ReadStreamWriter;
 import stream.SamLine;
 import stream.SamStreamer;
-import structures.EntropyTracker;
 import structures.IntList;
 import tax.TaxTree;
+import tracker.EntropyTracker;
+import tracker.ReadStats;
 import var2.CallVariants;
 
 /**
@@ -169,6 +171,15 @@ public class Parser {
 		return true;
 	}
 	
+	public boolean parseK(String arg, String a, String b){
+		if(a.equalsIgnoreCase("k")){
+			k=Integer.parseInt(b);
+		}else{
+			return false;
+		}
+		return true;
+	}
+	
 	public boolean parseInterleaved(String arg, String a, String b){
 		if(a.equals("testinterleaved")){
 			FASTQ.TEST_INTERLEAVED=Parse.parseBoolean(b);
@@ -657,8 +668,11 @@ public class Parser {
 			int x=Tools.mid(0, Integer.parseInt(b), 93);
 			Read.setMinCalledQuality((byte)x);
 		}else if(a.equals("t") || a.equals("threads")){
+			int old=Shared.threads();
 			Shared.setThreads(b);
-			if(!silent){System.err.println("Set threads to "+Shared.threads());}
+			if(!silent && printSetThreads && old!=Shared.threads()){
+				System.err.println("Set threads to "+Shared.threads());
+			}
 		}else if(a.equals("recalpairnum") || a.equals("recalibratepairnum")){
 			CalcTrueQuality.USE_PAIRNUM=Parse.parseBoolean(b);
 		}else if(a.equals("taxpath")){
@@ -667,7 +681,7 @@ public class Parser {
 			}else{
 				TaxTree.TAX_PATH=b.replaceAll("\\\\", "/");
 			}
-		}else if(a.equals("parallelsort")){
+		}else if(a.equals("parallelsort") || a.equals("paralellsort")){
 			boolean x=Parse.parseBoolean(b);
 			Shared.setParallelSort(x);
 		}else if(a.equals("gcbeforemem")){
@@ -680,8 +694,6 @@ public class Parser {
 			TaxTree.SILVA_MODE=Parse.parseBoolean(b);
 		}else if(a.equals("unite")){
 			TaxTree.UNITE_MODE=Parse.parseBoolean(b);
-		}else if(a.equals("parallelsort") || a.equals("paralellsort")){
-			Shared.parallelSort=Parse.parseBoolean(b);
 		}else if(a.equals("imghq")){
 			TaxTree.IMG_HQ=Parse.parseBoolean(b);
 		}
@@ -722,6 +734,15 @@ public class Parser {
 			Tools.FORCE_JAVA_PARSE_DOUBLE=Parse.parseBoolean(b);
 		}
 		
+		else if(a.equalsIgnoreCase("simd")){
+			Shared.SIMD=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("simdcopy")){
+			Vector.SIMDCOPY=Parse.parseBoolean(b);
+		}
+//		else if(a.equalsIgnoreCase("simdminlen")) {//Disabled.
+//			Vector.MINLEN=Integer.parseInt(b);
+//		}
+		
 		else if(a.equalsIgnoreCase("awsServers") || a.equalsIgnoreCase("aws")){
 			Shared.awsServers=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("nerscServers") || a.equalsIgnoreCase("nersc")){
@@ -758,6 +779,13 @@ public class Parser {
 				KmerCountAbstract.BUFFERED=Parse.parseBoolean(b);
 			}
 		}
+		
+		else if(a.equalsIgnoreCase("pairreads") && b!=null){
+			FASTQ.PAIR_READS=Parse.parseBoolean(b);
+		}else if(a.equalsIgnoreCase("flipr2")){
+			FASTQ.FLIP_R2=Parse.parseBoolean(b);
+		}
+		
 //		else if(a.equalsIgnoreCase("sortserial")){
 //			KmerCountAbstract.SORT_SERIAL=Parse.parseBoolean(b);
 //		}
@@ -901,10 +929,12 @@ public class Parser {
 			}
 		}else if(a.equals("entropyns") || a.equals("entropyhistns")){
 			ReadStats.allowEntropyNs=Parse.parseBoolean(b);
+		}else if(a.equals("barcodestats") || a.equals("barcodecounts")){
+			ReadStats.BARCODE_STATS_FILE=(b==null || b.equalsIgnoreCase("null") || b.equalsIgnoreCase("none")) ? null : b;
+			ReadStats.COLLECT_BARCODE_STATS=(ReadStats.BARCODE_STATS_FILE!=null);
 		}else if(a.equals("timehistogram") || a.equals("thist")){
 			ReadStats.TIME_HIST_FILE=(b==null || b.equalsIgnoreCase("null") || b.equalsIgnoreCase("none")) ? null : b;
 			ReadStats.COLLECT_TIME_STATS=(ReadStats.TIME_HIST_FILE!=null);
-			if(ReadStats.COLLECT_IDENTITY_STATS){System.err.println("Set identity histogram output to "+ReadStats.IDENTITY_HIST_FILE);}
 		}else if(a.equals("identityhistogram") || a.equals("idhist")){
 			ReadStats.IDENTITY_HIST_FILE=(b==null || b.equalsIgnoreCase("null") || b.equalsIgnoreCase("none")) ? null : b;
 			ReadStats.COLLECT_IDENTITY_STATS=(ReadStats.IDENTITY_HIST_FILE!=null);
@@ -1432,12 +1462,15 @@ public class Parser {
 	public String extin=null;
 	public String extout=null;
 	
+	public int k=31;
+	
 	/*--------------------------------------------------------------*/
 	/*----------------        Static Fields         ----------------*/
 	/*--------------------------------------------------------------*/
 	
 	public static String loglogType="LogLog2";
 	public static boolean silent=false;
+	public static boolean printSetThreads=true;
 	
 	private static boolean setTrimRname=false;
 	private static byte qin=-1;
