@@ -32,9 +32,11 @@ public class Shared {
 	public static boolean GENEPOOL=envContainsPair("NERSC_HOST", "genepool", false);//Probably deprecated
 	public static boolean DENOVO=envContainsPair("NERSC_HOST", "denovo", false);//Almost certainly deprecated
 	public static boolean CORI=envContainsPair("NERSC_HOST", "cori", false);
+	public static boolean PERLMUTTER=envContainsPair("NERSC_HOST", "perlmutter", false);
 	public static boolean NERSC=envContainsKey("NERSC_HOST");
 	public static boolean AWS=envContainsKey("EC2_HOME");
 	public static boolean IGBVM="taxonomy-vm".equals(HOSTNAME()) || "taxonomy-vm-2".equals(HOSTNAME());
+	public static boolean DORI=envContainsPair("SLURM_PARTITION", "dori", false);
 	public static boolean AMD64="amd64".equalsIgnoreCase(System.getProperty("os.arch"));
 
 	public static void setTaxServer(String path){
@@ -125,8 +127,8 @@ public class Shared {
 	public static final int GAPCOST=Tools.max(1, GAPLEN/64);
 	public static final byte GAPC='-';
 	
-	public static String BBMAP_VERSION_STRING="39.01";
-	public static String BBMAP_VERSION_NAME="Smoked Paprika";
+	public static String BBMAP_VERSION_STRING="39.06";
+	public static String BBMAP_VERSION_NAME="Tag Parse";
 	
 	public static boolean TRIM_READ_COMMENTS=false;
 	public static boolean TRIM_RNAME=false; //For mapped sam reads
@@ -162,14 +164,20 @@ public class Shared {
 	public static List<String> JVM_ARGS(){
 		return ManagementFactory.getRuntimeMXBean().getInputArguments();
 	}
-	
-	public static String fullCommandline(){
+
+	public static String fullCommandline(){return fullCommandline(true, true);}
+	public static String fullCommandline(boolean includeCP){return fullCommandline(includeCP, true);}
+	public static String fullCommandline(boolean includeCP, boolean includeArgs){
 		StringBuilder sb=new StringBuilder();
-		sb.append("java ");
-		for(String s : JVM_ARGS()) {
-			sb.append(s).append(' ');
+		if(includeArgs) {
+			sb.append("java ");
+			for(String s : JVM_ARGS()) {
+				sb.append(s).append(' ');
+			}
+		}
+		if(includeCP) {
+			sb.append("-cp "+System.getProperty("java.class.path")+" ");
 		}
-		sb.append("-cp "+System.getProperty("java.class.path")+" ");
 		sb.append(mainClass.getCanonicalName()).append(' ');
 		for(String s : COMMAND_LINE) {
 			sb.append(s).append(' ');
@@ -568,6 +576,19 @@ public class Shared {
 			KillSwitch.memKill(e);
 		}
 	}
+
+	public static final <T extends Comparable<? super T>> void sort(T[] array, Comparator<? super T> comparator){sort(array, 0, array.length, comparator);}
+	public static final <T extends Comparable<? super T>> void sort(T[] array, int from, int to, Comparator<? super T> comparator){
+		try {
+			if(!parallelSort || array.length<=parallelSortLength || THREADS<2){
+				Arrays.sort(array, from, to, comparator); //Supported in pre-Java 8.
+				return;
+			}
+			Arrays.parallelSort(array, from, to, comparator);
+		} catch (OutOfMemoryError e) {
+			KillSwitch.memKill(e);
+		}
+	}
 	
 	public static final <T extends Comparable<? super T>> void sort(ArrayList<T> list){
 		try {
@@ -626,11 +647,12 @@ public class Shared {
 		}
 	}
 	
-	public static final long MAX_ARRAY_LEN=Integer.MAX_VALUE-20;
+	public static final int MAX_ARRAY_LEN=Integer.MAX_VALUE-20;
 	
 	public static final int parallelSortLength=10000;
 	private static boolean disableParallelSort=false;
 	public static boolean parallelSort=testParallelSort();
+	public static boolean SIMD=false;
 	
 	public static double javaVersion=parseJavaVersion();
 	
