@@ -25,7 +25,6 @@ import stream.ConcurrentReadInputStream;
 import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
-import structures.EntropyTracker;
 import structures.IntList;
 import structures.IntListCompressor;
 import structures.ListNum;
@@ -34,6 +33,7 @@ import tax.AccessionToTaxid;
 import tax.GiToTaxid;
 import tax.TaxNode;
 import tax.TaxTree;
+import tracker.EntropyTracker;
 
 /**
  * Makes blacklists in a taxa-aware manner.
