@@ -12,7 +12,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -22,6 +21,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * 
@@ -295,7 +295,7 @@ public class KmerLimit extends SketchObject {
 		t.stop();
 		outstream.println(Tools.timeReadsBasesProcessed(t, readsProcessed, basesProcessed, 8));
 		outstream.println(Tools.readsBasesOut(readsProcessed, basesProcessed, readsOut, basesOut, 8, false));
-		String kstring=Tools.padKM(sharedHeap.genomeSizeEstimate(minCount), 8);
+		String kstring=Tools.padKMB(sharedHeap.genomeSizeEstimate(minCount), 8);
 		outstream.println("Unique Kmers Out:   "+kstring);
 		
 //		Sketch sk=new Sketch(sharedHeap, true, true, null);
