@@ -14,7 +14,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -25,6 +24,7 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import structures.IntMap;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * 
@@ -296,8 +296,8 @@ public class KmerLimit2 extends SketchObject {
 		outstream.println("Finished counting kmers.");
 		outstream.println(Tools.timeReadsBasesProcessed(t, readsProcessed, basesProcessed, 8));
 		
-		String kstring0=Tools.padKM(sketch.genomeSizeEstimate(minCount), 8);
-		String rstring0=Tools.padKM(targetReads, 8);
+		String kstring0=Tools.padKMB(sketch.genomeSizeEstimate(minCount), 8);
+		String rstring0=Tools.padKMB(targetReads, 8);
 		outstream.println("Unique Kmers:       "+kstring0);
 		outstream.println("Target Reads:       "+rstring0+"\t"+targetRateS);
 		
@@ -334,7 +334,7 @@ public class KmerLimit2 extends SketchObject {
 		outstream.println(Tools.timeReadsBasesProcessed(t, readsProcessed, basesProcessed, 8));
 		
 		outstream.println(Tools.readsBasesOut(readsProcessed, basesProcessed, readsOut, basesOut, 8, false));
-		String kstring=Tools.padKM(sharedHeap.genomeSizeEstimate(minCount), 8);
+		String kstring=Tools.padKMB(sharedHeap.genomeSizeEstimate(minCount), 8);
 		outstream.println("Unique Kmers Out:   "+kstring);
 		
 		//Throw an exception of there was an error in a thread
@@ -522,7 +522,7 @@ public class KmerLimit2 extends SketchObject {
 		if(targetKmerFraction>=1){return reads;}
 		
 		final int targetKeys=(int)(targetKmerFraction*counts.length);
-		final long countSum=Tools.sum(counts0);
+		final long countSum=shared.Vector.sum(counts0);
 		assert(countSum<Shared.MAX_ARRAY_LEN) : countSum;
 //		System.err.println("countsum: "+countSum);
 		
@@ -553,7 +553,7 @@ public class KmerLimit2 extends SketchObject {
 //		}
 //		
 //		int len=counts.length;
-//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+Tools.sum(counts)+", "+Arrays.toString(counts));
+//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+shared.Vector.sum(counts)+", "+Arrays.toString(counts));
 //		for(; valid>targetKeys; rounds++){
 //			int pos=randy.nextInt(len);
 ////			assert(counts[pos]>0) : pos+"/"+len+": "+targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+Arrays.toString(counts);
@@ -572,7 +572,7 @@ public class KmerLimit2 extends SketchObject {
 //			System.err.println(len+", "+pos+": "+Arrays.toString(counts));
 //		}
 //		
-//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+Tools.sum(counts));
+//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+shared.Vector.sum(counts));
 //		
 //		return rounds;
 //	}
@@ -589,9 +589,9 @@ public class KmerLimit2 extends SketchObject {
 		}
 		
 		int len=counts.length;
-		final long sum0=Tools.sum(counts);
+		final long sum0=shared.Vector.sum(counts);
 		long sum=sum0;
-//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+Tools.sum(counts)+", "+Arrays.toString(counts));
+//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+shared.Vector.sum(counts)+", "+Arrays.toString(counts));
 		for(; valid>targetKeys; rounds++){
 			long posNum=(Long.MAX_VALUE&randy.nextLong())%sum;
 			long sum2=0;
@@ -630,7 +630,7 @@ public class KmerLimit2 extends SketchObject {
 //			System.err.println(len+", "+pos+": "+Arrays.toString(counts));
 		}
 		
-//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+Tools.sum(counts));
+//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+shared.Vector.sum(counts));
 		
 		return rounds;
 	}
@@ -652,10 +652,10 @@ public class KmerLimit2 extends SketchObject {
 				expanded[k]=i;
 			}
 		}
-		assert(expanded.length==Tools.sum(counts0));
+		assert(expanded.length==shared.Vector.sum(counts0));
 		
 		int len=expanded.length;
-//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+Tools.sum(counts)+", "+Arrays.toString(counts));
+//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+shared.Vector.sum(counts)+", "+Arrays.toString(counts));
 		for(; valid>targetKeys; rounds++){
 			final int pos=randy.nextInt(len);
 			final int key=expanded[pos];
@@ -675,7 +675,7 @@ public class KmerLimit2 extends SketchObject {
 //			System.err.println(len+", "+pos+": "+Arrays.toString(counts));
 		}
 		
-//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+Tools.sum(counts));
+//		System.err.println(targetKeys+", "+counts.length+", "+valid+", "+len+", "+rounds+", "+shared.Vector.sum(counts));
 		
 		return rounds;
 	}
