@@ -16,13 +16,13 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
 import structures.ByteBuilder;
 import structures.StringNum;
 import tax.TaxTree;
+import tracker.ReadStats;
 
 /**
  * Compares one or more input sketches to a set of reference sketches.
