@@ -545,7 +545,7 @@ public class Sketch extends SketchObject implements Comparable<Sketch>, Cloneabl
 			for(; i<a.length && j<b.length; ){
 				final long ka=a[i], kb=b[j];
 				final int bit=(int)(ka&1);
-				final int count=present.getCount(i);
+//				final int count=present.getCount(i);
 				if(ka==kb){
 					matches++;
 					k1hits+=bit;
@@ -1134,7 +1134,7 @@ public class Sketch extends SketchObject implements Comparable<Sketch>, Cloneabl
 	/** Stores sorted hashcodes, ascending, as Long.MAX_VALUE-(raw hashcode) */
 	public long[] keys;
 	/** Stores kmer (hashcode) observation counts */
-	int[] keyCounts;
+	public int[] keyCounts;
 	/** Stores base (ACGTN) counts */
 	final long[] baseCounts;
 	private byte[] r16S;
