@@ -16,7 +16,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -32,6 +31,7 @@ import tax.GiToTaxid;
 import tax.ImgRecord2;
 import tax.TaxNode;
 import tax.TaxTree;
+import tracker.ReadStats;
 
 /**
  * Creates MinHashSketches rapidly.
