@@ -18,10 +18,10 @@ import shared.Parse;
 import shared.Tools;
 import stream.ConcurrentReadInputStream;
 import stream.Read;
-import structures.EntropyTracker;
 import structures.ListNum;
 import tax.TaxNode;
 import tax.TaxTree;
+import tracker.EntropyTracker;
 
 /**
  * Creates MinHashSketches rapidly.
@@ -49,6 +49,7 @@ public class SketchMakerMini extends SketchObject {
 		mode=mode_;
 		minProb=minProb_;
 		minQual=minQual_;
+		rcomp=tool.rcomp;
 		
 		aminoShift=AminoAcid.AMINO_SHIFT;
 		if(!aminoOrTranslate()){
@@ -89,9 +90,6 @@ public class SketchMakerMini extends SketchObject {
 
 	/** Create read streams and process all data */
 	public ArrayList<Sketch> toSketches(final String fname, float samplerate, long reads){
-		heap.clear(false); //123
-		final String simpleName;
-		
 		final FileFormat ffin1, ffin2;
 		if(fname.indexOf('#')>=0 && FileFormat.isFastq(ReadWrite.rawExtension(fname)) && !new File(fname).exists()){
 			ffin1=FileFormat.testInput(fname.replaceFirst("#", "1"), FileFormat.FASTQ, null, true, true);
@@ -100,6 +98,13 @@ public class SketchMakerMini extends SketchObject {
 			ffin1=FileFormat.testInput(fname, FileFormat.FASTA, null, true, true);
 			ffin2=null;
 		}
+		return toSketches(ffin1, ffin2, samplerate, reads);
+	}
+
+	/** Create read streams and process all data */
+	public ArrayList<Sketch> toSketches(FileFormat ffin1, FileFormat ffin2, float samplerate, long reads){
+		heap.clear(false); //123
+		final String simpleName;
 		
 		//Create a read input stream
 		final ConcurrentReadInputStream cris;
@@ -277,7 +282,7 @@ public class SketchMakerMini extends SketchObject {
 		}
 	}
 	
-	void processReadNucleotide(final Read r){
+	public void processReadNucleotide(final Read r){
 		if(processSSU && heap.r16S()==null && r.length()>=min_SSU_len && !useSSUMapOnly && !heap.isEukaryote()){
 			Orf orf=gCaller.makeRna(r.id, r.bases, ProkObject.r16S);//TODO: 18S
 			if(orf!=null && orf.length()>=min_SSU_len){
@@ -339,7 +344,7 @@ public class SketchMakerMini extends SketchObject {
 //							+AminoAcid.kmerToString(AminoAcid.reverseComplementBinaryFast(rkmer, k), k)+"\n"
 //							+len+", "+(char)b+", "+x+", "+x2;
 						
-						final long hashcode=hash(kmer, rkmer);
+						final long hashcode=hash(kmer, rkmer, rcomp);
 						//				System.err.println(kmer+"\t"+rkmer+"\t"+z+"\t"+hash);
 						if(hashcode>min){
 							if(noBlacklist){
@@ -399,7 +404,7 @@ public class SketchMakerMini extends SketchObject {
 						heap.genomeSizeKmers++;
 						heap.probSum+=prob;
 						if(eTracker==null || eTracker.passes()){
-							final long hashcode=hash(kmer, rkmer);
+							final long hashcode=hash(kmer, rkmer, rcomp);
 //							System.err.println(kmer+"\t"+rkmer+"\t"+z+"\t"+hash);
 							if(hashcode>min){
 								if(noBlacklist){
@@ -421,7 +426,7 @@ public class SketchMakerMini extends SketchObject {
 //				if(len>=k){
 //					kmersProcessed++;
 //					heap.genomeSizeKmers++;
-//					final long hash=hash(kmer, rkmer);
+//					final long hash=hash(kmer, rkmer, rcomp);
 //					//				System.err.println(kmer+"\t"+rkmer+"\t"+z+"\t"+hash);
 //					if(hash>min){
 //						if(prob>=minProb || (!heap.setMode && heap.contains(hash))){
@@ -558,6 +563,22 @@ public class SketchMakerMini extends SketchObject {
 		pacBioDetected|=smm.pacBioDetected;
 	}
 
+	public boolean isEmpty() {
+		return heap==null || heap.size()<1;
+	}
+	
+	public float minEntropy() {
+		// TODO Auto-generated method stub
+		return eTracker==null ? -1 : eTracker.cutoff();
+	}
+	
+	public SketchHeap heap() {return heap;}
+	
+	/*--------------------------------------------------------------*/
+	/*----------------            Fields            ----------------*/
+	/*--------------------------------------------------------------*/
+	
+
 	/** True only if this thread has completed successfully */
 	boolean success=false;
 
@@ -570,23 +591,16 @@ public class SketchMakerMini extends SketchObject {
 	final EntropyTracker eTracker;
 	final GeneCaller gCaller;
 	
-	public float minEntropy() {
-		// TODO Auto-generated method stub
-		return eTracker==null ? -1 : eTracker.cutoff();
-	}
-	
-	/*--------------------------------------------------------------*/
-	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
 
 	/** Number of reads processed */
-	protected long readsProcessed=0;
+	public long readsProcessed=0;
 	/** Number of bases processed */
-	protected long basesProcessed=0;
+	public long basesProcessed=0;
 	/** Number of bases processed */
-	protected long kmersProcessed=0;
+	public long kmersProcessed=0;
 	/** Number of sketches started */
-	protected long sketchesMade=0;
+	public long sketchesMade=0;
 
 	float minProb() {return minProb;}
 	byte minQual() {return minQual;}
@@ -599,6 +613,7 @@ public class SketchMakerMini extends SketchObject {
 	/*--------------------------------------------------------------*/
 	
 	private final SketchTool tool;
+	private final boolean rcomp;
 	final int mode;
 	
 	/*--------------------------------------------------------------*/
