@@ -19,9 +19,9 @@ import shared.Shared;
 import shared.Timer;
 import shared.Tools;
 import stream.Read;
-import structures.EntropyTracker;
 import structures.IntList3;
 import tax.TaxTree;
+import tracker.EntropyTracker;
 
 public class SketchObject {
 	
@@ -530,25 +530,31 @@ public class SketchObject {
 	}
 	
 	public static final long hash(long kmer){//Avoid using this.
-		return rcomp ? hash(kmer, AminoAcid.reverseComplementBinaryFast(kmer,  k)) : hash(kmer, kmer);
+		return rcomp ? hash(kmer, AminoAcid.reverseComplementBinaryFast(kmer,  k), rcomp) : 
+			hash(kmer, kmer, rcomp);
 	}
 	
 	public static final long hash(long kmer, long rkmer){
 		assert(postparsed);
-//		return hasher.hash_inner(kmer); //Slow
-//		return k2<1 ? hash1(kmer) : hash2(kmer);
-		if(useToValue2){return hashToValue2(kmer, rkmer);}
+		if(useToValue2){return hashToValue2(kmer, rkmer, rcomp);}
 		final long key=toValue(kmer, rkmer);
 		return k2<1 ? hash1(key) : k2submask==0 ? hash2(key) : hash3(key);
 	}
 	
+	public static final long hash(long kmer, long rkmer, boolean rcomp){
+		assert(postparsed);
+		if(useToValue2){return hashToValue2(kmer, rkmer, rcomp);}
+		final long key=rcomp ? toValue(kmer, rkmer) : kmer;
+		return k2<1 ? hash1(key) : k2submask==0 ? hash2(key) : hash3(key);
+	}
+	
 	/**
 	 * New version.
 	 * Generates a hash code from a kmer.
 	 * @param kmer Kmer to hash
 	 * @return Hash code
 	 */
-	private static final long hashToValue2(final long kmer0, final long rkmer0){
+	private static final long hashToValue2(final long kmer0, final long rkmer0, final boolean rcomp){
 //		return Tools.max(Tools.hash64shift(kmer0), Tools.hash64shift(kmer0&0xFFFFFFFFFFFFL));//Something like this would be around 10% faster; not worth it.
 		long kmer=kmer0, rkmer=rkmer0;
 		final long key;
@@ -568,11 +574,15 @@ public class SketchObject {
 //			System.err.println("\n"+AminoAcid.kmerToString(kmer, k)+"\n"+AminoAcid.kmerToString(rkmer, k)+
 //					"\n"+AminoAcid.kmerToString(kmer2, k2)+"\n"+AminoAcid.kmerToString(rkmer2, k2)+"\n"+AminoAcid.kmerToString(value, k)+"\n");
 //			assert(kmer2==AminoAcid.reverseComplementBinaryFast(rkmer2, k2));)
-		}else{
+		}else if(amino || translate){
 			assert(amino || translate);
 			final long kmer2=(kmer&k2mask);
 			useK1=((kmer2%4999)&1L)==0L;
 			key=useK1 ? kmer : kmer2;
+		}else{//if for whatever reason you want forward kmers
+			final long kmer2=((kmer&k2midmask)>>>k2shift);
+			useK1=((kmer2%4999L)&1L)==0L;
+			key=useK1 ? kmer : kmer2;
 		}
 //		if(key%5!=0){return -1;}//This makes it a little faster.
 		final long bit=useK1 ? 0 : 1; //Note that this gets reversed later during the subtraction process
@@ -1198,7 +1208,7 @@ public class SketchObject {
 	static boolean ban18SForProks=true;
 	static boolean ban16SForEuks=true;
 	
-	static long sampleseed=-1L;
+	public static long sampleseed=-1L;
 	
 	public static TaxTree taxtree=null;
 	private static String treefile=null;
