@@ -41,14 +41,16 @@ public final class SketchTool extends SketchObject {
 	/*--------------------------------------------------------------*/
 	
 	public SketchTool(int size_, DisplayParams params){
-		this(size_, params.minKeyOccuranceCount, params.trackCounts(), params.mergePairs);
+		this(size_, params.minKeyOccuranceCount, params.trackCounts(), params.mergePairs, SketchObject.rcomp);
 	}
 	
-	public SketchTool(int size_, int minKeyOccuranceCount_, boolean trackCounts_, boolean mergePairs_){
+	public SketchTool(int size_, int minKeyOccuranceCount_, boolean trackCounts_, 
+			boolean mergePairs_, boolean rcomp_){
 		stTargetSketchSize=size_;
 		minKeyOccuranceCount=minKeyOccuranceCount_;
 		trackCounts=trackCounts_;
 		mergePairs=mergePairs_;
+		rcomp=rcomp_;
 		
 		assert(!aminoOrTranslate() || !rcomp) : "rcomp should be false in amino mode.";
 		assert(!aminoOrTranslate() || (k*AminoAcid.AMINO_SHIFT<64)) : "Protein sketches require 1 <= K <= "+(63/AminoAcid.AMINO_SHIFT)+".";
@@ -1361,6 +1363,7 @@ public final class SketchTool extends SketchObject {
 	public final boolean trackCounts;
 	/** Merge reads before processing kmers. */
 	public final boolean mergePairs;
+	public final boolean rcomp;
 	
 	public static int BUFLEN=16384;
 	public static boolean BUFFERED_READER=false;
