@@ -13,11 +13,11 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
 import structures.ByteBuilder;
+import tracker.ReadStats;
 
 /**
  * Generates smaller sketches from input sketches.
