@@ -12,7 +12,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -23,6 +22,7 @@ import structures.ListNum;
 import tax.AccessionToTaxid;
 import tax.GiToTaxid;
 import tax.TaxTree;
+import tracker.ReadStats;
 import var2.ScafMap;
 
 /**
