@@ -14,7 +14,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -27,6 +26,7 @@ import stream.ReadStreamWriter;
 import stream.SamLine;
 import stream.SamReadInputStream;
 import structures.ListNum;
+import tracker.ReadStats;
 
 
 /**
