@@ -15,7 +15,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -27,6 +26,7 @@ import stream.FastaReadInputStream;
 import stream.Read;
 import stream.SamLine;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Sorts reads by name, potentially from multiple input files.
