@@ -14,7 +14,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -29,6 +28,7 @@ import structures.ListNum;
 import tax.AccessionToTaxid;
 import tax.GiToTaxid;
 import tax.TaxTree;
+import tracker.ReadStats;
 import var2.ScafMap;
 
 /**
@@ -148,6 +148,11 @@ public class SortByName {
 				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorFlowcell.comparator;
 				}
+			}else if(a.equals("crispr")){
+				if(Parse.parseBoolean(b)){
+					ReadComparatorCrispr.loadNet();
+					comparator=ReadComparatorCrispr.comparator;
+				}
 			}else if(a.equalsIgnoreCase("clump") || a.equalsIgnoreCase("clumpify")){
 				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorClump.comparator;
@@ -436,7 +441,7 @@ public class SortByName {
 					if(verbose){outstream.println("currentMem: "+currentMem+" >= "+currentLimit+", dumping. ");}
 					outstandingMem.addAndGet(currentMem);
 //					dumpCount.add(storage.size());
-					sortAndDump(storage, currentMem, outstandingMem, null, false);
+					sortAndDump(storage, currentMem, outstandingMem, null, null, false);
 					storage=new ArrayList<Read>();
 					bytesDumped+=currentMem;
 					dumps++;
@@ -468,7 +473,7 @@ public class SortByName {
 			ReadWrite.ZIPLEVEL=ziplevel0;
 			outstream.println("Sorting.");
 			if(out1!=null){
-				sortAndDump(storage, currentMem, outstandingMem, out1, useSharedHeader);
+				sortAndDump(storage, currentMem, outstandingMem, out1, out2, useSharedHeader);
 				storage=null;
 				waitOnMemory(outstandingMem, 0);
 			}else{
@@ -478,7 +483,7 @@ public class SortByName {
 			}
 		}else{
 //			dumpCount.add(storage.size());
-			sortAndDump(storage, currentMem, outstandingMem, null, false);
+			sortAndDump(storage, currentMem, outstandingMem, null, null, false);
 			storage=null;
 			waitOnMemory(outstandingMem, 0);
 			outstream.println("Merging "+(dumps+1)+" files.");
@@ -811,19 +816,20 @@ public class SortByName {
 		return a;
 	}
 	
-	private void sortAndDump(final ArrayList<Read> storage, final long currentMem, final AtomicLong outstandingMem, String fname, boolean useHeader) {
-		String temp=fname;
-		if(temp==null){
+	private void sortAndDump(final ArrayList<Read> storage, final long currentMem, final AtomicLong outstandingMem, String fname1, String fname2, boolean useHeader) {
+		String temp1=fname1;
+		String temp2=fname2;
+		if(temp1==null){
 			synchronized(outTemp){
 				if(verbose2){outstream.println("Synced to outTemp to make a temp file.");}
-				temp=getTempFile();
-				if(verbose2){outstream.println("Temp file: "+temp);}
-				outTemp.add(temp);
+				temp1=getTempFile();
+				if(verbose2){outstream.println("Temp file: "+temp1);}
+				outTemp.add(temp1);
 			}
 		}
 
-		if(verbose || true){outstream.println("Created a WriteThread for "+temp);}
-		WriteThread wt=new WriteThread(storage, currentMem, outstandingMem, temp, useHeader, outstream);
+		if(verbose || true){outstream.println("Created a WriteThread for "+temp1+(temp2==null ? "" : ", "+temp2));}
+		WriteThread wt=new WriteThread(storage, currentMem, outstandingMem, temp1, temp2, useHeader, outstream);
 		wt.start();
 	}
 	
@@ -833,11 +839,13 @@ public class SortByName {
 	
 	private static class WriteThread extends Thread{
 		
-		public WriteThread(final ArrayList<Read> storage_, final long currentMem_, final AtomicLong outstandingMem_, String fname_, boolean useHeader_, PrintStream outstream_){
+		public WriteThread(final ArrayList<Read> storage_, final long currentMem_, final AtomicLong outstandingMem_, 
+				String fname1_, String fname2_, boolean useHeader_, PrintStream outstream_){
 			storage=storage_;
 			currentMem=currentMem_;
 			outstandingMem=outstandingMem_;
-			fname=fname_;
+			fname1=fname1_;
+			fname2=fname2_;
 			useHeader=useHeader_;
 			outstream=outstream_;
 		}
@@ -846,11 +854,12 @@ public class SortByName {
 		public void run(){
 			
 			if(verbose){outstream.println("Started a WriteThread.");}
-			final FileFormat ffout=FileFormat.testOutput(fname, FileFormat.FASTQ, null, true, false, false, false);
+			final FileFormat ffout1=FileFormat.testOutput(fname1, FileFormat.FASTQ, null, true, false, false, false);
+			final FileFormat ffout2=FileFormat.testOutput(fname2, FileFormat.FASTQ, null, true, false, false, false);
 			final ConcurrentReadOutputStream ros;
-			if(ffout!=null){
+			if(ffout1!=null){
 				final int buff=4;
-				ros=ConcurrentReadOutputStream.getStream(ffout, null, null, null, buff, null, useHeader);
+				ros=ConcurrentReadOutputStream.getStream(ffout1, ffout2, null, null, buff, null, useHeader);
 				ros.start(); //Start the stream
 			}else{ros=null;}
 
@@ -887,7 +896,8 @@ public class SortByName {
 		final ArrayList<Read> storage;
 		final long currentMem;
 		final AtomicLong outstandingMem;
-		final String fname;
+		final String fname1;
+		final String fname2;
 		final boolean useHeader;
 		boolean errorState=false;
 		final PrintStream outstream;
