@@ -255,54 +255,55 @@ public class ConcurrentGenericReadInputStream extends ConcurrentReadInputStream
 		if(verbose){System.err.println("crisG:    Added poison.");}
 	}
 	
-	private final void readSingles(){
-
-		while(!shutdown && producer1.hasMore() && generated<maxReads){
-			ArrayList<Read> list=null;
-			while(list==null){
-				try {
-					list=depot.empty.take();
-				} catch (InterruptedException e) {
-					// TODO Auto-generated catch block
-					e.printStackTrace();
-					if(shutdown){break;}
-				}
-			}
-			if(shutdown || list==null){break;}
-			
-			long bases=0;
-			while(list.size()<depot.bufferSize && generated<maxReads && bases<MAX_DATA){
-				Read a=producer1.next();
-				Read b=(producer2==null ? null : producer2.next());
-				if(a==null){break;}
-				readsIn++;
-				basesIn+=a.length();
-				if(b!=null){
-					readsIn++;
-					basesIn+=b.length();
-				}
-				if(randy==null || randy.nextFloat()<samplerate){
-					list.add(a);
-					if(b!=null){
-						assert(a.numericID==b.numericID) : "\n"+a.numericID+", "+b.numericID+"\n"+a.toText(false)+"\n"+b.toText(false)+"\n";
-						assert(a.mate==null) : "Please set interleaved=false when using dual input files.\n"+a.id+"\n"+a.mate.id+"\n"+producer1+"\n"+producer2;
-						assert(b.mate==null) : "Please set interleaved=false when using dual input files.";
-						a.mate=b;
-						b.mate=a;
-
-						assert(a.pairnum()==0);
-						b.setPairnum(1);
-						bases+=(b.bases==null ? 0 : b.length());
-					}
-					bases+=(a.bases==null ? 0 : a.length());
-				}
-				incrementGenerated(1);
-			}
-
-			if(verbose){System.err.println("crisG:    E: Adding list("+list.size()+") to full.");}
-			depot.full.add(list);
-		}
-	}
+//	@Deprecated
+//	private final void readSingles(){
+//
+//		while(!shutdown && producer1.hasMore() && generated<maxReads){
+//			ArrayList<Read> list=null;
+//			while(list==null){
+//				try {
+//					list=depot.empty.take();
+//				} catch (InterruptedException e) {
+//					// TODO Auto-generated catch block
+//					e.printStackTrace();
+//					if(shutdown){break;}
+//				}
+//			}
+//			if(shutdown || list==null){break;}
+//			
+//			long bases=0;
+//			while(list.size()<depot.bufferSize && generated<maxReads && bases<MAX_DATA){
+//				Read a=producer1.next();
+//				Read b=(producer2==null ? null : producer2.next());
+//				if(a==null){break;}
+//				readsIn++;
+//				basesIn+=a.length();
+//				if(b!=null){
+//					readsIn++;
+//					basesIn+=b.length();
+//				}
+//				if(randy==null || randy.nextFloat()<samplerate){
+//					list.add(a);
+//					if(b!=null){
+//						assert(a.numericID==b.numericID) : "\n"+a.numericID+", "+b.numericID+"\n"+a.toText(false)+"\n"+b.toText(false)+"\n";
+//						assert(a.mate==null) : "Please set interleaved=false when using dual input files.\n"+a.id+"\n"+a.mate.id+"\n"+producer1+"\n"+producer2;
+//						assert(b.mate==null) : "Please set interleaved=false when using dual input files.";
+//						a.mate=b;
+//						b.mate=a;
+//
+//						assert(a.pairnum()==0);
+//						b.setPairnum(1);
+//						bases+=(b.bases==null ? 0 : b.length());
+//					}
+//					bases+=(a.bases==null ? 0 : a.length());
+//				}
+//				incrementGenerated(1);
+//			}
+//
+//			if(verbose){System.err.println("crisG:    E: Adding list("+list.size()+") to full.");}
+//			depot.full.add(list);
+//		}
+//	}
 	
 	private final void readLists(){
 		ArrayList<Read> buffer1=null;
@@ -361,7 +362,7 @@ public class ConcurrentGenericReadInputStream extends ConcurrentReadInputStream
 								e.printStackTrace();
 							}
 						}
-						if(buffer2!=null){pair(buffer1, buffer2);}
+						if(buffer2!=null && FASTQ.PAIR_READS){pair(buffer1, buffer2);}
 						if(REMOVE_DISCARDED_READS){removeDiscarded(buffer1, buffer2);}
 					}
 //					System.out.println("crisG:    f");
@@ -500,6 +501,10 @@ public class ConcurrentGenericReadInputStream extends ConcurrentReadInputStream
 				"\nThe pairing may have been corrupted by an upstream process.  It may be fixable by running repair.sh.";
 		final int lim=Tools.min(len1, len2);
 		
+		if(FASTQ.FLIP_R2){
+			for(Read r2 : buffer2) {r2.reverseComplement();}
+		}
+		
 		for(int i=0; i<lim; i++){
 			Read a=buffer1.get(i);
 			Read b=buffer2.get(i);
@@ -640,7 +645,7 @@ public class ConcurrentGenericReadInputStream extends ConcurrentReadInputStream
 
 	@Override
 	public boolean paired() {
-		return producer1.paired() || producer2!=null;
+		return FASTQ.PAIR_READS && (producer1.paired() || producer2!=null);
 	}
 	
 	@Override
