@@ -5,21 +5,29 @@ import java.util.Comparator;
 
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import sort.ReadComparatorClump;
+import sort.ReadComparatorTopological5Bit;
 import structures.ListNum;
 
 public class CrisContainer implements Comparable<CrisContainer> {
 	
 	public CrisContainer(String fname, Comparator<Read> comparator_, boolean allowSubprocess){
 		comparator=comparator_;
+		genKmer=(comparator==ReadComparatorTopological5Bit.comparator);
+		clump=(comparator==ReadComparatorClump.comparator);
 		FileFormat ff=FileFormat.testInput(fname, FileFormat.FASTQ, null, allowSubprocess, true);
 		cris=ConcurrentReadInputStream.getReadInputStream(-1, true, ff, null, null, null);
+//		System.err.println(genKmer+", "+clump+", "+comparator.getClass());
 		cris.start();
 		fetch();
 	}
 	
 	public CrisContainer(ConcurrentReadInputStream cris_, Comparator<Read> comparator_){
 		comparator=comparator_;
+		genKmer=(comparator==ReadComparatorTopological5Bit.comparator);
+		clump=(comparator==ReadComparatorClump.comparator);
 		cris=cris_;
+//		System.err.println(genKmer+", "+clump+", "+comparator.getClass());
 		fetch();
 	}
 	
@@ -33,6 +41,11 @@ public class CrisContainer implements Comparable<CrisContainer> {
 		ListNum<Read> ln=cris.nextList();
 		list=(ln==null ? null : ln.list);
 		if(list.size()<1){list=null;}
+		else if(genKmer){
+			for(Read r : list){ReadComparatorTopological5Bit.genKmer(r);}
+		}else if(clump){
+			for(Read r : list){ReadComparatorClump.set(r);}
+		}
 		read=(list==null ? null : list.get(0));
 		if(lastNum>=0){cris.returnList(lastNum, list==null);}
 		if(ln!=null){lastNum=ln.id;}
@@ -78,6 +91,7 @@ public class CrisContainer implements Comparable<CrisContainer> {
 	private long lastNum=-1;
 	private ArrayList<Read> list;
 	private final Comparator<Read> comparator;
+	private final boolean genKmer, clump;
 //	private double sum=0;
 //	final int count;
 //	private final Random randy;
