@@ -2021,7 +2021,7 @@ public class SamLine implements Serializable {
 		if(parseCustom){
 			
 			
-			Header h=new Header(qname, pairnum());
+			CustomHeader h=new CustomHeader(qname, pairnum());
 			
 			numericId_=h.id;
 			int trueChrom=h.bbchrom;
@@ -2221,7 +2221,7 @@ public class SamLine implements Serializable {
 			assert(!(rname==null && rnameS!=null));
 			appendTo(bb, rname).append('\t');
 		}else{
-			assert(!(rname!=null && rnameS==null));
+			assert(!(rname!=null && rnameS==null)) : RNAME_AS_BYTES+", "+rname+", "+rnameS;
 			appendTo(bb, rnameS).append('\t');
 		}
 		bb.append(pos).append('\t');
@@ -2558,6 +2558,28 @@ public class SamLine implements Serializable {
 	public String rnameS(){return rnameS!=null ? rnameS : rname==null ? null : new String(rname);}
 	public String rnextS(){return rnext==null ? null : new String(rnext);}
 	
+	public String rnamePrefix() {
+		return (rnameS!=null ? toPrefix(rnameS) : toPrefix(rname));
+	}
+	
+	private static String toPrefix(String s) {
+		for(int i=0; i<s.length(); i++) {
+			if(Character.isWhitespace(s.charAt(i))) {
+				return s.substring(0, i);
+			}
+		}
+		return s;
+	}
+	
+	private static String toPrefix(byte[] s) {
+		for(int i=0; i<s.length; i++) {
+			if(Character.isWhitespace(s[i])) {
+				return new String(s, 0, i);
+			}
+		}
+		return new String(s);
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------           Fields             ----------------*/
 	/*--------------------------------------------------------------*/
