@@ -33,7 +33,7 @@ public final class LongList{
 	public LongList(){this(256);}
 	
 	public LongList(int initial){
-		assert(initial>0);
+		assert(initial>0) : initial;
 		array=KillSwitch.allocLong1D(initial);
 	}
 	
@@ -102,6 +102,19 @@ public final class LongList{
 		size++;
 	}
 	
+	public boolean contains(long x) {
+		for(int i=0; i<size; i++) {
+			if(array[i]==x) {return true;}
+		}
+		return false;
+	}
+	
+	public void addAll(LongList list2) {
+		final long[] array2=list2.array;
+		final int size2=list2.size;
+		for(int i=0; i<size2; i++){add(array2[i]);}
+	}
+	
 	private final void resize(final long size2){
 		assert(size2>size) : size+", "+size2;
 		final int size3=(int)Tools.min(Shared.MAX_ARRAY_LEN, size2);
@@ -152,6 +165,14 @@ public final class LongList{
 		return sum;
 	}
 	
+	public final long sumHist(){
+		long sum=0;
+		for(int i=0; i<size; i++){
+			sum+=array[i]*i;
+		}
+		return sum;
+	}
+	
 	public final double sum(){
 		double sum=0;
 		for(int i=0; i<size; i++){
@@ -164,6 +185,10 @@ public final class LongList{
 		return size<1 ? 0 : sum()/size;
 	}
 	
+	public final double meanHist(){
+		return size<1 ? 0 : sumHist()/sum();
+	}
+	
 	//Ignores elements below 1
 	public final double harmonicMean(){
 		double sum=0;
@@ -346,6 +371,13 @@ public final class LongList{
 		size=i+1;
 	}
 	
+	public void removeElementAt(int i) {
+		for(int j=i+1; j<size; i++, j++) {
+			array[i]=array[j];
+		}
+		size--;
+	}
+	
 	@Override
 	public String toString(){
 		return toStringListView();
@@ -416,6 +448,36 @@ public final class LongList{
 		return array.length-size;
 	}
 	
+	public boolean isEmpty() {
+		return size==0;
+	}
+	
+	public int findIndex(long x) {
+		for(int i=0; i<size; i++) {
+			if(array[i]==x) {return i;}
+		}
+		return -1;
+	}
+	
+	/** Assumes sorted ascending */
+	public int findIndexAfter(long x) {
+		for(int i=0; i<size; i++) {
+			if(array[i]>x) {return i;}
+		}
+		return size;
+	}
+	
+	public void capHist(final int max) {
+		if(size<=max+1) {return;}
+		//size=2, max=0 are the lowest values to enter
+		long sum=0;
+		for(int i=size-1; i>=max; i--) {
+			sum+=array[i];
+		}
+		array[max]=sum;
+		size=max+1;
+	}
+	
 	private static final long min(long x, long y){return x<y ? x : y;}
 	private static final long max(long x, long y){return x>y ? x : y;}
 	
