@@ -269,7 +269,6 @@ public class SuperLongList {
 	}
 	
 	public long mode(){
-//		assert(sorted);
 		long maxCount=0;
 		long maxValue=0;
 		for(int i=0; i<array.length; i++){
@@ -326,6 +325,9 @@ public class SuperLongList {
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
+
+	public long count() {return count;}
+	public long sum() {return sum;}
 	
 	private long count;
 	private long sum;
