@@ -466,8 +466,9 @@ public class AccessionToTaxid_old {
 				if(line.length>0){
 					linesProcessedT++;
 					bytesProcessedT+=line.length;
-					
-					final boolean valid=(!Tools.startsWith(line, "accession\t")) & !skipParse;
+
+//					final boolean valid=(!Tools.startsWith(line, "accession\t")) & !skipParse;
+					final boolean valid=(!Tools.startsWith(line, "accession")) & !skipParse;
 //					assert(valid); //Not true if concatenated
 					
 //					if(Tools.startsWith(line, "NZ_LM994619")){
