@@ -88,36 +88,24 @@ public class GiToTaxid {
 	
 	public static int parseGiToTaxid(String s){return parseGiToTaxid(s, '|');}
 	public static int parseGiToTaxid(String s, char delimiter){
-		int x=parseGiNumber(s, delimiter);
-		assert(x>=0) : s;
-		assert(array!=null) : "To use gi numbers, you must load a gi table.";
-//		if(x>=array.length || array[x]<0){x=(int)(Math.random()*array.length);} //Test to make sure array is nonempty.
-		if(x>=0 && x<array.length){return array[x];}
-		assert(x<array.length) : "The GI number "+x+" is too big.\n"
-				+ "Please update the gi table with the latest version from NCBI as per the instructions in gitable.sh.\n"
-				+ "To ignore this problem, please run with the -da flag.\n";
-		return -1;
+		long x=parseGiNumber(s, delimiter);
+		assert(x>=0) : x+", "+s;
+		return getID(x);
 	}
 	
 
 	public static int parseGiToTaxid(byte[] s){return parseGiToTaxid(s, '|');}
 	public static int parseGiToTaxid(byte[] s, char delimiter){
-		int x=parseGiNumber(s, delimiter);
-		if(x>=0){return array[x];}
-		return -1;
+		long x=parseGiNumber(s, delimiter);
+		return x<0 ? -1 : getID(x);
 	}
 	
 	/** Parse a gi number, or return -1 if formatted incorrectly. */
-	static int parseGiNumber(String s, char delimiter){
+	static long parseGiNumber(String s, char delimiter){
 		if(s==null || s.length()<4){return -1;}
-//		System.err.println("a");
 		if(s.charAt(0)=='>'){return getID(s.substring(1), delimiter);}
-//		System.err.println("b");
 		if(!s.startsWith("gi")){return -1;}
-//		System.err.println("c");
-//		System.err.println("d");
 		int initial=s.indexOf(delimiter);
-//		System.err.println("e");
 		if(initial<0){
 			if(delimiter!='~'){
 				delimiter='~';
@@ -128,21 +116,16 @@ public class GiToTaxid {
 				initial=s.indexOf(delimiter);
 			}
 			if(initial<0){return -1;}
-//			System.err.println("f");
-//			System.err.println("g");
 		}
-//		System.err.println("h");
 		if(!Tools.isDigit(s.charAt(initial+1))){return -1;}
-//		System.err.println("i");
 		
-		int number=0;
+		long number=0;
 		for(int i=initial+1; i<s.length(); i++){
 			char c=s.charAt(i);
 			if(c==delimiter){break;}
 			assert(Tools.isDigit(c));
 			number=(number*10)+(c-'0');
 		}
-//		System.err.println("j: "+number);
 		return number;
 	}
 	
@@ -173,15 +156,14 @@ public class GiToTaxid {
 	public static int getID(String s){return getID(s, '|');}
 	/** Get the taxID from a header starting with a taxID or gi number */
 	public static int getID(String s, char delimiter){
-		int x=parseTaxidNumber(s, delimiter);
-		if(x>=0){return x;}
+		long x=parseTaxidNumber(s, delimiter);
+		if(x>=0){return (int)x;}
 		x=parseGiNumber(s, delimiter);
-		if(x>=0){return array[x];}
-		return -1;
+		return x<0 ? -1 : getID(x);
 	}
 	
 	/** Parse a gi number, or return -1 if formatted incorrectly. */
-	static int parseGiNumber(byte[] s, char delimiter){
+	static long parseGiNumber(byte[] s, char delimiter){
 		if(s==null || s.length<4){return -1;}
 		if(!Tools.startsWith(s, "gi") && !Tools.startsWith(s, ">gi")){return -1;}
 		int initial=Tools.indexOf(s, (byte)delimiter);
@@ -192,7 +174,7 @@ public class GiToTaxid {
 		}
 		if(!Tools.isDigit(s[initial+1])){return -1;}
 		
-		int number=0;
+		long number=0;
 		for(int i=initial+1; i<s.length; i++){
 			byte c=s[i];
 			if(c==delimiter){break;}
@@ -227,16 +209,37 @@ public class GiToTaxid {
 	public static int getID(byte[] s){return getID(s, '|');}
 	/** Get the taxID from a header starting with a taxID or gi number */
 	public static int getID(byte[] s, char delimiter){
-		int x=parseGiNumber(s, delimiter);
-		if(x>=0){return array[x];}
+		long x=parseGiNumber(s, delimiter);
+		if(x>=0){return getID(x, true);}
 		return parseNcbiNumber(s, delimiter);
 	}
 	
-	/** Get the taxID from a gi number */
-	public static int getID(int gi){
-		assert(gi>=0) : gi;
-		assert(gi<array.length) : gi+", "+array.length;
-		return array[gi];
+	/** Get the taxID from a gi number;
+	 * -1 if not present or invalid (negative input),
+	 * -2 if out of range (too high) */
+	public static int getID(long gi){
+		return getID(gi, true);
+	}
+	
+	/** Get the taxID from a gi number;
+	 * 0 if not present,
+	 * -1 if invalid (negative input),
+	 * -2 if out of range (too high) */
+	public static int getID(long gi, boolean assertInRange){
+		assert(initialized) : "To use gi numbers, you must load a gi table.";
+		if(gi<0 || gi>maxGiLoaded){
+			assert(!assertInRange) : gi<0 ? "gi number "+gi+" is invalid." : 
+				"The gi number "+gi+" is too big: Max loaded gi number is "+maxGiLoaded+".\n"
+				+ "Please update the gi table with the latest version from NCBI"
+				+ " as per the instructions in gitable.sh.\n"
+				+ "To ignore this problem, please run with the -da flag.\n";
+			return gi<0 ? -1 : -2;
+		}
+		final long upper=gi>>>SHIFT;
+		final int lower=(int)(gi&LOWERMASK);
+		assert(upper<Shared.MAX_ARRAY_LEN && upper<array.length) : gi+", "+upper+", "+array.length;
+		final int[] slice=array[(int)upper];
+		return slice==null || slice.length<=lower ? 0 : slice[lower];
 	}
 	
 	public static void initialize(String fname){
@@ -245,8 +248,19 @@ public class GiToTaxid {
 			synchronized(GiToTaxid.class){
 				if(!initialized || fileString==null || !fileString.equals(fname)){
 					fileString=fname;
-					if(fname.contains(".int1d")){
-						array=ReadWrite.read(int[].class, fname, true);
+					if(fname.contains(".int2d")){
+						array=ReadWrite.read(int[][].class, fname, true);
+						maxGiLoaded=-1;
+						if(array!=null && array.length>0){
+							int upper=array.length-1;
+							int[] section=array[upper];
+							int lower=section.length-1;
+							maxGiLoaded=(((long)upper)<<SHIFT)|lower;
+						}
+					}else if(fname.contains(".int1d")){
+						throw new RuntimeException("Old gi table format filename "+fname+".\n"
+								+ "Current files should end in .int2d.");
+						
 					}else{
 						array=makeArray(fname);
 					}
@@ -259,17 +273,19 @@ public class GiToTaxid {
 	public static boolean isInitialized(){return initialized;}
 	
 	public static synchronized void unload(){
+		maxGiLoaded=-1;
 		array=null;
 		fileString=null;
 		initialized=false;
 	}
 	
-	private static int[] makeArray(String fnames){
+	private static int[][] makeArray(String fnames){
 		String[] split;
 		if(new File(fnames).exists()){split=new String[] {fnames};}
 		else if(fnames.indexOf(',')>=0){split=fnames.split(",");}
 		else if(fnames.indexOf('#')>=0){
-			assert(fnames.indexOf("/")<0) : "Note: Wildcard # only works for relative paths in present working directory.";
+			assert(fnames.indexOf("/")<0) : "Note: Wildcard # only works for "
+					+ "relative paths in present working directory.";
 			File dir=new File(System.getProperty("user.dir"));
 			String prefix=fnames.substring(0, fnames.indexOf('#'));
 			String suffix=fnames.substring(fnames.indexOf('#')+1);
@@ -290,20 +306,28 @@ public class GiToTaxid {
 			throw new RuntimeException("Invalid file: "+fnames);
 		}
 		
-		IntList list=new IntList();
-//		assert(max<Integer.MAX_VALUE) : "Overflow.";
-//		int[] x=new int[(int)max+1];
-//		Arrays.fill(x, -1);
+		int numLists=32;
+		IntList[] lists=new IntList[numLists];
 		
 		long total=0;
 		for(String s : split){
-			long count=addToList(s, list);
+			long count=addToList(s, lists);
 			total+=count;
 		}
-		return list.shrink().array;
+		for(int i=0; i<lists.length; i++){
+			if(lists[i]!=null && lists[i].size>0){
+				lists[i].shrink();
+				numLists=i+1;
+			}
+		}
+		int[][] table=new int[numLists][];
+		for(int i=0; i<numLists; i++){
+			table[i]=lists[i].array;
+		}
+		return table;
 	}
 	
-	private static long addToList(String fname, IntList list){
+	private static long addToList(String fname, IntList[] lists){
 		boolean warned=false;
 		ByteFile bf=ByteFile.makeByteFile(fname, true);
 		long count=0, invalid=0;
@@ -316,34 +340,18 @@ public class GiToTaxid {
 				assert(tab2>0 && (tab2<tab3) && tab3<line.length) : tab2+", "+tab3+", "+line.length;
 				assert(tab2<line.length && line[tab2]=='\t') : tab2+", "+tab3+", '"+new String(line)+"'";
 				assert(tab3<line.length && line[tab3]=='\t') : tab2+", "+tab3+", '"+new String(line)+"'";
-//				assert(false) : tab2+", "+tab3+", '"+new String(line)+"'";
+				//assert(false) : tab2+", "+tab3+", '"+new String(line)+"'";
 				int tid=Parse.parseInt(line, tab2+1, tab3);
 				int gi=Parse.parseInt(line, tab3+1, line.length);
-				if(gi>=Shared.MAX_ARRAY_LEN || gi<0){//A gi over 2.5b was observed May 3, 2021.
+				if(gi<0){
 					invalid++;
 				}else{
-				assert(gi>=0) : "tid="+tid+", gi="+gi+", line=\n'"+new String(line)+"'";
-				int old=list.get(gi);
-				assert(old==0 || old==tid) : "Contradictory entries for gi "+gi+": "+old+" -> "+tid+"\n'"+new String(line)+"'\ntab2="+tab2+", tab3="+tab3;
-				
-				list.set(gi, tid);
-				
-				//assert(x[gi]==-1 || x[gi]==ncbi) : "Contradictory entries for gi "+gi+": "+x[gi]+" -> "+ncbi;
-//				if(x[gi]!=-1 && x[gi]!=ncbi){
-//					if(!warned){
-//						System.err.println("***WARNING*** For file "+fname+":\n"+
-//								("Contradictory entries for gi "+gi+": mapped to both taxID "+x[gi]+" and taxID "+ncbi)+
-//								"\nThis may be an error from NCBI and you may wish to report it, but it is\n"
-//								+ "being suppressed because NCBI data is known to contain multi-mapped gi numbers,\n"
-//								+ "at least between nucleotide and protein, and gi numbers are deprecated anyway.");
-//						warned=true;
-//					}
-//				}else{
-//					x[gi]=ncbi;
-//				}
+					assert(gi>=0) : "tid="+tid+", gi="+gi+", line=\n'"+new String(line)+"'";
+					int old=setID(gi, tid, lists);
+					assert(old<1 || old==tid) : "Contradictory entries for gi "+gi+": "+old+" -> "+tid+"\n'"+new String(line)+"'\ntab2="+tab2+", tab3="+tab3;
 				}
 			}else{
-				if(line.length==0){System.err.println(fname+", "+count);}//debug
+				//if(line.length==0){System.err.println(fname+", "+count);}//debug
 				invalid++;
 			}
 			line=bf.nextLine();
@@ -353,6 +361,28 @@ public class GiToTaxid {
 		return count;
 	}
 	
+	private static int getID(long gi, IntList[] lists){
+		assert(gi>=0) : "gi number "+gi+" is invalid.";
+		final long upper=gi>>>SHIFT;
+		final int lower=(int)(gi&LOWERMASK);
+		assert(upper<Shared.MAX_ARRAY_LEN) : gi+", "+upper;
+		IntList list=lists[(int)upper];
+		return lower<0 ? -1 : lower>=list.size ? -2 : list.get(lower);
+	}
+	
+	private static int setID(long gi, int tid, IntList[] lists){
+		assert(gi>=0) : "gi number "+gi+" is invalid.";
+		final long upper=gi>>>SHIFT;
+		final int lower=(int)(gi&LOWERMASK);
+		assert(upper<Shared.MAX_ARRAY_LEN) : gi+", "+upper;
+		IntList list=lists[(int)upper];
+		if(list==null){list=lists[(int)upper]=new IntList();}
+		int old=lower<0 ? -1 : lower>=list.size ? -2 : list.get(lower);
+		list.set(lower, tid);
+		maxGiLoaded=Tools.max(gi, maxGiLoaded);
+		return old;
+	}
+	
 //	private static int[] makeArrayOld(String fnames){
 //		String[] split;
 //		if(new File(fnames).exists()){split=new String[] {fnames};}
@@ -420,7 +450,12 @@ public class GiToTaxid {
 //		return count;
 //	}
 	
-	private static int[] array;
+	private static long maxGiLoaded=-1;
+	private static int[][] array;
+	private static final int SHIFT=30;
+	private static final long UPPERMASK=(-1L)<<SHIFT;
+	private static final long LOWERMASK=~UPPERMASK;
+	
 	private static String fileString;
 	
 	public static boolean verbose=false;
