@@ -13,7 +13,6 @@ import fileIO.TextStreamWriter;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -21,6 +20,7 @@ import stream.ConcurrentReadInputStream;
 import stream.Read;
 import structures.ByteBuilder;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Filters sequences according to their taxonomy,
