@@ -16,7 +16,6 @@ import shared.KillSwitch;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -25,6 +24,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import structures.ByteBuilder;
 import structures.IntList;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
