@@ -136,8 +136,8 @@ public class RenameIMG {
 
 		final int spaces=8;
 		String fpstring=""+filesProcessed;
-		String cpstring=Tools.padKM(sequencesProcessed, spaces);
-		String bapstring=Tools.padKM(basesProcessed, spaces);
+		String cpstring=Tools.padKMB(sequencesProcessed, spaces);
+		String bapstring=Tools.padKMB(basesProcessed, spaces);
 		String tpstring=""+knownTaxid;
 		
 		outstream.println("Time:                         \t"+t);
