@@ -29,6 +29,7 @@ import json.JsonObject;
 import server.PercentEncoding;
 import server.ServerTools;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -97,6 +98,9 @@ public class TaxServer {
 		long defaultSketchReads=200000;
 		boolean https=false;
 		
+		int serverNum_=0;
+		int serverCount_=1;
+		
 		//Create a parser object
 		Parser parser=new Parser();
 		
@@ -110,15 +114,26 @@ public class TaxServer {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("verbose2")){
-				verbose2=SketchObject.verbose2=Tools.parseBoolean(b);
+				verbose2=SketchObject.verbose2=Parse.parseBoolean(b);
 			}else if(a.equals("html")){
-				useHtml=Tools.parseBoolean(b);
+				useHtml=Parse.parseBoolean(b);
 			}else if(a.equals("https")){
-				https=Tools.parseBoolean(b);
+				https=Parse.parseBoolean(b);
 			}else if(a.equals("http")){
-				https=!Tools.parseBoolean(b);
+				https=!Parse.parseBoolean(b);
+			}else if(a.equals("servers") || a.equals("numservers") || a.equals("servercount")){
+				serverCount_=Integer.parseInt(b);
+				assert(serverCount_>0) : arg;
+			}else if(a.equals("servernum")){
+				serverNum_=Integer.parseInt(b);
+				assert(serverNum_>=0) : arg;
+			}else if(a.startsWith("slave") && Tools.isDigit(a.charAt(a.length()-1))){
+				int num=Integer.parseInt(a.substring(5));
+				if(slaveAddress==null){slaveAddress=new ArrayList<String>(serverCount_);}
+				while(slaveAddress.size()<=num){slaveAddress.add(null);}
+				slaveAddress.set(num, b);
 			}else if(a.equals("table") || a.equals("gi") || a.equals("gitable")){
 				giTableFile=b;
 			}else if(a.equals("tree") || a.equals("taxtree")){
@@ -143,9 +158,9 @@ public class TaxServer {
 			}else if(a.equals("oldaddress")){
 				oldAddress=b;
 			}else if(a.equals("sketchonly")){
-				sketchOnly=Tools.parseBoolean(b);
+				sketchOnly=Parse.parseBoolean(b);
 			}else if(a.equals("sketchreads")){
-				defaultSketchReads=Tools.parseKMG(b);
+				defaultSketchReads=Parse.parseKMG(b);
 			}else if(a.equals("handlerthreads")){
 				handlerThreads=Integer.parseInt(b);
 			}else if(a.equals("sketchthreads") || a.equals("sketchcomparethreads")){
@@ -153,23 +168,23 @@ public class TaxServer {
 			}else if(a.equals("sketchloadthreads")){
 				maxConcurrentSketchLoadThreads=Integer.parseInt(b);
 			}else if(a.equals("hashnames")){
-				hashNames=Tools.parseBoolean(b);
+				hashNames=Parse.parseBoolean(b);
 			}else if(a.equals("hashdotformat")){
-				hashDotFormat=Tools.parseBoolean(b);
+				hashDotFormat=Parse.parseBoolean(b);
 			}else if(a.equals("printip")){
-				printIP=Tools.parseBoolean(b);
+				printIP=Parse.parseBoolean(b);
 			}else if(a.equals("printheaders")){
-				printHeaders=Tools.parseBoolean(b);
+				printHeaders=Parse.parseBoolean(b);
 			}else if(a.equals("countqueries")){
-				countQueries=Tools.parseBoolean(b);
+				countQueries=Parse.parseBoolean(b);
 			}else if(a.equals("clear") || a.equals("clearmem")){
-				clearMem=Tools.parseBoolean(b);
+				clearMem=Parse.parseBoolean(b);
 			}else if(a.equals("dbname")){
 				SketchObject.defaultParams.dbName=b;
 			}else if(a.equals("allowremotefileaccess")){
-				allowRemoteFileAccess_=Tools.parseBoolean(b);
+				allowRemoteFileAccess_=Parse.parseBoolean(b);
 			}else if(a.equals("allowlocalhost")){
-				allowLocalHost_=Tools.parseBoolean(b);
+				allowLocalHost_=Parse.parseBoolean(b);
 			}else if(a.equals("addressprefix")){
 				addressPrefix_=b;
 			}else if(a.equals("maxpigzprocesses")){
@@ -178,7 +193,7 @@ public class TaxServer {
 				basePath=b;
 			}else if(a.equalsIgnoreCase("prealloc")){
 				if(b==null || Character.isLetter(b.charAt(0))){
-					if(Tools.parseBoolean(b)){
+					if(Parse.parseBoolean(b)){
 						prealloc=0.78f;
 					}else{
 						prealloc=0;
@@ -202,6 +217,18 @@ public class TaxServer {
 		if("auto".equalsIgnoreCase(patternFile)){patternFile=TaxTree.defaultPatternFile();}
 		if("auto".equalsIgnoreCase(sizeFile)){sizeFile=TaxTree.defaultSizeFile();}
 		
+		serverNum=AccessionToTaxid.serverNum=serverNum_;
+		serverCount=AccessionToTaxid.serverCount=serverCount_;
+		distributed=AccessionToTaxid.distributed=serverCount>1;
+		assert(serverNum<serverCount && serverNum>=0);
+		if(distributed && serverNum==0){
+			assert(slaveAddress!=null);
+			assert(slaveAddress.size()==serverCount);
+			for(int i=1; i<slaveAddress.size(); i++){
+				assert(slaveAddress.get(i)!=null);
+			}
+		}
+		
 		maxConcurrentSketchCompareThreads=Tools.mid(1, maxConcurrentSketchCompareThreads, Shared.threads());
 		maxConcurrentSketchLoadThreads=Tools.mid(1, maxConcurrentSketchLoadThreads, Shared.threads());
 		assert(maxConcurrentSketchCompareThreads>=1);
@@ -985,6 +1012,7 @@ public class TaxServer {
 		boolean printRange=false;
 		boolean silvaHeader=false;
 		boolean plaintext=false, semicolon=false, path=false;
+		boolean mononomial=false;
 		boolean ancestor=false;
 		int source=SOURCE_REFSEQ;
 		
@@ -997,6 +1025,9 @@ public class TaxServer {
 				printNumChildren=true;
 			}else if(s.equals("printchildren") || s.equals("children")){
 				printChildren=true;
+			}else if(s.equals("mononomial") || s.equals("cn") 
+					|| s.equals("fixname") || s.equals("fn") || s.equals("mono") || s.equals("mononomial")){
+				mononomial=true;
 			}else if(s.equals("printpath") || s.equals("pp")){
 				printPath=true;
 			}else if(s.equals("printsize") || s.equals("size") || s.equals("ps")){
@@ -1025,6 +1056,8 @@ public class TaxServer {
 		newParams.add(params[params.length-1]);
 		params=newParams.toArray(new String[newParams.size()]);
 		
+//		System.err.println("mononomial="+mononomial);
+		
 		if(params.length<2){
 			if(params.length==1 && "advice".equalsIgnoreCase(params[0])){return TAX_ADVICE;}
 			if(logUsage){System.err.println("usage");}
@@ -1099,11 +1132,11 @@ public class TaxServer {
 		
 		if(ancestor){
 			if(verbose2){System.err.println("toAncestor: "+Arrays.toString(names));}
-			return toAncestor(type, names, plaintext, semicolon, path, query, simple, !simple, printNumChildren, printChildren, printPath, printSize, printRange, source);
+			return toAncestor(type, names, plaintext, semicolon, path, query, simple, !simple, printNumChildren, printChildren, printPath, printSize, printRange, mononomial, source);
 		}
 		
 		if(semicolon){
-			return toSemicolon(type, names, simple);
+			return toSemicolon(type, names, simple, mononomial);
 		}else if(plaintext){
 			return toText(type, names);
 		}else if(path){
@@ -1112,14 +1145,17 @@ public class TaxServer {
 
 		JsonObject j=new JsonObject();
 		for(String name : names){
-			j.add(name, toJson(type, name, simple, !simple, printNumChildren, printChildren, printPath, printSize, printRange, source));
+			j.add(name, toJson(type, name, simple, !simple, printNumChildren, printChildren, 
+					printPath, printSize, printRange, mononomial, source));
 		}
 		return j.toString();
 	}
 	
 	/** Look up common ancestor of terms */
-	String toAncestor(final int type, final String[] names, boolean plaintext, boolean semicolon, boolean path, String query, final boolean skipNonCanonical,
-			boolean originalLevel, boolean printNumChildren, boolean printChildren, boolean printPath, boolean printSize, boolean printRange, int source){
+	String toAncestor(final int type, final String[] names, boolean plaintext, boolean semicolon, boolean path,
+			String query, final boolean skipNonCanonical, boolean originalLevel, boolean printNumChildren,
+			boolean printChildren, boolean printPath, boolean printSize, boolean printRange, boolean mononomial,
+			int source){
 		IntList ilist=toIntList(type, names);
 		int id=FindAncestor.findAncestor(tree, ilist);
 		TaxNode tn=(id>-1 ? tree.getNode(id) : null);
@@ -1127,7 +1163,7 @@ public class TaxServer {
 			return new JsonObject("error","Not found.").toString(query);
 		}
 		if(semicolon){
-			return tree.toSemicolon(tn, skipNonCanonical);
+			return tree.toSemicolon(tn, skipNonCanonical, mononomial);
 		}else if(plaintext){
 			return ""+id;
 		}else if(path){
@@ -1135,7 +1171,12 @@ public class TaxServer {
 		}
 		
 		JsonObject j=new JsonObject();
+//		j.add("name", mononomial ? tree.mononomial(tn) : tn.name);
 		j.add("name", tn.name);
+		if(mononomial || true){
+			String mono=tree.mononomial(tn);
+			if(tn.name!=mono){j.add("mononomial", mono);}
+		}
 		j.add("tax_id", tn.id);
 		if(printNumChildren){j.add("num_children", tn.numChildren);}
 		if(printPath){j.add("path", toPath(tn, source));}
@@ -1154,7 +1195,7 @@ public class TaxServer {
 //		if(printChildren){j.add(getChildren(id, originalLevel, printRange));}
 		while(tn!=null && tn.levelExtended!=TaxTree.LIFE_E && tn.id!=TaxTree.CELLULAR_ORGANISMS_ID){
 			if(!skipNonCanonical || tn.isSimple()){
-				j.addAndRename(tn.levelStringExtended(originalLevel), toJson(tn, originalLevel, printNumChildren, printChildren, printPath, printSize, printRange, source, -1));
+				j.addAndRename(tn.levelStringExtended(originalLevel), toJson(tn, originalLevel, printNumChildren, printChildren, printPath, printSize, printRange, mononomial, source, -1));
 			}
 			if(tn.pid==tn.id){break;}
 			tn=tree.getNode(tn.pid);
@@ -1162,19 +1203,24 @@ public class TaxServer {
 		return j.toString();
 	}
 	
-	JsonObject getChildren(final int id, boolean originalLevel, boolean printRange){
+	JsonObject getChildren(final int id, boolean originalLevel, boolean printRange, boolean mononomial){
 		TaxNode x=tree.getNode(id);
 		if(x==null || x.numChildren==0){return null;}
 		ArrayList<TaxNode> list=tree.getChildren(x);
-		return makeChildrenObject(list, originalLevel, printRange);
+		return makeChildrenObject(list, originalLevel, printRange, mononomial);
 	}
 	
-	JsonObject makeChildrenObject(ArrayList<TaxNode> list, boolean originalLevel, boolean printRange){
+	JsonObject makeChildrenObject(ArrayList<TaxNode> list, boolean originalLevel, boolean printRange, boolean mononomial){
 		if(list==null || list.isEmpty()){return null;}
 		JsonObject j=new JsonObject();
 		for(TaxNode tn : list){
 			JsonObject child=new JsonObject();
+//			child.add("name", mononomial ? tree.mononomial(tn) : tn.name);
 			child.add("name", tn.name);
+			if(mononomial || true){
+				String mono=tree.mononomial(tn);
+				if(tn.name!=mono){child.add("mononomial", mono);}
+			}
 			child.add("tax_id", tn.id);
 			child.add("num_children", tn.numChildren);
 			child.add("level", tn.levelStringExtended(originalLevel));
@@ -1197,7 +1243,7 @@ public class TaxServer {
 		if(type2==GI){
 			for(String name : names){
 				sb.append(comma);
-				TaxNode tn=getTaxNodeGi(Integer.parseInt(name));
+				TaxNode tn=getTaxNodeGi(Long.parseLong(name));
 				if(tn==null){sb.append("-1");}
 				else{sb.append(tn.id);}
 				comma=",";
@@ -1221,7 +1267,7 @@ public class TaxServer {
 		}else if(type2==ACCESSION){
 			for(String name : names){
 				sb.append(comma);
-				int ncbi=AccessionToTaxid.get(name);
+				int ncbi=accessionToTaxid(name);
 				sb.append(ncbi);
 				comma=",";
 			}
@@ -1251,13 +1297,13 @@ public class TaxServer {
 		int type2=type&15;
 		final TaxNode tn;
 		if(type2==GI){
-			tn=getTaxNodeGi(Integer.parseInt(name));
+			tn=getTaxNodeGi(Long.parseLong(name));
 		}else if(type2==NAME){
 			tn=getTaxNodeByName(name);
 		}else if(type2==TAXID){
 			tn=getTaxNodeTaxid(Integer.parseInt(name));
 		}else if(type2==ACCESSION){
-			int ncbi=AccessionToTaxid.get(name);
+			int ncbi=accessionToTaxid(name);
 			tn=(ncbi<0 ? null : tree.getNode(ncbi));
 		}else if(type2==HEADER || type2==SILVAHEADER){
 			tn=getTaxNodeHeader(name, type2==SILVAHEADER);
@@ -1293,7 +1339,7 @@ public class TaxServer {
 	}
 	
 	/** Format a reply as plaintext, semicolon-delimited, full lineage */
-	String toSemicolon(final int type, final String[] names, boolean skipNonCanonical){
+	String toSemicolon(final int type, final String[] names, boolean skipNonCanonical, boolean mononomial){
 		
 		StringBuilder sb=new StringBuilder();
 		String comma="";
@@ -1302,9 +1348,9 @@ public class TaxServer {
 		if(type2==GI){
 			for(String name : names){
 				sb.append(comma);
-				TaxNode tn=getTaxNodeGi(Integer.parseInt(name));
+				TaxNode tn=getTaxNodeGi(Long.parseLong(name));
 				if(tn==null){sb.append("Not found");}
-				else{sb.append(tree.toSemicolon(tn, skipNonCanonical));}
+				else{sb.append(tree.toSemicolon(tn, skipNonCanonical, mononomial));}
 				comma=",";
 			}
 		}else if(type2==NAME){
@@ -1312,7 +1358,7 @@ public class TaxServer {
 				sb.append(comma);
 				TaxNode tn=getTaxNodeByName(name);
 				if(tn==null){sb.append("Not found");}
-				else{sb.append(tree.toSemicolon(tn, skipNonCanonical));}
+				else{sb.append(tree.toSemicolon(tn, skipNonCanonical, mononomial));}
 				comma=",";
 			}
 		}else if(type2==TAXID){
@@ -1321,16 +1367,16 @@ public class TaxServer {
 				TaxNode tn=getTaxNodeTaxid(Integer.parseInt(name));
 //				if(verbose2){outstream.println("name="+name+", tn="+tn);}
 				if(tn==null){sb.append("Not found");}
-				else{sb.append(tree.toSemicolon(tn, skipNonCanonical));}
+				else{sb.append(tree.toSemicolon(tn, skipNonCanonical, mononomial));}
 				comma=",";
 			}
 		}else if(type2==ACCESSION){
 			for(String name : names){
 				sb.append(comma);
-				final int tid=AccessionToTaxid.get(name);
+				final int tid=accessionToTaxid(name);
 				TaxNode tn=tree.getNode(tid, true);
 				if(tn==null){sb.append("Not found");}
-				else{sb.append(tree.toSemicolon(tn, skipNonCanonical));}
+				else{sb.append(tree.toSemicolon(tn, skipNonCanonical, mononomial));}
 				comma=",";
 			}
 		}else if(type2==HEADER || type2==SILVAHEADER){
@@ -1338,7 +1384,7 @@ public class TaxServer {
 				sb.append(comma);
 				TaxNode tn=getTaxNodeHeader(name, type2==SILVAHEADER);
 				if(tn==null){sb.append("Not found");}
-				else{sb.append(tree.toSemicolon(tn, skipNonCanonical));}
+				else{sb.append(tree.toSemicolon(tn, skipNonCanonical, mononomial));}
 				comma=",";
 			}
 		}else if(type2==IMG){
@@ -1347,7 +1393,7 @@ public class TaxServer {
 				final int tid=TaxTree.imgToTaxid(Long.parseLong(name));
 				TaxNode tn=tree.getNode(tid, true);
 				if(tn==null){sb.append("Not found");}
-				else{sb.append(tree.toSemicolon(tn, skipNonCanonical));}
+				else{sb.append(tree.toSemicolon(tn, skipNonCanonical, mononomial));}
 				comma=",";
 			}
 		}else{
@@ -1361,19 +1407,20 @@ public class TaxServer {
 	
 	/** Create a JsonObject from a String, including full lineage */
 	JsonObject toJson(final int type, final String name, boolean skipNonCanonical, boolean originalLevel, 
-			boolean printNumChildren, boolean printChildren, boolean printPath, boolean printSize, boolean printRange, int source){
+			boolean printNumChildren, boolean printChildren, boolean printPath, boolean printSize, 
+			boolean printRange, boolean mononomial, int source){
 		final TaxNode tn0;
 		TaxNode tn;
 		
 		long img=-1;
 		if(type==GI){
-			tn0=getTaxNodeGi(Integer.parseInt(name));
+			tn0=getTaxNodeGi(Long.parseLong(name));
 		}else if(type==NAME){
 			tn0=getTaxNodeByName(name);
 		}else if(type==TAXID){
 			tn0=getTaxNodeTaxid(Integer.parseInt(name));
 		}else if(type==ACCESSION){
-			int ncbi=AccessionToTaxid.get(name);
+			int ncbi=accessionToTaxid(name);
 			tn0=(ncbi>=0 ? tree.getNode(ncbi) : null);
 		}else if(type==HEADER || type==SILVAHEADER){
 			tn0=getTaxNodeHeader(name, type==SILVAHEADER);
@@ -1392,7 +1439,12 @@ public class TaxServer {
 		
 		if(tn!=null){
 			JsonObject j=new JsonObject();
+//			j.add("name", mononomial ? tree.mononomial(tn) : tn.name);
 			j.add("name", tn.name);
+			if(mononomial || true){
+				String mono=tree.mononomial(tn);
+				if(tn.name!=mono){j.add("mononomial", mono);}
+			}
 			j.add("tax_id", tn.id);
 			if(printNumChildren){j.add("num_children", tn.numChildren);}
 			if(printPath){j.add("path", type==IMG ? toPathIMG(img) : toPath(tn, source));}
@@ -1408,11 +1460,11 @@ public class TaxServer {
 				j.add("maxDescendent", TaxTree.levelToStringExtended(tn.maxChildLevelExtended));
 				j.add("minAncestor", TaxTree.levelToStringExtended(tn.minParentLevelExtended));
 			}
-			if(printChildren && (tn.id==tn.pid || tn.id==TaxTree.CELLULAR_ORGANISMS_ID)){j.add("children", getChildren(tn.id, originalLevel, printRange));}
+			if(printChildren && (tn.id==tn.pid || tn.id==TaxTree.CELLULAR_ORGANISMS_ID)){j.add("children", getChildren(tn.id, originalLevel, printRange, mononomial));}
 			while(tn!=null && tn.levelExtended!=TaxTree.LIFE_E && tn.id!=TaxTree.CELLULAR_ORGANISMS_ID){
 //				System.err.println(tn+", "+(!skipNonCanonical)+", "+tn.isSimple());
 				if(!skipNonCanonical || tn.isSimple()){
-					j.addAndRename(tn.levelStringExtended(originalLevel), toJson(tn, originalLevel, printNumChildren, printChildren, printPath && tn==tn0, printSize, printRange, source, img));
+					j.addAndRename(tn.levelStringExtended(originalLevel), toJson(tn, originalLevel, printNumChildren, printChildren, printPath && tn==tn0, printSize, printRange, mononomial, source, img));
 //					System.err.println(j);
 				}
 				if(tn.pid==tn.id){break;}
@@ -1430,9 +1482,15 @@ public class TaxServer {
 	
 	/** Create a JsonObject from a TaxNode, at that level only */
 	JsonObject toJson(TaxNode tn, boolean originalLevel, boolean printNumChildren, 
-			boolean printChildren, boolean printPath, boolean printSize, boolean printRange, int source, long img){
+			boolean printChildren, boolean printPath, boolean printSize, boolean printRange, 
+			boolean mononomial, int source, long img){
 		JsonObject j=new JsonObject();
+//		j.add("name", mononomial ? tree.mononomial(tn) : tn.name);
 		j.add("name", tn.name);
+		if(mononomial || true){
+			String mono=tree.mononomial(tn);
+			if(tn.name!=mono){j.add("mononomial", mono);}
+		}
 		j.add("tax_id", tn.id);
 		if(printNumChildren){j.add("num_children", tn.numChildren);}
 		if(printPath){j.add("path", source==SOURCE_IMG ? toPathIMG(img) : toPath(tn, source));}
@@ -1448,7 +1506,7 @@ public class TaxServer {
 			j.add("minAncestor", TaxTree.levelToStringExtended(tn.minParentLevelExtended));
 		}
 		if(printChildren){
-			JsonObject children=getChildren(tn.id, originalLevel, printRange);
+			JsonObject children=getChildren(tn.id, originalLevel, printRange, mononomial);
 			if(children!=null){j.add("children", children);}
 		}
 		return j;
@@ -1488,7 +1546,7 @@ public class TaxServer {
 		int type2=type&15;
 		if(type2==GI){
 			for(String name : names){
-				TaxNode tn=getTaxNodeGi(Integer.parseInt(name));
+				TaxNode tn=getTaxNodeGi(Long.parseLong(name));
 				if(tn!=null){list.add(tn.id);}
 				else{notFound.incrementAndGet();}
 			}
@@ -1506,7 +1564,7 @@ public class TaxServer {
 			}
 		}else if(type2==ACCESSION){
 			for(String name : names){
-				int ncbi=AccessionToTaxid.get(name);
+				int ncbi=accessionToTaxid(name);
 				if(ncbi>=0){list.add(ncbi);}
 				else{notFound.incrementAndGet();}
 			}
@@ -1522,6 +1580,30 @@ public class TaxServer {
 		return list;
 	}
 	
+	public static final String stripAccession(String s){
+		if(s==null){return null;}
+		s=s.toUpperCase();
+		for(int i=0; i<s.length(); i++){
+			char c=s.charAt(i);
+			if(c=='.' || c==':'){return s.substring(0, i);}
+		}
+		return s;
+	}
+	
+	private int accessionToTaxid(String accession){
+		if(accession==null){return -1;}
+		int tid=AccessionToTaxid.get(accession);
+		if(tid<0 && distributed && serverNum==0){
+			accession=stripAccession(accession);
+			int slaveNum=accession.hashCode()%serverCount;
+			if(slaveNum!=serverNum){
+				String path=slaveAddress.get(slaveNum);
+				tid=TaxClient.accessionToTaxidSpecificServer(path, accession);
+			}
+		}
+		return tid;
+	}
+	
 	/** Look up a TaxNode by parsing the organism name */
 	TaxNode getTaxNodeByName(String name){
 		if(verbose2){System.err.println("Fetching node for "+name);}
@@ -1538,7 +1620,7 @@ public class TaxServer {
 	}
 	
 	/** Look up a TaxNode from the gi number */
-	TaxNode getTaxNodeGi(int gi){
+	TaxNode getTaxNodeGi(long gi){
 		int ncbi=-1;
 		try {
 			ncbi=GiToTaxid.getID(gi);
@@ -2193,7 +2275,7 @@ public class TaxServer {
 	private String sizeFile=null;
 
 	/** Location of sequence directory tree */
-	private String basePath="/global/projectb/sandbox/gaag/bbtools/tree/";
+	private String basePath="/global/cfs/cdirs/bbtools/tree/";
 	
 	/** Used for taxonomic tree traversal */
 	private final TaxTree tree;
@@ -2223,6 +2305,11 @@ public class TaxServer {
 	/*----------------         Final Fields         ----------------*/
 	/*--------------------------------------------------------------*/
 
+	private final boolean distributed;
+	private final int serverNum;
+	private final int serverCount;
+	private ArrayList<String> slaveAddress;
+	
 	public final String favIconPath=Data.findPath("?favicon.ico");
 	public final byte[] favIcon=ReadWrite.readRaw(favIconPath);
 	
