@@ -176,9 +176,9 @@ public class TaxSize {
 			double bpnano=basesProcessed/(double)(t.elapsed);
 			
 			//Add "k" and "m" for large numbers
-			String rpstring=Tools.padKM(readsProcessed, 8);
-			String lpstring=Tools.padKM(linesProcessed, 8);
-			String bpstring=Tools.padKM(basesProcessed, 8);
+			String rpstring=Tools.padKMB(readsProcessed, 8);
+			String lpstring=Tools.padKMB(linesProcessed, 8);
+			String bpstring=Tools.padKMB(basesProcessed, 8);
 
 			String li="Lines In:               \t"+linesProcessed+" lines";
 			String lo="Lines Out:              \t"+linesAssigned+" lines";
