@@ -224,7 +224,7 @@ public class TaxTree implements Serializable{
 				}
 			}
 		}
-		nodeCount=(int)Tools.sum(nodesPerLevelExtended);
+		nodeCount=(int)shared.Vector.sum(nodesPerLevelExtended);
 		
 	}
 	
@@ -2483,6 +2483,7 @@ public class TaxTree implements Serializable{
 	private static final String defaultTaxPathNersc="/global/cfs/cdirs/bbtools/tax/latest";
 	private static final String defaultTaxPathAws="/test1/tax/latest";
 	private static final String defaultTaxPathIGBVM="/data/tax/latest";
+	private static final String defaultTaxPathDori="/clusterfs/jgi/groups/gentech/homes/bbushnell/tax/latest";
 	private static final String default16SFileNersc="/global/cfs/cdirs/bbtools/silva/16S_consensus_with_silva_maxns10_taxsorted.fa.gz";
 	private static final String default16SFileAws="/test1/16S_consensus_with_silva_maxns10_taxsorted.fa.gz";
 	private static final String default16SFileIGBVM="/data/sketch/silva/16S_consensus_with_silva_maxns10_taxsorted.fa.gz";
@@ -2511,7 +2512,7 @@ public class TaxTree implements Serializable{
 
 	/** For setting TAX_PATH, the root to taxonomy files */
 	public static final String defaultTaxPath(){
-		return (Shared.AWS && !Shared.NERSC) ? defaultTaxPathAws : Shared.IGBVM ? defaultTaxPathIGBVM : defaultTaxPathNersc;
+		return (Shared.AWS && !Shared.NERSC) ? defaultTaxPathAws : Shared.IGBVM ? defaultTaxPathIGBVM : Shared.DORI ? defaultTaxPathDori : defaultTaxPathNersc;
 	}
 
 	/** 16S consensus sequences per TaxID */
