@@ -73,7 +73,8 @@ public class A_SampleByteFile {
 
 			out1=parser.out1;
 		}
-		
+
+		validateParams();
 		fixExtensions(); //Add or remove .gz or .bz2 as needed
 		checkFileExistence(); //Ensure files can be read and written
 		checkStatics(); //Adjust file-related static fields as needed for this program
@@ -90,9 +91,18 @@ public class A_SampleByteFile {
 	/** Parse arguments from the command line */
 	private Parser parse(String[] args){
 		
+		//Create a parser object
 		Parser parser=new Parser();
+		
+		//Set any necessary Parser defaults here
+		//parser.foo=bar;
+//		parser.out1="stdout";
+		
+		//Parse each argument
 		for(int i=0; i<args.length; i++){
 			String arg=args[i];
+			
+			//Break arguments into their constituent parts, in the form of "a=b"
 			String[] split=arg.split("=");
 			String a=split[0].toLowerCase();
 			String b=split.length>1 ? split[1] : null;
@@ -108,12 +118,15 @@ public class A_SampleByteFile {
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				ReadWrite.verbose=verbose;
+			}else if(a.equals("parse_flag_goes_here")){
+				long fake_variable=Parse.parseKMG(b);
+				//Set a variable here
 			}else if(parser.parse(arg, a, b)){
 				//do nothing
 			}else{
 				outstream.println("Unknown parameter "+args[i]);
 				assert(false) : "Unknown parameter "+args[i];
-				//				throw new RuntimeException("Unknown parameter "+args[i]);
+				throw new RuntimeException("Unknown parameter "+args[i]);
 			}
 		}
 		
@@ -158,10 +171,18 @@ public class A_SampleByteFile {
 //		}
 	}
 	
+	/** Ensure parameter ranges are within bounds and required parameters are set */
+	private boolean validateParams(){
+//		assert(minfoo>0 && minfoo<=maxfoo) : minfoo+", "+maxfoo;
+		assert(false) : "TODO";
+		return true;
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------         Outer Methods        ----------------*/
 	/*--------------------------------------------------------------*/
-	
+
+	/** Create streams and process all data */
 	void process(Timer t){
 		
 		ByteFile bf=ByteFile.makeByteFile(ffin1);
@@ -187,6 +208,7 @@ public class A_SampleByteFile {
 		outstream.println("Valid Lines:       \t"+linesOut);
 		outstream.println("Invalid Lines:     \t"+(linesProcessed-linesOut));
 		
+		//Throw an exception of there was an error in a thread
 		if(errorState){
 			throw new RuntimeException(getClass().getName()+" terminated in an error state; the output may be corrupt.");
 		}
@@ -237,9 +259,14 @@ public class A_SampleByteFile {
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
-	
+
+	/** Primary input file path */
 	private String in1=null;
+
+	/** Primary output file path */
 	private String out1=null;
+
+	/** Junk output file path */
 	private String outInvalid=null;
 	
 	/*--------------------------------------------------------------*/
@@ -255,18 +282,26 @@ public class A_SampleByteFile {
 	/*----------------         Final Fields         ----------------*/
 	/*--------------------------------------------------------------*/
 	
+	/** Input File */
 	private final FileFormat ffin1;
+	/** Output File */
 	private final FileFormat ffout1;
+	/** Optional Output File for Junk */
 	private final FileFormat ffoutInvalid;
 	
 	/*--------------------------------------------------------------*/
 	/*----------------        Common Fields         ----------------*/
 	/*--------------------------------------------------------------*/
 	
+	/** Print status messages to this output stream */
 	private PrintStream outstream=System.err;
+	/** Print verbose messages */
 	public static boolean verbose=false;
+	/** True if an error was encountered */
 	public boolean errorState=false;
+	/** Overwrite existing output files */
 	private boolean overwrite=false;
+	/** Append to existing output files */
 	private boolean append=false;
 	
 }
