@@ -10,7 +10,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -20,6 +19,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * This class does nothing.
@@ -337,11 +337,13 @@ public class A_SampleMT implements Accumulator<A_SampleMT.ProcessThread> {
 	
 	@Override
 	public final void accumulate(ProcessThread pt){
-		readsProcessed+=pt.readsProcessedT;
-		basesProcessed+=pt.basesProcessedT;
-		readsOut+=pt.readsOutT;
-		basesOut+=pt.basesOutT;
-		errorState|=(!pt.success);
+		synchronized(pt) {
+			readsProcessed+=pt.readsProcessedT;
+			basesProcessed+=pt.basesProcessedT;
+			readsOut+=pt.readsOutT;
+			basesOut+=pt.basesOutT;
+			errorState|=(!pt.success);
+		}
 	}
 	
 	@Override
