@@ -9,7 +9,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -21,6 +20,7 @@ import stream.SamLine;
 import stream.SamReadStreamer;
 import stream.SamStreamer;
 import structures.ListNum;
+import tracker.ReadStats;
 import var2.Realigner;
 import var2.SamFilter;
 import var2.ScafMap;
