@@ -10,7 +10,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -20,6 +19,7 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
