@@ -12,6 +12,7 @@ import dna.Data;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
 import pacbio.SiteR;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -59,19 +60,19 @@ public class GenerateVarlets3 {
 			if(Parser.parseZip(arg, a, b)){
 				//do nothing
 			}else if(a.equals("condense")){
-				CONDENSE=Tools.parseBoolean(b);
+				CONDENSE=Parse.parseBoolean(b);
 			}else if(a.equals("condensesnps")){
-				CONDENSE_SNPS=Tools.parseBoolean(b);
+				CONDENSE_SNPS=Parse.parseBoolean(b);
 			}else if(a.startsWith("splitsubs")){
-				SPLIT_SUBS=Tools.parseBoolean(b);
+				SPLIT_SUBS=Parse.parseBoolean(b);
 			}else if(a.startsWith("illumina")){
-				PAC_BIO_MODE=!Tools.parseBoolean(b);
+				PAC_BIO_MODE=!Parse.parseBoolean(b);
 			}else if(a.startsWith("pacbio")){
-				PAC_BIO_MODE=Tools.parseBoolean(b);
+				PAC_BIO_MODE=Parse.parseBoolean(b);
 			}else if(a.equals("tosssolo1")){
-				TOSS_SOLO1=Tools.parseBoolean(b);
+				TOSS_SOLO1=Parse.parseBoolean(b);
 			}else if(a.equals("tosssolo2")){
-				TOSS_SOLO2=Tools.parseBoolean(b);
+				TOSS_SOLO2=Parse.parseBoolean(b);
 			}else if(a.startsWith("minchrom")){
 				minChrom=Integer.parseInt(b);
 			}else if(a.startsWith("maxchrom")){
