@@ -10,7 +10,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -23,6 +22,7 @@ import structures.ByteBuilder;
 import structures.CoverageArray;
 import structures.CoverageArray2;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Applies variants
