@@ -668,9 +668,9 @@ public class CallVariants {
 			long a=initialCount, b=varMap.size(), c=varsPrefiltered, d=varsProcessed;
 			double amult=100.0/a;
 			double bmult=100.0/b;
-			long homozygousCount=(ploidy<2 ? Tools.sum(ploidyArray) : ploidyArray[ploidyArray.length-1]);
+			long homozygousCount=(ploidy<2 ? shared.Vector.sum(ploidyArray) : ploidyArray[ploidyArray.length-1]);
 //			System.err.println(Arrays.toString(ploidyArray));
-			double homozygousRate=homozygousCount*1.0/Tools.sum(ploidyArray);
+			double homozygousRate=homozygousCount*1.0/shared.Vector.sum(ploidyArray);
 //			outstream.println();
 			if(prefilter){
 				outstream.println(c+" of "+d+" events were screened by the prefilter ("+String.format(Locale.ROOT, "%.4f%%", c*100.0/d)+").");
@@ -1183,7 +1183,7 @@ public class CallVariants {
 				}
 			}else{
 				trimmedBasesProcessedT+=r.length();
-				totalQualitySumT+=Tools.sum(r.quality);
+				totalQualitySumT+=shared.Vector.sum(r.quality);
 				totalMapqSumT+=sl.mapq;
 				if(calcCoverage){scaf.add(sl);}
 				if(vars==null){return true;}
@@ -1286,6 +1286,7 @@ public class CallVariants {
 		final int scafnum=scafMap.getNumber(sl.rnameS());
 		assert(scafnum>=0) : "Can't find scaffold "+sl.rnameS();
 		if(scafnum<0){return 0;}
+//		System.err.println("A");
 		
 		if(r.match!=null && r.shortmatch()){
 			r.toLongMatchString(false);
@@ -1345,6 +1346,8 @@ public class CallVariants {
 		if(rcomp){r.reverseComplement();}
 		
 //		assert(false) : new String(r.match);
+
+//		System.err.println("B:"+varsFound);
 		return varsFound;
 	}
 	
