@@ -1119,7 +1119,7 @@ public class CallVariants2 {
 					}
 				}else{
 					trimmedBasesProcessedT+=r.length();
-					totalQualitySumT+=Tools.sum(r.quality);
+					totalQualitySumT+=shared.Vector.sum(r.quality);
 					totalMapqSumT+=sl.mapq;
 					if(calcCoverage){scaf.add(sl);}
 					if(vars==null){return true;}
