@@ -10,7 +10,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -22,6 +21,7 @@ import stream.SamLine;
 import stream.SamReadStreamer;
 import stream.SamStreamer;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Removes lines with unsupported variations from a sam file.
@@ -215,7 +215,13 @@ public class FilterSam {
 			
 			String[] cvargs=new String[] {inString, "ref="+ref, "clearfilters", "minreads="+(maxBadAlleleDepth), 
 					"minallelefraction="+maxBadAlleleFraction, "printexecuting=f"};
+
+			boolean trd=Shared.TRIM_READ_COMMENTS;
+			boolean trn=Shared.TRIM_RNAME;
 			CallVariants cv=new CallVariants(cvargs);
+			Shared.TRIM_READ_COMMENTS=trd;
+			Shared.TRIM_RNAME=trn;
+			
 			cv.prefilter=prefilter;
 			cv.ploidy=ploidy;
 
