@@ -9,7 +9,6 @@ import fileIO.ReadWrite;
 import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -21,6 +20,7 @@ import stream.Read;
 import stream.ReadStreamWriter;
 import stream.SamLine;
 import structures.ListNum;
+import tracker.ReadStats;
 
 /**
  * Realigns samlines to a reference.
