@@ -3,6 +3,7 @@ package var2;
 import java.util.HashSet;
 
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Tools;
 import stream.SamLine;
 
@@ -11,31 +12,31 @@ public class SamFilter {
 	public boolean parse(String arg, String a, String b){
 
 		if(a.equals("min") || a.equals("minpos")){
-			minPos=Tools.parseIntKMG(b);
+			minPos=Parse.parseIntKMG(b);
 			assert(minPos<=maxPos) : "minPos>maxPos";
 		}else if(a.equals("max") || a.equals("maxpos")){
-			maxPos=Tools.parseIntKMG(b);
+			maxPos=Parse.parseIntKMG(b);
 			assert(minPos<=maxPos) : "minPos>maxPos";
 		}else if(a.equals("minreadmapq") || a.equals("minsammapq") || a.equals("minmapq")){
-			minMapq=Tools.parseIntKMG(b);
+			minMapq=Parse.parseIntKMG(b);
 		}else if(a.equals("maxreadmapq") || a.equals("maxsammapq") || a.equals("maxmapq")){
-			maxMapq=Tools.parseIntKMG(b);
+			maxMapq=Parse.parseIntKMG(b);
 		}else if(a.equals("mapped")){
-			includeMapped=Tools.parseBoolean(b);
+			includeMapped=Parse.parseBoolean(b);
 		}else if(a.equals("unmapped")){
-			includeUnmapped=Tools.parseBoolean(b);
+			includeUnmapped=Parse.parseBoolean(b);
 		}else if(a.equals("secondary") || a.equals("nonprimary")){
-			includeNonPrimary=Tools.parseBoolean(b);
+			includeNonPrimary=Parse.parseBoolean(b);
 		}else if(a.equals("supplimentary")){
-			includeSupplimentary=Tools.parseBoolean(b);
+			includeSupplimentary=Parse.parseBoolean(b);
 		}else if(a.equals("duplicate") || a.equals("duplicates")){
-			includeDuplicate=Tools.parseBoolean(b);
+			includeDuplicate=Parse.parseBoolean(b);
 		}else if(a.equals("qfail") || a.equals("samqfail")){
-			includeQfail=Tools.parseBoolean(b);
+			includeQfail=Parse.parseBoolean(b);
 		}else if(a.equals("lengthzero")){
-			includeLengthZero=Tools.parseBoolean(b);
+			includeLengthZero=Parse.parseBoolean(b);
 		}else if(a.equals("invert")){
-			invert=Tools.parseBoolean(b);
+			invert=Parse.parseBoolean(b);
 		}else if(a.equals("minid")){
 			minId=Float.parseFloat(b);
 			if(minId>1f){minId/=100;}
