@@ -22,7 +22,8 @@ public class VarMap implements Iterable<Var> {
 	}
 
 	@SuppressWarnings("unchecked")
-	VarMap(ScafMap scafMap_, int ploidy_, double pairingRate_, double totalQualityAvg_, double mapqAvg_, double readLengthAvg_){
+	VarMap(ScafMap scafMap_, int ploidy_, double pairingRate_, double totalQualityAvg_,
+			double mapqAvg_, double readLengthAvg_){
 		scafMap=scafMap_;
 		ploidy=ploidy_;
 		properPairRate=pairingRate_;
@@ -117,7 +118,73 @@ public class VarMap implements Iterable<Var> {
 	/*--------------------------------------------------------------*/
 	/*----------------           Methods            ----------------*/
 	/*--------------------------------------------------------------*/
-
+	
+	public int countNearbyVars(VarFilter varFilter) {
+		return countNearbyVars(varFilter, varFilter.maxNearbyCount, varFilter.nearbyDist, 
+				varFilter.nearbyGap, varFilter.flagNearby);
+	}
+	
+	public int countNearbyVars(VarFilter varFilter, final int maxCount0, final int maxDist, final int maxGap, final boolean flag) {
+		final int maxCount=maxCount0<0 ? 19 : Tools.mid(maxCount0, 8, 19);
+		final Var[] array=toArray(true);
+		int failed=0;
+		for(int vloc=0; vloc<array.length; vloc++){
+			int x=countNearbyVars(varFilter, array, vloc, maxCount, maxDist, maxGap, flag);
+			if(x>maxCount){failed++;}
+		}
+		return failed;
+	}
+	
+	private boolean passesSolo(Var v, VarFilter varFilter){
+		assert(varFilter!=null);
+		if(varFilter==null){return true;}
+		boolean pass=varFilter.passesFast(v);
+		if(pass){
+			v.calcCoverage(scafMap);
+			pass=v.forced() || varFilter.passesFilter(v, properPairRate, totalQualityAvg,
+					totalMapqAvg, readLengthAvg, ploidy, scafMap, false);
+		}
+		return pass;
+	}
+	
+	public int countNearbyVars(VarFilter varFilter, final Var[] array, final int vloc0, final int maxCount, 
+			final int maxDist, final int maxGap, final boolean flag) {
+		final Var v0=array[vloc0];
+		assert(v0.nearbyVarCount==-1) : "Nearby vars were already counted?";
+		int nearby=0;
+		
+		{//Scan left
+			Var prev=v0;
+			for(int i=vloc0-1; i>=0 && nearby<=maxCount; i--){
+				final Var v=array[i];
+				//			v.stop==v.start means adjacent;
+				if(prev.start-v.stop>maxGap || v0.start-v.stop>maxDist){break;}
+				
+				if(!v.forced() || passesSolo(v, varFilter)){
+					nearby++;
+					prev=v;
+				}
+			}
+		}
+		{//Scan right
+			Var prev=v0;
+			for(int i=vloc0+1; i<array.length && nearby<=maxCount; i++){
+				final Var v=array[i];
+				//			v.stop==v.start means adjacent;
+				if(v.start-prev.stop>maxGap || v.start-v0.stop>maxDist){break;}
+				
+				if(!v.forced() || passesSolo(v, varFilter)){
+					nearby++;
+					prev=v;
+				}
+			}
+		}
+		v0.nearbyVarCount=nearby;
+		if(flag && nearby>varFilter.maxNearbyCount){
+			v0.setFlagged(true);
+		}
+		return nearby;
+	}
 	
 	/*--------------------------------------------------------------*/
 	/*----------------           Getters            ----------------*/
@@ -187,6 +254,11 @@ public class VarMap implements Iterable<Var> {
 		return 0;
 	}
 	
+	int removeUnsynchronized(Var v){
+		final ConcurrentHashMap<Var, Var> map=maps[v.start&MASK];
+		return map.remove(v)==null ? 0 : 1;
+	}
+	
 	int dumpVars(HashMap<Var, Var> mapT){
 		int added=0;
 		@SuppressWarnings("unchecked")
@@ -241,9 +313,9 @@ public class VarMap implements Iterable<Var> {
 		
 		long[] types=new long[Var.VAR_TYPES];
 		for(ConcurrentHashMap<Var, Var> map : maps){
-			long[] types2=processVariants(map, filter, null, null, null, null, null, null, false);
-			types2=processVariants(map, filter, null, null, null, null, null, null, true);
-			types2=processVariants(map, filter, scoreArray, ploidyArray, avgQualityArray, maxQualityArray, ADArray, AFArray, false);
+			long[] types2=processVariants(map, filter, null, null, null, null, null, null, false, false);
+			types2=processVariants(map, filter, null, null, null, null, null, null, true, false);
+			types2=processVariants(map, filter, scoreArray, ploidyArray, avgQualityArray, maxQualityArray, ADArray, AFArray, false, false);
 			Tools.add(types, types2);
 		}
 		return types;
@@ -332,7 +404,7 @@ public class VarMap implements Iterable<Var> {
 		
 		@Override
 		public void run(){
-			types=processVariants(map, filter, scoreArray, ploidyArray, avgQualityArray, maxQualityArray, ADArray, AFArray, processInsertions);
+			types=processVariants(map, filter, scoreArray, ploidyArray, avgQualityArray, maxQualityArray, ADArray, AFArray, processInsertions, false);
 			success=true;
 		}
 		
@@ -350,7 +422,7 @@ public class VarMap implements Iterable<Var> {
 	}
 
 	private long[] processVariants(Map<Var, Var> map, VarFilter filter, long[][] scoreArray, long[] ploidyArray, 
-			long[][] avgQualityArray, long[] maxQualityArray, long[][] ADArray, double[] AFArray, boolean processInsertions) {
+			long[][] avgQualityArray, long[] maxQualityArray, long[][] ADArray, double[] AFArray, boolean processInsertions, boolean considerNearby) {
 		assert(properPairRate>=0);
 		assert(ploidy>0);
 		assert(totalQualityAvg>=0);
@@ -371,7 +443,7 @@ public class VarMap implements Iterable<Var> {
 				boolean pass=filter.passesFast(v);
 				if(pass){
 					v.calcCoverage(scafMap);
-					pass=v.forced() || filter.passesFilter(v, properPairRate, totalQualityAvg, totalMapqAvg, readLengthAvg, ploidy, scafMap);
+					pass=v.forced() || filter.passesFilter(v, properPairRate, totalQualityAvg, totalMapqAvg, readLengthAvg, ploidy, scafMap, considerNearby);
 				}
 				if(pass){
 					types[v.type()]++;
