@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified January 26, 2021
+Last modified November 22, 2023
 
 Description:  Reformats reads to change ASCII quality encoding, interleaving, file format, or compression format.
 Optionally performs additional functions such as quality trimming, subsetting, and subsampling.
@@ -140,6 +140,18 @@ maxgc=1                 Discard reads with GC content above this.
 gcpairs=t               Use average GC of paired reads.
                         Also affects gchist.
 
+Tag-filtering parameters:
+tag=                    Look for this tag in the header to filter by the next value.
+                        e.g. to filter reads with a tag like 'depth=5.5' where you only want depths
+                        of at least 3, the two necessary flags would be 'tag=depth= minvalue=3'.
+delimiter=              Character after the end of the value, such as delimiter=X.  Control symbols
+                        may be escaped or spelled out, like delimiter=\t or delimiter=pipe.
+                        The tag may contain the delimiter.  If the value is the last term
+                        in the header, the delimiter doesn't matter but is still required.
+minvalue=               If set, only accept a numeric value of at least this.
+maxvalue=               If set, only accept a numeric value of at most this.
+value=                  If set, only accept a string value of exactly this.
+
 Sam and bam processing options:
 
 mappedonly=f            Toss unmapped reads.
@@ -209,7 +221,7 @@ popd > /dev/null
 CP="$DIR""current/"
 
 z="-Xmx300m"
-z="-Xms300m"
+z2="-Xms300m"
 set=0
 
 if [ -z "$1" ] || [[ $1 == -h ]] || [[ $1 == --help ]]; then
