@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified February 3, 2021
+Last modified July 18, 2021
 
 Description:  RQCFilter2 is a revised version of RQCFilter that uses a common path for all dependencies.
 The dependencies are available at http://portal.nersc.gov/dna/microbial/assembly/bushnell/RQCFilterData.tar
@@ -105,6 +105,7 @@ trimpolyg=0         Trim reads that start or end with a G polymer at least this
 phix=t              Remove reads containing phiX kmers.
 lambda=f            Remove reads containing Lambda phage kmers.
 pjet=t              Remove reads containing PJET kmers.
+sip=f               Remove SIP spikeins.
 maskmiddle=t        (mm) Treat the middle base of a kmer as a wildcard, to increase sensitivity in the presence of errors.
 maxbadkmers=0       (mbk) Reads with more than this many contaminant kmers will be discarded.
 filterhdist=1       Hamming distance used for filtering.
