@@ -3,20 +3,22 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified January 13, 2022
-Description:  Shreds sequences into shorter, potentially overlapping sequences.
+Last modified November 14, 2023
+Description:  Shreds sequences into shorter, possibly overlapping sequences.
 
-Usage:	shred.sh in=<file> out=<file> length=<number> minlength=<number> overlap=<number>
+Usage: shred.sh in=<file> out=<file> length=<int>
 
 in=<file>       Input sequences.
 out=<file>      Destination of output shreds.
-length=500      Desired length of shreds.
-minlength=1     Shortest allowed shred.  The last shred of each input sequence may be shorter than desired length.
-overlap=0       Amount of overlap between successive reads.
+length=500      Desired length of shreds if a uniform length is desired.
+minlen=-1       Shortest allowed shred.  The last shred of each input sequence
+                may be shorter than desired length if this is not set.
+maxlen=-1       Longest shred length.  If minlength and maxlength are both
+                set, shreds will use a random flat length distribution.
+overlap=0       Amount of overlap between successive shreds.
 reads=-1        If nonnegative, stop after this many input sequences.
-equal=f         Shred each sequence into subsequences of equal size of at most 'length', instead of a fixed size.
-median=0        If nonzero, randomly shred reads to a length with this median.
-variance=0      If median is nonzero, shred to lengths of median +-variance.
+equal=f         Shred each sequence into subsequences of equal size of at most
+                'length', instead of a fixed size.
 qfake=30        Quality score, if using fastq output.
 
 Please contact Brian Bushnell at bbushnell@lbl.gov if you encounter any problems.
@@ -37,7 +39,7 @@ popd > /dev/null
 #DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )/"
 CP="$DIR""current/"
 
-z="-Xmx1400m"
+z="-Xmx4000m"
 set=0
 
 if [ -z "$1" ] || [[ $1 == -h ]] || [[ $1 == --help ]]; then
